//--------------------------------------------------------------------------
//  Include file which defines the LS radio packet format
//
//  NOTE:If you are porting this code to another processor, the bit fields 
//       may need to be swapped around, and calls to protocol_gen_parity may need to be 
//       changed also (casting to find the beginning of the header byte).
//
//--------------------------------------------------------------------------
// $Archive: /WirelessUSB/LS/Firmware/LS DVK/PSoC/Radio/protocol.h $
// $Modtime: 3/04/04 3:11p $
// $Revision: 1.2 $
//--------------------------------------------------------------------------
//
// Copyright 2003-2004, Cypress Semiconductor Corporation.
//
// This software is owned by Cypress Semiconductor Corporation (Cypress)
// and is protected by and subject to worldwide patent protection (United
// States and foreign), United States copyright laws and international 
// treaty provisions. Cypress hereby grants to licensee a personal, 
// non-exclusive, non-transferable license to copy, use, modify, create 
// derivative works of, and compile the Cypress Source Code and derivative 
// works for the sole purpose of creating custom software in support of 
// licensee product to be used only in conjunction with a Cypress integrated 
// circuit as specified in the applicable agreement. Any reproduction, 
// modification, translation, compilation, or representation of this 
// software except as specified above is prohibited without the express 
// written permission of Cypress.
//
// Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED, 
// WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Cypress reserves the right to make changes without further notice to the
// materials described herein. Cypress does not assume any liability arising
// out of the application or use of any product or circuit described herein.
// Cypress does not authorize its products for use as critical components in
// life-support systems where a malfunction or failure may reasonably be
// expected to result in significant injury to the user. The inclusion of
// Cypress product in a life-support systems application implies that the
// manufacturer assumes all risk of such use and in doing so indemnifies
// Cypress against all charges.
//
// Use may be limited by and subject to the applicable Cypress software
// license agreement.
//
//--------------------------------------------------------------------------

#ifndef _PROTOCOL_H_
#define _PROTOCOL_H_

#include "ls_config.h"

#define NUM_CHANNELS 	        78
#define PIN_MASK       	        0x03  
#define MIN_PIN                 0x02
#define DEFAULT_CHECKSUM_SEED   0x00   // Connect and data seed


#define LS_STATUS_SUCCESS   0x00
#define LS_STATUS_FAILED    0x01

//  Status codes
#define DATA_SENT      		41

// setup packet types
#define DATA_PACKET         0x04
#define ACK_PACKET          0x05
#define DATA_ACK_PACKET     0x06


typedef union _SYS_PARAMETERS
{
    struct 
    {
    	UINT8	channel;
    	UINT8	pn_code;
    	UINT8   seed;
       	UINT8	pin;
       	UINT8	base_channel;
        UINT8   signature;
    } network_id;

    #ifdef PROTOCOL_1_1
    struct 
    {
        UINT8   mid_1;
        UINT8   mid_2;
        UINT8   mid_3;
        UINT8   mid_4;
        //UINT8   signature;
    } bridge_mid;
    #endif // PROTOCOL_1_1

} SYS_PARAMETERS;

extern SYS_PARAMETERS sys_params;

#define SIGNATURE_BYTE    0x90

#define GAP_DELAY  0x01   // delay between retransmissions in msec

typedef union _LS_TX_PACKET
{
    struct
    {
        struct
        {
            unsigned parity : 0x01;
            unsigned dev_id : 0x01;   
            unsigned dt_data: 0x01;   
            unsigned fill   : 0x01;   
            unsigned type   : 0x04;   
        } hdr; 
    
        // check sum is added to the end of variable length packet
	    UINT8   app_packet[APP_TX_PACKET_SIZE + 1]; 
    } data;

    struct
    {
        UINT8 byte;
    } first;

} LS_TX_PACKET;


UINT8  protocol_init(void);
void * protocol_get_tx_pkt(void);
UINT8  protocol_gen_parity(UINT8 data);
UINT8  protocol_calc_ck_sum(UINT8 *data, UINT8 len, UINT8 seed);
UINT8  protocol_send_packet(UINT8 data_length);


#ifdef PROTOCOL_1_1
void   calculate_network_id(void);
#endif

extern LS_TX_PACKET  tx_packet;
extern UINT8 protocol_device_type;

#endif // _PROTOCOL_H_
