//--------------------------------------------------------------------------
//
//  Collection of the bind routines for basic, sem-auto, and automatic bind.
//
//--------------------------------------------------------------------------
// $Archive: $
// $Modtime: $
// $Revision: 1.2 $
//--------------------------------------------------------------------------
//
// Copyright 2003-2004, Cypress Semiconductor Corporation.
//
// This software is owned by Cypress Semiconductor Corporation (Cypress)
// and is protected by and subject to worldwide patent protection (United
// States and foreign), United States copyright laws and international 
// treaty provisions. Cypress hereby grants to licensee a personal, 
// non-exclusive, non-transferable license to copy, use, modify, create 
// derivative works of, and compile the Cypress Source Code and derivative 
// works for the sole purpose of creating custom software in support of 
// licensee product to be used only in conjunction with a Cypress integrated 
// circuit as specified in the applicable agreement. Any reproduction, 
// modification, translation, compilation, or representation of this 
// software except as specified above is prohibited without the express 
// written permission of Cypress.
//
// Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED, 
// WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Cypress reserves the right to make changes without further notice to the
// materials described herein. Cypress does not assume any liability arising
// out of the application or use of any product or circuit described herein.
// Cypress does not authorize its products for use as critical components in
// life-support systems where a malfunction or failure may reasonably be
// expected to result in significant injury to the user. The inclusion of
// Cypress product in a life-support systems application implies that the
// manufacturer assumes all risk of such use and in doing so indemnifies
// Cypress against all charges.
//
// Use may be limited by and subject to the applicable Cypress software
// license agreement.
//
//--------------------------------------------------------------------------


#include "bind.h"
#include "protocol.h"
#include "radio.h"


///////////////////////////////////////////////////////////////////////////////
//
//  Function:    protocol_bind_init
//
//  Description: Perform the semi-automatic bind and PN Code setup
//
//  Inputs:      Void
//
//  Returns:     Void
//
///////////////////////////////////////////////////////////////////////////////

void protocol_bind_init()    // Bind Semi
{
    // initialize PN Code
    radio_set_pn_code(sys_params.pn_code);

#ifdef RADIO_SLEEP_ENABLED
    radio_sleep();
#endif
}

///////////////////////////////////////////////////////////////////////////////
//
//  Function:    protocol_bind
//
//  Description: Read the rotary switch and set the channel
//
//  Inputs:      Void
//
//  Returns:     Void
//
///////////////////////////////////////////////////////////////////////////////

UINT8 protocol_bind()    // Bind Semi
{

#ifdef RADIO_SLEEP_ENABLED
    radio_wakeup();
#endif    
    
    // semi-bind mode state machine
    
    UINT8 payload[3];
    UINT8 ping_packet[LEN_PING];
    UINT8 bind_hops;
    UINT8 bind_radio_transmits;

    sys_params.channel += 25;   // bump channel
    if( sys_params.channel > NUM_CHANNELS )
    {
         sys_params.channel -= NUM_CHANNELS;
    }
    sys_params.pn_code += 3;   // bump PN Code index
    if( sys_params.pn_code > NUM_PN_CODES )
    {
         sys_params.pn_code -=  NUM_PN_CODES;
    }

    // build the bind packet
    payload[0] = sys_params.channel; // frequency
    payload[1] = sys_params.pn_code; // PN code
    
    payload[2] = protocol_calc_ck_sum((UINT8 *)&payload, 2, BIND_SEED);
    ping_packet[0] = PING_DATA;
	
    for(bind_hops = BIND_MAX_HOPS; bind_hops > 0; bind_hops--) 
    {
        // transmit the bind packet
        radio_set_pn_code(BIND_PN_CODE);
	for(bind_radio_transmits = BIND_MAX_TRANSMITS;
            bind_radio_transmits > 0;
            bind_radio_transmits--) 
        {
	    radio_transmit_on(BIND_CHANNEL);
	    radio_transmit(LEN_BIND, &payload[0]);
	    radio_off();
	    TIMER_DELAY_MSEC(1);
	}

	// transmit the ping packet
        radio_set_pn_code(sys_params.pn_code);
	for(bind_radio_transmits = BIND_MAX_TRANSMITS;
            bind_radio_transmits > 0;
            bind_radio_transmits--) 
        {            
	    radio_transmit_on(sys_params.channel);
	    radio_transmit(LEN_PING, &ping_packet[0]);
	    radio_off();
	    TIMER_DELAY_MSEC(1);
	}		
    }
    radio_off();
	
    // write the flash
    NVRAM_WRITE( &sys_params, sizeof(sys_params) );

    // load the PN Code based on the index       
    radio_set_pn_code(sys_params.pn_code);       

#ifdef RADIO_SLEEP_ENABLED
    radio_sleep();
#endif   
        
    return LS_STATUS_SUCCESS;
}
