//--------------------------------------------------------------------------
//
//  Collection of the bind routines for basic bind.
//
//--------------------------------------------------------------------------
// $Archive: $
// $Modtime: $
// $Revision: 1.4 $
//--------------------------------------------------------------------------
//
// Copyright 2003-2004, Cypress Semiconductor Corporation.
//
// This software is owned by Cypress Semiconductor Corporation (Cypress)
// and is protected by and subject to worldwide patent protection (United
// States and foreign), United States copyright laws and international 
// treaty provisions. Cypress hereby grants to licensee a personal, 
// non-exclusive, non-transferable license to copy, use, modify, create 
// derivative works of, and compile the Cypress Source Code and derivative 
// works for the sole purpose of creating custom software in support of 
// licensee product to be used only in conjunction with a Cypress integrated 
// circuit as specified in the applicable agreement. Any reproduction, 
// modification, translation, compilation, or representation of this 
// software except as specified above is prohibited without the express 
// written permission of Cypress.
//
// Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED, 
// WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Cypress reserves the right to make changes without further notice to the
// materials described herein. Cypress does not assume any liability arising
// out of the application or use of any product or circuit described herein.
// Cypress does not authorize its products for use as critical components in
// life-support systems where a malfunction or failure may reasonably be
// expected to result in significant injury to the user. The inclusion of
// Cypress product in a life-support systems application implies that the
// manufacturer assumes all risk of such use and in doing so indemnifies
// Cypress against all charges.
//
// Use may be limited by and subject to the applicable Cypress software
// license agreement.
//
//--------------------------------------------------------------------------


#include "basic_bind.h"
#include "protocol.h"
#include "radio.h"

//! Created for protocol_send_packet defaulted to CONNECTED_STATE
UINT8 bind_mode = CONNECTED_STATE;

#ifdef DATA_RATE_16

//! 8 PN codes for a data rate of 32kbps or 64kbps, and 48 PN codes for a
//! data rate of 16kbps
const UINT8 pn_code_table[] = 
{
    0x83, 0xF7, 0xA8, 0x2D, 0x7A, 0x44, 0x64, 0xD3,
    0x3F, 0x2C, 0x4E, 0xAA, 0x71, 0x48, 0x7A, 0xC9,
    0x17, 0xFF, 0x9E, 0x21, 0x36, 0x90, 0xC7, 0x82,
    0xA6, 0x46, 0xB5, 0x9A, 0x3A, 0x30, 0xB6, 0xAD,
    0xBC, 0x5D, 0x9A, 0x5B, 0xEE, 0x7F, 0x42, 0xEB,
    0x24, 0xF5, 0xDD, 0xF8, 0x7A, 0x77, 0x74, 0xE7,
    0x3D, 0x70, 0x7C, 0x94, 0xDC, 0x84, 0xAD, 0x95,
    0x1E, 0x6A, 0xF0, 0x37, 0x52, 0x7B, 0x11, 0xD4,
    0x62, 0xF5, 0x2B, 0xAA, 0xFC, 0x33, 0xBF, 0xAF,
    0x40, 0x56, 0x32, 0xD9, 0x0F, 0xD9, 0x5D, 0x97,
    0x8E, 0x4A, 0xD0, 0xA9, 0xA7, 0xFF, 0x20, 0xCA,
    0x38, 0xB3, 0x31, 0xAB, 0x24, 0x78, 0xA6, 0xBD,
    0x4C, 0x97, 0x9D, 0xBF, 0xB8, 0x3D, 0xB5, 0xBE,
    0x0C, 0x5D, 0x24, 0x30, 0x9F, 0xCA, 0x6D, 0xBD,
    0x29, 0x29, 0x7B, 0xB5, 0xC8, 0xF4, 0x4D, 0x8A,
    0x50, 0x14, 0x33, 0xDE, 0xF1, 0x78, 0x95, 0xAD,
    0xD6, 0xA6, 0xAA, 0x10, 0x96, 0xB3, 0xA6, 0xA7,
    0xF6, 0xCE, 0x0D, 0x12, 0xE3, 0x66, 0xA6, 0x94,
    0x0C, 0x3C, 0xFA, 0xF9, 0xF0, 0xF2, 0x10, 0xC9,
    0xF4, 0xDA, 0x06, 0xDB, 0xBF, 0x4E, 0x6F, 0xB3,
    0x93, 0x9C, 0x4E, 0x14, 0x1A, 0x39, 0xCF, 0xE6,
    0xC9, 0x2C, 0x06, 0x93, 0x86, 0xB9, 0x9E, 0xD7,
    0x9E, 0x08, 0xD1, 0xAE, 0x59, 0x5E, 0xE8, 0xF0,
    0xC0, 0x90, 0x8F, 0xBB, 0x7C, 0x8E, 0x2B, 0x8E,
    0x80, 0x69, 0x26, 0x80, 0x08, 0xF8, 0x49, 0xE7,
    0x7d, 0x2d, 0x49, 0x54, 0xd0, 0x80, 0x40, 0xC1,
    0xB6, 0xF2, 0xE6, 0x1B, 0x80, 0x5A, 0x36, 0xB4,
    0x42, 0xAE, 0x9C, 0x1C, 0xDA, 0x67, 0x05, 0xF6,
    0x9B, 0x75, 0xF7, 0xE0, 0x14, 0x8D, 0xB5, 0x80,
    0xBF, 0x54, 0x98, 0xB9, 0xB7, 0x30, 0x5A, 0x88,
    0x35, 0xD1, 0xFC, 0x97, 0x23, 0xD4, 0xC9, 0x88,
    0xE1, 0xD6, 0x31, 0x26, 0x5F, 0xBD, 0x40, 0x93,
    0xDC, 0x68, 0x08, 0x99, 0x97, 0xAE, 0xAF, 0x8C,
    0xC3, 0x0E, 0x01, 0x16, 0x0E, 0x32, 0x06, 0xBA,
    0xE0, 0x83, 0x01, 0xFA, 0xAB, 0x3E, 0x8F, 0xAC,
    0x5C, 0xD5, 0x9C, 0xB8, 0x46, 0x9C, 0x7D, 0x84,
    0xF1, 0xC6, 0xFE, 0x5C, 0x9D, 0xA5, 0x4F, 0xB7,
    0x58, 0xB5, 0xB3, 0xDD, 0x0E, 0x28, 0xF1, 0xB0,
    0x9A, 0xD6, 0x95, 0xBA, 0xA4, 0xC5, 0x32, 0x9C,
    0x5F, 0x30, 0x3B, 0x56, 0x96, 0x45, 0xF4, 0xA1,
    0x03, 0xBC, 0x6E, 0x8A, 0xEF, 0xBD, 0xFE, 0xF8,
    0x88, 0x17, 0x13, 0x3B, 0x2D, 0xBF, 0x06, 0xD6,
    0xF1, 0x94, 0x30, 0x21, 0xA1, 0x1C, 0x88, 0xA9,
    0xD0, 0xD2, 0x8E, 0xBC, 0x82, 0x2F, 0xE3, 0xB4,
    0x8C, 0xFA, 0x47, 0x9B, 0x83, 0xA5, 0x66, 0xD0,
    0x07, 0xBD, 0x9F, 0x26, 0xC8, 0x31, 0x0F, 0xB8,
    0xD7, 0xA1, 0x54, 0xB1, 0x5E, 0x89, 0xAE, 0x86,
    0xEF, 0x03, 0x95, 0x89, 0xB4, 0x71, 0x61, 0x9D,
    0x40, 0xBA, 0x97, 0xD5, 0x86, 0x4F, 0xCC, 0xD1,
};
#endif

#ifndef DATA_RATE_16

//! 8 PN codes for a data rate of 32kbps or 64kbps, and 48 PN codes for a
//! data rate of 16kbps
const UINT8 pn_code_table[] = 
{
    0x6A, 0xE7, 0x01, 0xEA, 0x03, 0xFD, 0x13, 0xD2, 
    0xDC, 0xC0, 0x6B, 0xB8, 0x2B, 0x09, 0xBB, 0xB2, 
    0xA3, 0x1E, 0xF2, 0xA4, 0x31, 0x32, 0x7A, 0xB3, 
    0x44, 0x83, 0x3B, 0xDD, 0x14, 0xCF, 0x8E, 0xC9, 
    0x35, 0x35, 0x4E, 0xC5, 0xF3, 0x52, 0x47, 0xB0, 
    0x7C, 0x23, 0x8A, 0xCE, 0x45, 0x5C, 0x54, 0xD7, 
    0x81, 0xAC, 0xFB, 0x83, 0x7A, 0x9A, 0x61, 0xAC, 
    0x3C, 0x12, 0x5F, 0x9C, 0x39, 0x98, 0xF6, 0x8A, 
};
#endif

///////////////////////////////////////////////////////////////////////////////
//
//  Function:    protocol_bind_init
//
//!  Description: Sets the checksum seed and PN code
//!
//!  Inputs:      Void
//!
//!  Returns:     Void
//!
///////////////////////////////////////////////////////////////////////////////

void protocol_bind_init()   // Bind Basic
{
    // load default checksum seed
    sys_params.network_id.seed = DEFAULT_CHECKSUM_SEED;

    // load pn_code define in application header file	
    radio_set_pn_code(&pn_code_table[(8 * sys_params.network_id.pn_code)]);
    

#ifdef RADIO_SLEEP_ENABLED
    radio_sleep();
#endif
}

///////////////////////////////////////////////////////////////////////////////
//
//  Function:    bind
//
//!  Description: Permorms a basic bind by setting the channel and pn code
//!
//!  Inputs:      - channel - Value of channel for binding
//!               - pn_code - PN code value for binding
//!
//!  Returns:     Void
//!
///////////////////////////////////////////////////////////////////////////////
void protocol_bind(UINT8 channel, UINT8 pn_code)   // Bind Basic
{
    sys_params.network_id.channel = channel;
    sys_params.network_id.pn_code = pn_code;

    radio_set_channel(channel);    
}


///////////////////////////////////////////////////////////////////////////////
//
//  Function:    protocol_reconnect
//
//!  Description: Stub for protocol_send_packet()
//!
//!  Inputs:      Void
//!
//!  Returns:     Void
//
///////////////////////////////////////////////////////////////////////////////
void protocol_reconnect(void)   // Bind Basic
{
}