//--------------------------------------------------------------------------
//! \file
//!
//!  Header file for the automatic bind routine
//!
//--------------------------------------------------------------------------
// $Archive: /WirelessUSB/LS/Firmware/LS DVK/PSoC/Radio/bind.h $
// $Modtime: 3/18/04 4:22p $
// $Revision: 1.4 $
//--------------------------------------------------------------------------
//
// Copyright 2003-2004, Cypress Semiconductor Corporation.
//
// This software is owned by Cypress Semiconductor Corporation (Cypress)
// and is protected by and subject to worldwide patent protection (United
// States and foreign), United States copyright laws and international 
// treaty provisions. Cypress hereby grants to licensee a personal, 
// non-exclusive, non-transferable license to copy, use, modify, create 
// derivative works of, and compile the Cypress Source Code and derivative 
// works for the sole purpose of creating custom software in support of 
// licensee product to be used only in conjunction with a Cypress integrated 
// circuit as specified in the applicable agreement. Any reproduction, 
// modification, translation, compilation, or representation of this 
// software except as specified above is prohibited without the express 
// written permission of Cypress.
//
// Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED, 
// WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Cypress reserves the right to make changes without further notice to the
// materials described herein. Cypress does not assume any liability arising
// out of the application or use of any product or circuit described herein.
// Cypress does not authorize its products for use as critical components in
// life-support systems where a malfunction or failure may reasonably be
// expected to result in significant injury to the user. The inclusion of
// Cypress product in a life-support systems application implies that the
// manufacturer assumes all risk of such use and in doing so indemnifies
// Cypress against all charges.
//
// Use may be limited by and subject to the applicable Cypress software
// license agreement.
//
//--------------------------------------------------------------------------

#ifndef _BIND_H_
#define _BIND_H_

//--------------------------------------
// Included files
//--------------------------------------

#include "ls_config.h"


//--------------------------------------
// API Definitions and Types
//--------------------------------------

//! Flag for no device being bound 
#define DISCONNECTED_STATE   0x01

//! Flag for a device that is bound
#define CONNECTED_STATE      0x02

// setup 2 way timeouts
//! Number of channels in a usable set, being a set where each channel 
//! is in range from 1 to 78 and are 6 channels apart from the next or 
//! previous channel (78/6 = 13) 
#define SUBSET_CHANNELS                 13   

//! Number of reconnects on original channel  
#define ORIGINAL_CHAN_RECONNECT_COUNT   0x05 

#ifdef DATA_RATE_16
    #define BIND_ACK_TIMEOUT    100
    #define CONNECT_ACK_TIMEOUT 100
#endif
#ifdef DATA_RATE_32
    #define BIND_ACK_TIMEOUT    75
    #define CONNECT_ACK_TIMEOUT 75
#endif
#ifdef DATA_RATE_64
    //! Timeout for binding  (Data Rate 16 = 100, 32 = 75, 64 = 60)
    #define BIND_ACK_TIMEOUT    60
    //! Timeout for connecting  (Data Rate 16 = 100, 32 = 75, 64 = 60)
    #define CONNECT_ACK_TIMEOUT 60
#endif

//! Number of loops through the channels during bind (max = 255)
#define BIND_TIMEOUT      SUBSET_CHANNELS * 10

//! Number of loops through the channels during reconnect (max = 255)   
#define CONNECT_TIMEOUT   SUBSET_CHANNELS * 19   


//! Number of times to wait for bind ack
#define BIND_MAX_TRANSMITS  0x04

//! Checksum seed for bind mode and verifying bind response packets
#define BIND_SEED           0x00

//! PN code for bind mode
#define BIND_PN_CODE        0x00

//! PIN used for bind mode
#define BIND_PIN            0x00

//! Base channel for bind mode
#define BIND_BASE_CHANNEL   0x00


//! For a timer delay when pinging
#define BRIDGE_PING_TIME    30


//--------------------------------------
// API Function Declarations
//--------------------------------------

extern void protocol_bind_init(void);
extern UINT8 protocol_bind(void);
extern UINT8 protocol_reconnect(void);
extern void init_channel(void);
extern void get_next_channel(void);

//! To tell whether the device is in a connected state or not
extern UINT8 bind_mode;

#endif  // _BIND_H_
