//--------------------------------------------------------------------------
//! \file
//!
//!  Include file which defines the gamepad packet and application
//!  prototypes
//!
//--------------------------------------------------------------------------
// $Archive: /WirelessUSB/LS/Firmware/LS DVK/PSoC/DVK Gamepad/gamepad.h $
// $Modtime: 2/12/04 12:33p $
// $Revision: 1.4 $
//--------------------------------------------------------------------------
//
// Copyright 2003, Cypress Semiconductor Corporation.
//
// This software is owned by Cypress Semiconductor Corporation (Cypress)
// and is protected by and subject to worldwide patent protection (United
// States and foreign), United States copyright laws and international 
// treaty provisions. Cypress hereby grants to licensee a personal, 
// non-exclusive, non-transferable license to copy, use, modify, create 
// derivative works of, and compile the Cypress Source Code and derivative 
// works for the sole purpose of creating custom software in support of 
// licensee product to be used only in conjunction with a Cypress integrated 
// circuit as specified in the applicable agreement. Any reproduction, 
// modification, translation, compilation, or representation of this 
// software except as specified above is prohibited without the express 
// written permission of Cypress.
//
// Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED, 
// WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Cypress reserves the right to make changes without further notice to the
// materials described herein. Cypress does not assume any liability arising
// out of the application or use of any product or circuit described herein.
// Cypress does not authorize its products for use as critical components in
// life-support systems where a malfunction or failure may reasonably be
// expected to result in significant injury to the user. The inclusion of
// Cypress product in a life-support systems application implies that the
// manufacturer assumes all risk of such use and in doing so indemnifies
// Cypress against all charges.
//
// Use may be limited by and subject to the applicable Cypress software
// license agreement.
//
//--------------------------------------------------------------------------

#ifndef _GAMEPAD_H_
#define _GAMEPAD_H_
//--------------------------------------
// Included files
//--------------------------------------

#include "cypdef.h"

//--------------------------------------
// API Definitions and Types
//--------------------------------------

//! Button 8 on keypad (column 1, row 0)
#define NORTH       0x0001

//! Button 6 on keypad (column 2, row 1)
#define EAST        0x0002

//! Button 2 on keypad (column 1, row 2)
#define SOUTH       0x0004

//! Button 4 on keypad (column 0, row 1)
#define WEST        0x0008

//! Button right thumb switch (right joystick button) (column 3, row 0)
#define RIGHT       0x0010

//! Button left thumb switch (left joystick button) (column 4, row 0)
#define LEFT        0x0020


//! To ping the board for no activity
#define NO_ACTIVITY     0x00

//! To ping the board for activity
#define ACTIVITY        0x01

//! To ping the board for null activity
#define NULL_ACTIVITY   0x02


//! For transmitting data packets related to any gamepad activity
typedef struct _APP_TX_PACKET
{
    //! X coordinate of the left joystick position
    UINT8   leftX;

    //! Y coordinate of the left joystick position
    UINT8   leftY;

    //! X coordinate of the right joystick position
    UINT8   rightX;

    //! Y coordinate of the right joystick position
    UINT8   rightY;

    //! Position of POT A
    UINT8   leftTrigger;

    //! Position of POT B
    UINT8   rightTrigger;

    //! For help in finding state of active buttons
    UINT8   hat;

    //! State of active buttons
    UINT8   buttons;
} APP_TX_PACKET;

//! Structure to keep prototype.h LS_RX_PACKET structure clean
typedef struct _APP_RX_PACKET
{

    //! Rumble data for receive packet
    UINT8   rumble;
} APP_RX_PACKET;

//--------------------------------------
// API Function Declarations
//--------------------------------------

#ifdef BACK_CHANNEL_DATA
UINT8 app_rx_process();
#endif // BACK_CHANNEL_DATA

void app_init(void);
static UINT16 scan_buttons(void);
UINT8 app_tx_process(APP_TX_PACKET *packet);

#endif  //_GAMEPAD_H_
