//--------------------------------------------------------------------------
//! \file
//!
//! Flash Header file
//!
//--------------------------------------------------------------------------
// $Archive: /WirelessUSB/WUSB Kits/CY4632 LS KBM RDK/DocSrc/CD_Root/Firmware/Source Code/RDK Mouse/flash.h $
// $Modtime: 10/01/04 1:18p $
// $Revision: 1.3 $
//--------------------------------------------------------------------------
//
// Copyright 2004, Cypress Semiconductor Corporation.
//
// This software is owned by Cypress Semiconductor Corporation (Cypress)
// and is protected by and subject to worldwide patent protection (United
// States and foreign), United States copyright laws and international 
// treaty provisions. Cypress hereby grants to licensee a personal, 
// non-exclusive, non-transferable license to copy, use, modify, create 
// derivative works of, and compile the Cypress Source Code and derivative 
// works for the sole purpose of creating custom software in support of 
// licensee product to be used only in conjunction with a Cypress integrated 
// circuit as specified in the applicable agreement. Any reproduction, 
// modification, translation, compilation, or representation of this 
// software except as specified above is prohibited without the express 
// written permission of Cypress.
//
// Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED, 
// WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Cypress reserves the right to make changes without further notice to the
// materials described herein. Cypress does not assume any liability arising
// out of the application or use of any product or circuit described herein.
// Cypress does not authorize its products for use as critical components in
// life-support systems where a malfunction or failure may reasonably be
// expected to result in significant injury to the user. The inclusion of
// Cypress product in a life-support systems application implies that the
// manufacturer assumes all risk of such use and in doing so indemnifies
// Cypress against all charges.
//
// Use may be limited by and subject to the applicable Cypress software
// license agreement.
//
//--------------------------------------------------------------------------

#ifndef _FLASH_H_
#define _FLASH_H_

//--------------------------------------
// API Function Declarations
//--------------------------------------

///////////////////////////////////////////////////////////////////////////////
//
//  Function:    flash_read_lite
//
//!  Description:  Reads a specified flash block to a buffer in RAM.                         
//!                
//!                BlockID is converted to absolute address and then ROMX                                             
//!                command is used to read the data from flash into the 
//!                specified buffer. (See flash.asm for more info)                                                           
//!                
//!                Uses SSC storage at FBh and FDh                                                     
//!                
//!  Inputs:       
//!                - BYTE  - Flash block ID                                                        
//!                - void* - Destination RAM location                                              
//!                - BYTE  - Number of bytes to read
//!                
//!  Returns:      
//!                - Data read is returned at specified RAM location.
//!
///////////////////////////////////////////////////////////////////////////////
extern void flash_read_lite(BYTE nvr_block, void *data, BYTE len);

///////////////////////////////////////////////////////////////////////////////
//
//  Function:    flash_write_lite
//
//!  Description: Writes 64 bytes of data to the flash at the specified blockId.           
//!               Regardless of the size of the buffer, this routine always      
//!               writes 64 bytes of data. If the buffer is less than 64 bytes,         
//!               then the next 64-N bytes of data will be written to fill the 
//!               rest of flash block data.  (See flash.asm for more info) 
//!
//!               1 ) Compute the pulsewidths                                              
//!               2 ) Erase the specified block                                            
//!               3 ) Program the specified block                                          
//!
//!               Uses RAM locations 0xFB and 0xFD
//!
//!  Assumptions:                                                                
//!               Single block Write                                                       
//!               CPU clock is 12MHz                                                       
//!               Temperature is defined to be 32 degees celcius                           
//!
//!  Inputs:      
//!               - BYTE  - Flash block ID                                                   
//!               - void* - Source RAM location                                              
//!
//!  Returns:     SSC_RETURNCODE
//!
///////////////////////////////////////////////////////////////////////////////
extern BYTE flash_write_lite(BYTE nvr_block, void *data);


#endif   // _FLASH_H_


