//--------------------------------------------------------------------------
//
//  Include file which defines the keypad packet and application
//  prototypes
//
//--------------------------------------------------------------------------
// $Archive: /WirelessUSB/LS/Firmware/LS DVK/PSoC/DVK Keypad/keypad.h $
// $Modtime: 2/12/04 12:33p $
// $Revision: 1.4 $
//--------------------------------------------------------------------------
//
// Copyright 2003, Cypress Semiconductor Corporation.
//
// This software is owned by Cypress Semiconductor Corporation (Cypress)
// and is protected by and subject to worldwide patent protection (United
// States and foreign), United States copyright laws and international 
// treaty provisions. Cypress hereby grants to licensee a personal, 
// non-exclusive, non-transferable license to copy, use, modify, create 
// derivative works of, and compile the Cypress Source Code and derivative 
// works for the sole purpose of creating custom software in support of 
// licensee product to be used only in conjunction with a Cypress integrated 
// circuit as specified in the applicable agreement. Any reproduction, 
// modification, translation, compilation, or representation of this 
// software except as specified above is prohibited without the express 
// written permission of Cypress.
//
// Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED, 
// WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Cypress reserves the right to make changes without further notice to the
// materials described herein. Cypress does not assume any liability arising
// out of the application or use of any product or circuit described herein.
// Cypress does not authorize its products for use as critical components in
// life-support systems where a malfunction or failure may reasonably be
// expected to result in significant injury to the user. The inclusion of
// Cypress product in a life-support systems application implies that the
// manufacturer assumes all risk of such use and in doing so indemnifies
// Cypress against all charges.
//
// Use may be limited by and subject to the applicable Cypress software
// license agreement.
//
//--------------------------------------------------------------------------

#ifndef _KEYPAD_H_
#define _KEYPAD_H_


//--------------------------------------
// Included files
//--------------------------------------
#include "cypdef.h"


//--------------------------------------
// API Definitions and Types
//--------------------------------------

//! Used to generate the transmit report packet
#define REPORT_KEYCODES      0x01

//! For creation of the key queue array, and to check if the queue is full 
//! when accessing the queue
#define KEY_QUEUE_LEN        0x08


//! To ping the board for no activity
#define NO_ACTIVITY     0

//! To ping the board for activity
#define ACTIVITY        1

//! To ping the board for null activity
#define NULL_ACTIVITY   2

//! To check whether the key is up or down
typedef enum _KEY_STATE
{
    //! For setting and checking if the key state is up
    KEY_STATE_UP    = 1,

    //! For setting and checking if the key state is down
    KEY_STATE_DOWN  = 0
} KEY_STATE;

//! Attributes of the actual key, which key and what state it is in
typedef struct _KEY
{
    //! Key state attribute of the key, whether being up or down
    KEY_STATE   state;

    //! Index attribute of the key, to know what key it is
    UINT8       index;
} KEY;

//! For transmitting data packets related to any mouse activity
typedef struct _APP_TX_PACKET
{
    //! For shift, ctrl, and alt keys.  (Not used with platform board)
    UINT8   modifiers;

    //! For USB information.  (Not used with platform board)
    UINT8   reserved;

    //! To keep track of what keys have a down state
    UINT8   keyCode[REPORT_KEYCODES];
} APP_TX_PACKET;

//! Key queue structure with queue attributes
typedef struct _KEY_FIFO
{
    //! Number of keys that have been put in the queue
    UINT8   in;

    //! Number of keys that have been removed from the queue
    UINT8   out;

    //! Number of keys in the queue
    UINT8   count;

    //! Queue array for the keys
    KEY     key[KEY_QUEUE_LEN];
} KEY_FIFO;


//--------------------------------------
// API Function Declarations
//--------------------------------------

UINT8 app_tx_process(APP_TX_PACKET *packet);
void app_init(void);
void scan_keys(void);

#endif  // _KEYPAD_H_
