	.module timer.c
	.area text(rom, con, rel)
	.dbfile ./timer.c
	.dbfunc e tick_isr _tick_isr fV
_tick_isr::
	.dbline -1
	.dbline 129
; //--------------------------------------------------------------------------
; // $Archive: /WirelessUSB/WUSB Kits/CY4632 LS KBM RDK/DocSrc/CD_Root/Firmware/Source Code/RDK Keypad/timer.c $
; // $Modtime: 9/29/04 2:19p $
; // $Revision: 1.3 $
; //--------------------------------------------------------------------------
; //
; // Copyright 2003-2004, Cypress Semiconductor Corporation.
; //
; // This software is owned by Cypress Semiconductor Corporation (Cypress)
; // and is protected by and subject to worldwide patent protection (United
; // States and foreign), United States copyright laws and international 
; // treaty provisions. Cypress hereby grants to licensee a personal, 
; // non-exclusive, non-transferable license to copy, use, modify, create 
; // derivative works of, and compile the Cypress Source Code and derivative 
; // works for the sole purpose of creating custom software in support of 
; // licensee product to be used only in conjunction with a Cypress integrated 
; // circuit as specified in the applicable agreement. Any reproduction, 
; // modification, translation, compilation, or representation of this 
; // software except as specified above is prohibited without the express 
; // written permission of Cypress.
; //
; // Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED, 
; // WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
; // WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
; // Cypress reserves the right to make changes without further notice to the
; // materials described herein. Cypress does not assume any liability arising
; // out of the application or use of any product or circuit described herein.
; // Cypress does not authorize its products for use as critical components in
; // life-support systems where a malfunction or failure may reasonably be
; // expected to result in significant injury to the user. The inclusion of
; // Cypress product in a life-support systems application implies that the
; // manufacturer assumes all risk of such use and in doing so indemnifies
; // Cypress against all charges.
; //
; // Use may be limited by and subject to the applicable Cypress software
; // license agreement.
; //
; //--------------------------------------------------------------------------
; 
; 
; //--------------------------------------------------------------------------
; //! \file
; //!
; //! This module provides a timer interface for general purpose timing
; //! requirements.
; //!
; //! Tick requires one 8 bit timer block named "Tick" and configured with the 
; //! following parameters:
; //!
; //!   Clock:            CPU_32_KHz
; //!
; //!   Capture:          Low
; //!
; //!   Output:           Void
; //!
; //!   Period:           32
; //!
; //!   CompareValue:     0
; //!
; //!   CompareType:      Less Than Or Equal
; //!
; //!   InterruptType:    Terminal Count
; //!
; //!   InterruptAPI:     Enable
; //!
; //!   IntDispatchMode:  ActiveStatus
; //!
; //! This will provide a 1ms tick to be used for millisecond resolution 
; //! delays.  If the timer calibration feature is enabled, then the period 
; //! will be automatically set by the algorithm to meet 1ms timing.
; //!
; //! tickint.asm should have the following code:
; //!
; //! TickINT:
; //!   ljmp _Tick
; //!   reti
; //!
; //! The timer delay routines use cycle counting for delaying a specific
; //! amount of time.  These routines are calibrated for a 12MHz clock
; //! frequency.  The delay is computed by the following algorithm and is in
; //! clock cycles:
; //!
; //! delay = 20 * ( A + 2 )
; //!
; //! Most calls to these routines are executed with an lcall instruction 
; //! which is 13 clock cycles.  If the call is made with the call instruction
; //! it will be 2 cycles shorter, i.e. call = 11 clock cycles.
; //--------------------------------------------------------------------------
; 
; 
; //--------------------------------------
; // Included files
; //--------------------------------------
; 
; #include "tick.h"
; #include "ls_config.h"
; 
; //--------------------------------------
; // Local Function Declarations
; //--------------------------------------
; 
; #pragma interrupt_handler tick_isr
; void tick_isr(void);
; 
; static void delay_usec_loop(void);
; 
; 
; //--------------------------------------
; // Local Definitions
; //--------------------------------------
; 
; //! System tick, updated every Tick ISR ( See Tick_ISR in tickint.asm and 
; //! tick_ISR() )
; TIME_STAMP tick;
; 
; 
; ///////////////////////////////////////////////////////////////////////////////
; //
; //   Function:    tick_isr
; //
; //!  Description: Interrupt service routine for the timer to tick
; //!
; //!  Inputs:      Void
; //!
; //!  Returns:     Void
; //!
; ///////////////////////////////////////////////////////////////////////////////
; void tick_isr(void)
; {
	.dbline 130
;     tick++;
	inc [_tick+1]
	adc [_tick],0
	.dbline -2
	.dbline 131
; }
L1:
	.dbline 0 ; func end
	reti
	.dbend
	.dbfunc e timer_init _timer_init fV
_timer_init::
	.dbline -1
	.dbline 147
; 
; 
; ///////////////////////////////////////////////////////////////////////////////
; //
; //   Function:    timer_init
; //
; //!  Description: Initialize the timer by setting the 32KHz clock parameters
; //!                     during calibration, and actually starting the timer.
; //!
; //!  Inputs:      Void
; //!
; //!  Returns:     Void
; //!
; ///////////////////////////////////////////////////////////////////////////////
; void timer_init()
; {
	.dbline 148
;     TIMER_CALIBRATE_TIMER(FALSE);
	mov A,0
	push A
	xcall _timer_calibrate_timer
	add SP,-1
	.dbline 149
;     timer_timer_on();
	xcall _timer_timer_on
	.dbline -2
	.dbline 150
; }
L2:
	.dbline 0 ; func end
	ret
	.dbend
	.dbfunc e timer_timer_on _timer_timer_on fV
_timer_timer_on::
	.dbline -1
	.dbline 166
; 
; 
; ///////////////////////////////////////////////////////////////////////////////
; //
; //   Function:    timer_timer_on
; //
; //!  Description: Resets the tick count,  starts the timer, and enabled the
; //!                     timer interrupt
; //!
; //!  Inputs:      Void
; //!
; //!  Returns:     Void
; //!
; ///////////////////////////////////////////////////////////////////////////////
; void timer_timer_on()
; {
	.dbline 167
;     tick = 0;
	mov [_tick+1],0
	mov [_tick],0
	.dbline 168
;     Tick_Start();
	push X
	xcall _Tick_Start
	.dbline 169
;     Tick_EnableInt();
	xcall _Tick_EnableInt
	pop X
	.dbline -2
	.dbline 170
; }
L3:
	.dbline 0 ; func end
	ret
	.dbend
	.dbfunc e timer_timer_off _timer_timer_off fV
_timer_timer_off::
	.dbline -1
	.dbline 185
; 
; 
; ///////////////////////////////////////////////////////////////////////////////
; //
; //   Function:    timer_timer_off
; //
; //!  Description: Stops the timer and disables the timer interrupts
; //!
; //!  Inputs:      Void
; //!
; //!  Returns:     Void
; //!
; ///////////////////////////////////////////////////////////////////////////////
; void timer_timer_off()
; {
	.dbline 186
;     Tick_Stop();
	push X
	xcall _Tick_Stop
	.dbline 187
;     Tick_DisableInt();
	xcall _Tick_DisableInt
	pop X
	.dbline -2
	.dbline 188
; }
L4:
	.dbline 0 ; func end
	ret
	.dbend
	.dbfunc e timer_delay_10_usec _timer_delay_10_usec fV
_timer_delay_10_usec::
	.dbline -1
	.dbline 218
; 
; 
; //--------------------------------------------------------------------------
; // The timer delay routines use cycle counting for delaying a specific
; // amount of time.  These routines are calibrated for a 12MHz clock
; // frequency.  The delay is computed by the following algorithm and is in
; // clock cycles:
; //
; // delay = 20 * ( A + 2 )
; //
; // Most calls to these routines are executed with an lcall instruction 
; // which is 13 clock cycles.  If the call is made with the call instruction
; // it will be 2 cycles shorter, i.e. call = 11 clock cycles.
; //
; //--------------------------------------------------------------------------
; 
; ///////////////////////////////////////////////////////////////////////////////
; //
; //   Function:    timer_delay_10_usec
; //
; //!  Description: To delay 10 Usec by running through the cycles for these
; //!                     instructions and 4 iterations of the delay_msec_loop routine
; //!
; //!  Inputs:      Void
; //!
; //!  Returns:     Void
; //!
; ///////////////////////////////////////////////////////////////////////////////
; void timer_delay_10_usec(void)
; {
	.dbline 220
;                                    // [13] cycles for lcall
;     asm("mov A, 4");               // [4]  cycles
		mov A, 4

	.dbline 221
;     asm("jmp _delay_usec_loop");   // [5]  cycles
		jmp _delay_usec_loop

	.dbline -2
	.dbline 222
; }
L5:
	.dbline 0 ; func end
	ret
	.dbend
	.dbfunc e timer_delay_50_usec _timer_delay_50_usec fV
_timer_delay_50_usec::
	.dbline -1
	.dbline 238
; 
; 
; ///////////////////////////////////////////////////////////////////////////////
; //
; //   Function:    timer_delay_50_usec
; //
; //!  Description: To delay 50 Usec by running through the cycles for these
; //!                     instructions and 28 iterations of the delay_msec_loop routine
; //!
; //!  Inputs:      Void
; //!
; //!  Returns:     Void
; //!
; ///////////////////////////////////////////////////////////////////////////////
; void timer_delay_50_usec(void)
; {
	.dbline 240
;                                    // [13] cycles for lcall
;     asm("mov A, 28");              // [4]  cycles
		mov A, 28

	.dbline 241
;     asm("jmp _delay_usec_loop");   // [5]  cycles
		jmp _delay_usec_loop

	.dbline -2
	.dbline 242
; }
L6:
	.dbline 0 ; func end
	ret
	.dbend
	.dbfunc e timer_delay_100_usec _timer_delay_100_usec fV
_timer_delay_100_usec::
	.dbline -1
	.dbline 258
; 
; 
; ///////////////////////////////////////////////////////////////////////////////
; //
; //   Function:    timer_delay_100_usec
; //
; //!  Description: To delay 10 Usec by running through the cycles for these
; //!               instructions and 58 iterations of the delay_msec_loop routine
; //!
; //!  Inputs:      Void
; //!
; //!  Returns:     Void
; //!
; ///////////////////////////////////////////////////////////////////////////////
; void timer_delay_100_usec(void)
; {
	.dbline 260
;                                    // [13] cycles for lcall
;     asm("mov A, 58");              // [4]  cycles
		mov A, 58

	.dbline 261
;     asm("jmp _delay_usec_loop");   // [5]  cycles
		jmp _delay_usec_loop

	.dbline -2
	.dbline 262
; }
L7:
	.dbline 0 ; func end
	ret
	.dbend
	.dbfunc s delay_usec_loop _delay_usec_loop fV
_delay_usec_loop:
	.dbline -1
	.dbline 277
; 
; 
; ///////////////////////////////////////////////////////////////////////////////
; //
; //   Function:    delay_usec_loop
; //
; //!  Description: The main delay loop for the specific Usec delay routines
; //!
; //!  Inputs:      Void
; //!
; //!  Returns:     Void
; //!
; ///////////////////////////////////////////////////////////////////////////////
; static void delay_usec_loop(void)
; {
	.dbline 278
;     asm("and  A, FFh");            // [4] cycles
		and  A, FFh

	.dbline 279
;     asm("ljmp fwd");               // [7] cycles
		ljmp fwd

	.dbline 280
;     asm("fwd:");                   // [0] cycles
		fwd:

	.dbline 281
;     asm("dec  A");                 // [4] cycles
		dec  A

	.dbline 282
;     asm("jnz  _delay_usec_loop");  // [5] cycles
		jnz  _delay_usec_loop

	.dbline 283
;     asm("cmp  A, 0");              // [5] cycles
		cmp  A, 0

	.dbline 284
;     asm("cmp  A, 0");              // [5] cycles
		cmp  A, 0

	.dbline -2
	.dbline 286
;                                    // [8] cycles for return
; }
L8:
	.dbline 0 ; func end
	ret
	.dbend
	.dbfunc e timer_delay_msec _timer_delay_msec fV
;             cv -> X+0
; num_milliseconds -> X-5
_timer_delay_msec::
	.dbline -1
	push X
	mov X,SP
	add SP,2
	.dbline 306
; 
; 
; ///////////////////////////////////////////////////////////////////////////////
; //
; //   Function:    timer_delay_msec
; //
; //!  Description: Delays the number of milliseconds specified by the 
; //!               num_milliseconds parameter. First it takes a time stamp and
; //!               adds the number of milliseconds to delay (num_milliseconds).
; //!               Then it enters a while loop where each iteration puts the  
; //!               PSoC in sleep mode and is equivalent to one millisecond 
; //!
; //!  Inputs:      
; //!               - num_milliseconds - number of milliseconds to delay
; //!
; //!  Returns:     Void
; //!
; ///////////////////////////////////////////////////////////////////////////////
; void timer_delay_msec(UINT16 num_milliseconds)
; {
	.dbline 309
;     TIME_STAMP cv;
;     
;     cv = tick + MS_TO_TICK(num_milliseconds);
	mov A,[_tick+1]
	add A,[X-4]
	mov [X+1],A
	mov A,[_tick]
	adc A,[X-5]
	mov [X+0],A
	xjmp L11
L10:
	.dbline 312
	.dbline 313
	or REG[0xff],8
	.dbline 314
		nop

	.dbline 315
		nop

	.dbline 316
L11:
	.dbline 311
;     
;     while( tick <= cv )
	mov A,[X+1]
	sub A,[_tick+1]
	mov A,[X+0]
	sbb A,[_tick]
	jnc L10
X0:
	.dbline -2
	.dbline 317
;     {
;         M8C_Sleep;
;         asm("nop");
;         asm("nop");
;     }
; }
L9:
	add SP,-2
	pop X
	.dbline 0 ; func end
	ret
	.dbsym l cv 0 s
	.dbsym l num_milliseconds -5 s
	.dbend
	.dbfunc e timer_get_time_stamp _timer_get_time_stamp fs
_timer_get_time_stamp::
	.dbline -1
	.dbline 333
; 
; 
; ///////////////////////////////////////////////////////////////////////////////
; //
; //   Function:    timer_get_time_stamp
; //
; //!  Description: Returns the number of ticks the timer has gone through
; //!
; //!  Inputs:      Void
; //!
; //!  Returns:     
; //!               - tick - Number of ticks
; //!
; ///////////////////////////////////////////////////////////////////////////////
; TIME_STAMP timer_get_time_stamp(void)
; {
	.dbline 334
;     return tick;
	mov [__r1],[_tick+1]
	mov [__r0],[_tick]
	.dbline -2
L13:
	.dbline 0 ; func end
	ret
	.dbend
	.dbfunc e timer_delay_incremental _timer_delay_incremental fV
;          delta -> X+0
;       delay_ms -> X-7
; from_timestamp -> X-5
_timer_delay_incremental::
	.dbline -1
	push X
	mov X,SP
	add SP,2
	.dbline 354
; }
; 
; 
; ///////////////////////////////////////////////////////////////////////////////
; //
; //   Function:    timer_delay_incremental 
; //
; //!  Description: To delay the timer for a specific type of device (mouse, 
; //!                     keypad, gamepad, etc.)
; //!
; //!  Inputs:      
; //!               - from_timestamp - timestamp to help figure the correct delta
; //!                     for the delay
; //!               - delay_ms - The base amount of time to figure delta
; //!
; //!  Returns:     Void
; //!
; ///////////////////////////////////////////////////////////////////////////////
; void timer_delay_incremental( TIME_STAMP from_timestamp, UINT16 delay_ms )
; {
	.dbline 359
; 
;     UINT16 delta;
;     
;     
;     delta = TICK_TO_MS( MS_TO_TICK(delay_ms) - (tick - from_timestamp) );
	mov A,[_tick+1]
	sub A,[X-4]
	mov [__r1],A
	mov A,[_tick]
	sbb A,[X-5]
	mov [__r0],A
	mov A,[X-6]
	sub A,[__r1]
	mov [X+1],A
	mov A,[X-7]
	sbb A,[__r0]
	mov [X+0],A
	.dbline 361
;     
;     if( (INT16)delta > 0 )
	mov A,0
	sub A,[X+1]
	mov A,[X+0]
	xor A,-128
	mov [__rX],A
	mov A,(0 ^ 0x80)
	sbb A,[__rX]
	jnc L15
X1:
	.dbline 362
;     {
	.dbline 363
;         timer_delay_msec( delta );
	mov A,[X+0]
	push A
	mov A,[X+1]
	push A
	xcall _timer_delay_msec
	add SP,-2
	.dbline 364
;     }
	xjmp L16
L15:
	.dbline 366
	.dbline 367
	mov [X+1],0
	mov [X+0],0
	.dbline 368
L16:
	.dbline -2
	.dbline 369
;     else
;     {
;         delta = 0; // breakpoint location for bench test
;     }
; }
L14:
	add SP,-2
	pop X
	.dbline 0 ; func end
	ret
	.dbsym l delta 0 s
	.dbsym l delay_ms -7 s
	.dbsym l from_timestamp -5 s
	.dbend
	.dbfunc e timer_time_elapsed _timer_time_elapsed fc
; elapsed_time_ms -> X-7
; from_timestamp -> X-5
_timer_time_elapsed::
	.dbline -1
	push X
	mov X,SP
	.dbline 392
; 
; 
; ///////////////////////////////////////////////////////////////////////////////
; //
; //   Function:    timer_time_elapsed
; //
; //!  Description: Another kind of delay that is generally called within a
; //!                     conditional statement  
; //!               (i.e. while(!timer_time_elapsed(current_time, MFG_RX_TIMEOUT) ); ) 
; //!
; //!  Inputs:      
; //!               - from_timestamp - number of milliseconds to start with
; //!               - elapsed_time_ms - number of milliseconds needed to reach
; //!                     the elapsed time
; //!               
; //!
; //!  Returns:     
; //!               - True - If elapsed time has been reached 
; //!               - False - If elapsed time has NOT been reached
; //!
; ///////////////////////////////////////////////////////////////////////////////
; BOOL timer_time_elapsed(TIME_STAMP from_timestamp, UINT16 elapsed_time_ms)
; {
	.dbline 393
;     if( tick > (from_timestamp + MS_TO_TICK(elapsed_time_ms)) )
	mov A,[X-4]
	add A,[X-6]
	mov [__r1],A
	mov A,[X-5]
	adc A,[X-7]
	mov [__r0],A
	mov A,[__r1]
	sub A,[_tick+1]
	mov A,[__r0]
	sbb A,[_tick]
	jnc L18
X2:
	.dbline 394
;     {
	.dbline 395
;         return TRUE;
	mov A,1
	xjmp L17
L18:
	.dbline 398
;     }
;     else
;     {
	.dbline 399
;         return FALSE;
	mov A,0
	.dbline -2
L17:
	pop X
	.dbline 0 ; func end
	ret
	.dbsym l elapsed_time_ms -7 s
	.dbsym l from_timestamp -5 s
	.dbend
	.dbfunc e timer_calibrate_timer _timer_calibrate_timer fV
;     tick_count -> X+1
;              i -> X+0
;   set_timer_on -> X-4
_timer_calibrate_timer::
	.dbline -1
	push X
	mov X,SP
	add SP,2
	.dbline 419
;     }
; }
; 
; #ifdef TIMER_CAL
; ///////////////////////////////////////////////////////////////////////////////
; //
; //   Function:    timer_calibrate_timer
; //
; //!  Description: To calibrate the timer by setting the clock period and
; //!               parameters if necessary
; //!
; //!  Inputs:      
; //!               - set_timer_on - For restarting the timer or setting the
; //!               parameters
; //!
; //!  Returns:     Void
; //!
; ///////////////////////////////////////////////////////////////////////////////
; void timer_calibrate_timer(BOOL set_timer_on)
; {
	.dbline 423
;     UINT8 tick_count;
;     UINT8 i;
; 
;     Tick_Stop();
	push X
	xcall _Tick_Stop
	.dbline 425
; 
;     Tick_DisableInt();
	xcall _Tick_DisableInt
	pop X
	.dbline 428
; 
;     // Set 32KHz Clock parameters
;     if( !set_timer_on )
	cmp [X-4],0
	jnz L21
	.dbline 429
;     {
	.dbline 434
;         // Force Low Power bit, Maximum Bias, Maximum trim
;         //   1) Goto Bank 1
;         //   2) Set Trim value in ILO_TR (Force low power bit)
;         //   3) Goto Bank 0
;         asm("or  F, 10h");            
		or  F, 10h

	.dbline 435
;         asm("mov reg[E9h], 97h");     
		mov reg[E9h], 97h

	.dbline 436
;         asm("and F, EFh");            
		and F, EFh

	.dbline 437
;     }
L21:
	.dbline 440
; 
;     // Set timer to start at maximum period
;     Tick_WritePeriod(255);
	push X
	mov A,-1
	xcall _Tick_WritePeriod
	.dbline 444
; 
;     // This section of code has been cycle counted from Tick_Start
;     // to Tick_bReadTimer to be 12118 cycles, or 1.010ms @ 12MHz.
;     Tick_Start();
	xcall _Tick_Start
	pop X
	.dbline 446
; 
;     for(i=0; i < 82; i++)
	mov [X+0],0
	xjmp L26
L23:
	.dbline 447
	.dbline 448
		lcall _timer_delay_10_usec

	.dbline 449
L24:
	.dbline 446
	inc [X+0]
L26:
	.dbline 446
	cmp [X+0],82
	jc L23
X3:
	.dbline 451
	push X
	xcall _Tick_bReadTimer
	pop X
	mov [X+1],A
	.dbline 453
	push X
	xcall _Tick_Stop
	pop X
	.dbline 456
	mov A,-1
	sub A,[X+1]
	push X
	xcall _Tick_WritePeriod
	pop X
	.dbline 459
	cmp [X-4],0
	jz L27
	.dbline 460
	.dbline 461
	push X
	xcall _Tick_Start
	.dbline 462
	xcall _Tick_EnableInt
	pop X
	.dbline 463
L27:
	.dbline -2
	.dbline 464
;     {
;         asm("lcall _timer_delay_10_usec");
;     }
; 
;     tick_count = Tick_bReadTimer();
; 
;     Tick_Stop();
; 
;     // Set timer period to be the number of counts expired
;     Tick_WritePeriod(255 - tick_count);
; 
;     // Restart timer if necessary
;     if( set_timer_on )
;     {
;         Tick_Start();
;         Tick_EnableInt();
;     }
; }
L20:
	add SP,-2
	pop X
	.dbline 0 ; func end
	ret
	.dbsym l tick_count 1 c
	.dbsym l i 0 c
	.dbsym l set_timer_on -4 c
	.dbend
	.area bss(ram, con, rel)
	.dbfile ./timer.c
_tick::
	.blkb 2
	.dbsym e tick _tick s
