//--------------------------------------------------------------------------
//! \file
//!
//! Interrupt Service Routines
//!
//--------------------------------------------------------------------------
// $Archive: /WirelessUSB/LS/Firmware/LS DVK/PSoC/Common/isr.c $
// $Modtime: 2/12/04 12:33p $
// $Revision: 1.3 $
//--------------------------------------------------------------------------
//
// Copyright 2003-2004, Cypress Semiconductor Corporation.
//
// This software is owned by Cypress Semiconductor Corporation (Cypress)
// and is protected by and subject to worldwide patent protection (United
// States and foreign), United States copyright laws and international 
// treaty provisions. Cypress hereby grants to licensee a personal, 
// non-exclusive, non-transferable license to copy, use, modify, create 
// derivative works of, and compile the Cypress Source Code and derivative 
// works for the sole purpose of creating custom software in support of 
// licensee product to be used only in conjunction with a Cypress integrated 
// circuit as specified in the applicable agreement. Any reproduction, 
// modification, translation, compilation, or representation of this 
// software except as specified above is prohibited without the express 
// written permission of Cypress.
//
// Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED, 
// WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Cypress reserves the right to make changes without further notice to the
// materials described herein. Cypress does not assume any liability arising
// out of the application or use of any product or circuit described herein.
// Cypress does not authorize its products for use as critical components in
// life-support systems where a malfunction or failure may reasonably be
// expected to result in significant injury to the user. The inclusion of
// Cypress product in a life-support systems application implies that the
// manufacturer assumes all risk of such use and in doing so indemnifies
// Cypress against all charges.
//
// Use may be limited by and subject to the applicable Cypress software
// license agreement.
//
//--------------------------------------------------------------------------

//--------------------------------------
// Included files
//--------------------------------------

#include "radio.h"

///////////////////////////////////////////////////////////////////////////////
//
//  Function:    isr_gpio
//
//!  Description: Interrupt service routine for general purpose I/O (GPIO).  It
//!               It first checks for an interrupt request through the GPIO 
//!               port.  If there is a request gpio_isr_redirector() is used to
//!               call the interrupt handler ( radio_rx_isr() ) 
//!
//!  Inputs:      Void
//!
//!  Returns:     Void
//!
///////////////////////////////////////////////////////////////////////////////
void isr_gpio(void)
{
#ifdef RADIO_NON_BLOCKING_CALLS
    if( GPIO_ISR_RADIO_IE_PORT & GPIO_ISR_RADIO_INT )
    {
        gpio_isr_redirector(radio_rx_isr);
    }
#endif // RADIO_NON_BLOCKING_CALLS
}


///////////////////////////////////////////////////////////////////////////////
//
//  Function:    isr_init
//
//!  Description: Disables general purpose I/O (GPIO) interrupts via the 
//!               interrupt enable registers.  Enables GPIO and sleep interrupt
//!               mask and the global interrupt
//!
//!  Inputs:      Void
//!
//!  Returns:     Void
//!
///////////////////////////////////////////////////////////////////////////////
void isr_init(void)
{
    // Disable GPIO Interrupts
    PRT0IE = 0;
    PRT1IE = 0;
    PRT2IE = 0;

    // Enable GPIO and Sleep interrupt mask
    M8C_EnableIntMask(INT_MSK0, INT_MSK0_GPIO);

     // Enable global interrupt
    M8C_EnableGInt;
}

