
//--------------------------------------------------------------------------
//! \file
//!
//! This module implements the manufacturing test mode.
//!
//--------------------------------------------------------------------------
// $Archive: $
// $Modtime: $
// $Revision: 1.4 $
//--------------------------------------------------------------------------
//
// Copyright 2004, Cypress Semiconductor Corporation.
//
// This software is owned by Cypress Semiconductor Corporation (Cypress)
// and is protected by and subject to worldwide patent protection (United
// States and foreign), United States copyright laws and international 
// treaty provisions. Cypress hereby grants to licensee a personal, 
// non-exclusive, non-transferable license to copy, use, modify, create 
// derivative works of, and compile the Cypress Source Code and derivative 
// works for the sole purpose of creating custom software in support of 
// licensee product to be used only in conjunction with a Cypress integrated 
// circuit as specified in the applicable agreement. Any reproduction, 
// modification, translation, compilation, or representation of this 
// software except as specified above is prohibited without the express 
// written permission of Cypress.
//
// Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED, 
// WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Cypress reserves the right to make changes without further notice to the
// materials described herein. Cypress does not assume any liability arising
// out of the application or use of any product or circuit described herein.
// Cypress does not authorize its products for use as critical components in
// life-support systems where a malfunction or failure may reasonably be
// expected to result in significant injury to the user. The inclusion of
// Cypress product in a life-support systems application implies that the
// manufacturer assumes all risk of such use and in doing so indemnifies
// Cypress against all charges.
//
// Use may be limited by and subject to the applicable Cypress software
// license agreement.
//
//--------------------------------------------------------------------------


#ifndef MFGTEST_H
#define MFGTEST_H

//--------------------------------------
// Included files
//--------------------------------------

#include "ls_config.h"


//--------------------------------------
// API Definitions and Types
//--------------------------------------

//! PN code for manufacturing test mode
#define MFG_PN_CODE               0x01

//! Channel for manufacturing test mode
#define MFG_CHANNEL               0x01

//! Low threshold for manufacturing test mode
#define MFG_THRESHOLD_LO          0x01

//! Hi threshold for manufacturing test mode
#define MFG_THRESHOLD_HI          0x1F

//! Power level bias for manufacturing test mode
#define MFG_PA_BIAS               0x07

//! End of frame for manufacturing test mode
#define MFG_EOF_TIMEOUT           0x07



//! Timeout for receive packet
#define MFG_RX_TIMEOUT            100     // in milliseconds


//! Number of manufacturing test packets
#define MFG_NUM_PACKETS           200

//! Manufacturing test packet size without header and checksum
#define MFG_PACKET_PAYLOAD_SIZE   0x03

//! Delay time (msec) before transmitting data
#define MFG_PRE_TX_DELAY          50

//! Delay time (msec) after transmitting data
#define MFG_INTER_TX_DELAY        0x05 


//! Number of results packets
#define MFG_NUM_RESULTS_PACKETS   0x05

//! Delay time (msec) before transmitting results data
#define MFG_PRE_RESULTS_DELAY     100

//! Delay time (msec) after transmitting results data
#define MFG_INTER_RESULTS_DELAY   0x05


//--------------------------------------
// Manufacturing test port pin definitions
//! Port for manufacturing test packets
#define MFG_TEST_PORT             PRT0DR

//! Drive mode 0 for manufacturing test packets
#define MFG_TEST_DM0              PRT0DM0

//! Drive mode 1 for manufacturing test packets
#define MFG_TEST_DM1              PRT0DM1

//--------------------------------------
// API Function Declarations
//--------------------------------------

#ifdef USE_MFG_TEST

extern void mfg_test(void);

//! Macro for mfg_test()
#define MFG_TEST() mfg_test()


#else 

//! Defined as empty in case USE_MFG_TEST is not defined
#define MFG_TEST()

#endif // USE_MFG_TEST 

#endif   // MFGTEST_H

