//--------------------------------------------------------------------------
//! \file
//!
//!  Include file which defines the mouse packet and application
//!  prototypes
//!
//--------------------------------------------------------------------------
// $Archive: /WirelessUSB/LS/Firmware/LS DVK/PSoC/DVK Mouse/mouse.h $
// $Modtime: 2/12/04 12:33p $
// $Revision: 1.4 $
//--------------------------------------------------------------------------
//
// Copyright 2003, Cypress Semiconductor Corporation.
//
// This software is owned by Cypress Semiconductor Corporation (Cypress)
// and is protected by and subject to worldwide patent protection (United
// States and foreign), United States copyright laws and international 
// treaty provisions. Cypress hereby grants to licensee a personal, 
// non-exclusive, non-transferable license to copy, use, modify, create 
// derivative works of, and compile the Cypress Source Code and derivative 
// works for the sole purpose of creating custom software in support of 
// licensee product to be used only in conjunction with a Cypress integrated 
// circuit as specified in the applicable agreement. Any reproduction, 
// modification, translation, compilation, or representation of this 
// software except as specified above is prohibited without the express 
// written permission of Cypress.
//
// Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED, 
// WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Cypress reserves the right to make changes without further notice to the
// materials described herein. Cypress does not assume any liability arising
// out of the application or use of any product or circuit described herein.
// Cypress does not authorize its products for use as critical components in
// life-support systems where a malfunction or failure may reasonably be
// expected to result in significant injury to the user. The inclusion of
// Cypress product in a life-support systems application implies that the
// manufacturer assumes all risk of such use and in doing so indemnifies
// Cypress against all charges.
//
// Use may be limited by and subject to the applicable Cypress software
// license agreement.
//
//--------------------------------------------------------------------------

#ifndef _MOUSE_H_
#define _MOUSE_H_

//--------------------------------------
// Included files
//--------------------------------------
#include "cypdef.h"


//--------------------------------------
// API Definitions and Types
//--------------------------------------

//! Button right thumb switch (right joystick button) (column 3, row 0)
#define M_MIDDLE    0x0001

//! Button num_lock on keypad (column 4, row 1)
#define M_LEFT      0x0002

//! Button - on keypad (column 3, row 1)
#define M_RIGHT     0x0004


//! To ping the board for no activity
#define NO_ACTIVITY     0

//! To ping the board for activity
#define ACTIVITY        1

//! To ping the board for null activity
#define NULL_ACTIVITY   2

//! For transmitting data packets related to any mouse activity
typedef struct _APP_TX_PACKET
{
    //! X coordinate of the left joystick position
    UINT8   x;
    
    //! Y coordinate of the left joystick position
    UINT8   y;
    
    //! Z-wheel, Y coordinate of the right joystick position
    UINT8   z;  // z and button

} APP_TX_PACKET;


#endif  //_MOUSE_H_

//--------------------------------------
// API Function Declarations
//--------------------------------------

void  app_init(void);
UINT8 app_tx_process(APP_TX_PACKET *packet);
UINT8 normalize_data(UINT8 data, UINT8 index);
