//--------------------------------------------------------------------------
//! \file
//!
//! Configure All Global Compile Options
//!
//! These items are usually set in the sources files, but can be over-ridden
//!  here by using 'define' or 'undefine'.
//!
//--------------------------------------------------------------------------
// $Archive: /WirelessUSB/LS/Firmware/LS DVK/PSoC/DVK RS232 Master/ls_config.h $
// $Modtime: 3/04/04 2:41p $
// $Revision: 1.5 $
//--------------------------------------------------------------------------
//
// Copyright 2003-2004, Cypress Semiconductor Corporation.
//
// This software is owned by Cypress Semiconductor Corporation (Cypress)
// and is protected by and subject to worldwide patent protection (United
// States and foreign), United States copyright laws and international 
// treaty provisions. Cypress hereby grants to licensee a personal, 
// non-exclusive, non-transferable license to copy, use, modify, create 
// derivative works of, and compile the Cypress Source Code and derivative 
// works for the sole purpose of creating custom software in support of 
// licensee product to be used only in conjunction with a Cypress integrated 
// circuit as specified in the applicable agreement. Any reproduction, 
// modification, translation, compilation, or representation of this 
// software except as specified above is prohibited without the express 
// written permission of Cypress.
//
// Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED, 
// WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Cypress reserves the right to make changes without further notice to the
// materials described herein. Cypress does not assume any liability arising
// out of the application or use of any product or circuit described herein.
// Cypress does not authorize its products for use as critical components in
// life-support systems where a malfunction or failure may reasonably be
// expected to result in significant injury to the user. The inclusion of
// Cypress product in a life-support systems application implies that the
// manufacturer assumes all risk of such use and in doing so indemnifies
// Cypress against all charges.
//
// Use may be limited by and subject to the applicable Cypress software
// license agreement.
//
//--------------------------------------------------------------------------

#ifndef _LS_CONFIG_H_
#define _LS_CONFIG_H_

//--------------------------------------
// API Definitions and Types
//--------------------------------------

// RADIO PARAMETERS
//! Data rate 64 kbps
#define DATA_RATE_64

//! Option to use interrupt service routine, all related code will be executed
#define RADIO_NON_BLOCKING_CALLS

//! Option to use manufacture ID, all related code will be executed
#define RADIO_USE_MID

//! Option to use receive signal strength indicator, all related code will be
//! executed
#define RADIO_USE_RSSI


// PROTOCOL PARAMETERS
//! Option to use protocol 1:1, all related code will be executed
#define PROTOCOL_1_1

//! Option to use a non hopping bind, all related code will be executed
//#define BIND_NO_HOP
//! Option to use dynamic PA support (decreases transmit power as devices get
//! closer together and increases as they get farther apart), all related code
//! will be executed
#define DYNAMIC_PA_SUPPORT

//! Default PA setting 
#define DEFAULT_POWER_LEVEL 0x07

//! PA setting when binding
#define BIND_POWER_LEVEL    0x04

//! Default channel when initializing. Once the HID enters bind mode, the 
//! channel will switch
#define DEFAULT_CHANNEL     0x00

//! This is the index of the PN Code to be used. Auto bind procedures can
//! dynamically change the PN Code after the DEFAULT_PN_CODE is loaded 
//! during initialization. DEFAULT_PN_CODE can be any value between 0 and 48
//! for 16kbps, 0 and 17 for 32 and 64kbps
#define DEFAULT_PN_CODE     0x00

// RS232 SPECIFIC DEFINES
//! Type for RS232 device
#define DEVICE_TYPE             0x06

//! Maximum data length for RS232 data packet
#define MAX_DATA_LEN            20

//! Data length for RS232 data packet being transmitted
#define APP_TX_PACKET_SIZE      MAX_DATA_LEN

//! Data length for RS232 data packet being received
#define APP_RX_PACKET_SIZE      MAX_DATA_LEN

//! Length of the clear-to-send assert
#define CTS_ASSERT_LEN      0x01 



// API Macro's
//! Macro that is set to the port anded with the interrupt request mask
#define LS_IRQ_ASSERTED             (PRT1DR & R_IRQ_MASK)

//! Macro that is defined as ISR_ENABLE which enables ISR
#define RADIO_ISR_ENABLE()          ISR_ENABLE(GPIO_ISR_RADIO_IE_PORT, GPIO_ISR_RADIO_INT)

//! Macro that is defined as ISR_DISABLE which disables ISR
#define RADIO_ISR_DISABLE()         ISR_DISABLE(GPIO_ISR_RADIO_IE_PORT, GPIO_ISR_RADIO_INT)


// Flash Block location of the System Parameters
//! Used as a parameter for the non-encrypted nvram reads and writes. Set near the end
//! of 16K flash memory, 3e80.
#define SYS_PARAM_LOC     250  // set near the end of 16K flash memory, 3e80.

//! Macro for reading data from flash memory, using flash_read_lite()
#define NVRAM_READ(data, len)               flash_read_lite(SYS_PARAM_LOC, data, len)

//! Macro for writing data to flash memory, using flash_write_lite() 
#define NVRAM_WRITE(data)                   flash_write_lite(SYS_PARAM_LOC, data)

//! Macro for reading encrypted data from flash memory, using flash_read_lite()
#define ENCRYPT_NVRAM_READ(addr, data, len)	flash_read_lite(addr, data, len)

//! Macro for writing encrypted data to flash memory, using flash_write_lite() 
#define ENCRYPT_NVRAM_WRITE(addr, data)     flash_write_lite(addr, data)


//! Macro for the timer_delay_10_usec() routine
#define TIMER_DELAY_10_USEC()                 timer_delay_10_usec()

//! Macro for the timer_delay_50_usec() routine
#define TIMER_DELAY_50_USEC()                 timer_delay_50_usec()

//! Macro for the timer_delay_msec() routine
#define TIMER_DELAY_MSEC(cnt)                 timer_delay_msec(cnt)

//! Macro for the timer_delay_incremental() routine
#define TIMER_DELAY_INCREMENTAL(base, incr)   timer_delay_incremental(base, incr)

//! Macro for the timer_time_elapsed() routine
#define TIMER_IS_TIME_ELASPSED(base, curr)    timer_time_elasped(base, incr)

//! Macro for the timer_get_time_stamp() routine
#define TIMER_GET_TIME_STAMP()                timer_get_time_stamp()


//-----------------------------------------------
// Included files
// 
// These are at the bottom for the above #defines
//-----------------------------------------------

#include "psocgpioint.h"
#include "pdc9075.h"
#include "isr.h"
#include "timer.h"
#include "flash.h"

#endif // _LS_CONFIG_H_
