//--------------------------------------------------------------------------
//! \file
//!
//! The main RS232 Master control code.
//!
//--------------------------------------------------------------------------
// $Archive: /WirelessUSB/LS/Firmware/LS DVK/PSoC/DVK RS232 Master/main.c $
// $Modtime: 3/16/04 9:51a $
// $Revision: 1.4 $
//--------------------------------------------------------------------------
//
// Copyright 2003, Cypress Semiconductor Corporation.
//
// This software is owned by Cypress Semiconductor Corporation (Cypress)
// and is protected by and subject to worldwide patent protection (United
// States and foreign), United States copyright laws and international 
// treaty provisions. Cypress hereby grants to licensee a personal, 
// non-exclusive, non-transferable license to copy, use, modify, create 
// derivative works of, and compile the Cypress Source Code and derivative 
// works for the sole purpose of creating custom software in support of 
// licensee product to be used only in conjunction with a Cypress integrated 
// circuit as specified in the applicable agreement. Any reproduction, 
// modification, translation, compilation, or representation of this 
// software except as specified above is prohibited without the express 
// written permission of Cypress.
//
// Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED, 
// WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Cypress reserves the right to make changes without further notice to the
// materials described herein. Cypress does not assume any liability arising
// out of the application or use of any product or circuit described herein.
// Cypress does not authorize its products for use as critical components in
// life-support systems where a malfunction or failure may reasonably be
// expected to result in significant injury to the user. The inclusion of
// Cypress product in a life-support systems application implies that the
// manufacturer assumes all risk of such use and in doing so indemnifies
// Cypress against all charges.
//
// Use may be limited by and subject to the applicable Cypress software
// license agreement.
//--------------------------------------------------------------------------

//--------------------------------------
// Included files
//--------------------------------------


#include "master_protocol.h"
#include "rs232.h"
#include "spi.h"

//--------------------------------------
// Local Definitions and Types
//--------------------------------------

//! For checking bind button activity
#define BIND_CHECK_COUNT 100



///////////////////////////////////////////////////////////////////////////////
//
//  Function:    main
//
//!  Description: RS232 Master main routine initializes the interrupt service
//!               routine, timer, platform board, serial peripheral interface, 
//!               protocol, and RS232.  Then runs the main control loop that is 
//!               always listening for valid data packets, and checking the
//!               the platform board for a bind button press.
//!
//!  Inputs:      Void
//!
//!  Returns:     Void
//!
///////////////////////////////////////////////////////////////////////////////
void main()
{
    UINT8  length = 0;
    UINT8  bind_check_counter = 0;
    UINT8  status = 0;

  
    // initialize the system
    // setup the Radio/GPIO interrupt logic
    isr_init();

    // initialize the timer and its ISR
    timer_init();
    
    // configure the board
    platform_init();
    
    spi_init();
    
    // setup the protocol initialization 
    master_init();

    // perfrom RS-232 initialization
    app_init();

    set_connect_led(ON);

    // main infinite control loop
    while(1) 
    {   
        status = master_data_mode( );
            
        // clear CTS so that next packet can be loaded from RS-232
        if (status & ACK_RECEIVED )
        {
            app_packet_transmitted();
        }        
        
        // check for a protocol button change
        if(bind_check_counter++ > BIND_CHECK_COUNT)
        {
            bind_check_counter = 0;
            
            if ( bind_pressed() == TRUE)
            {
                set_bind_led(ON); 

                // turn off the Connect LED
                set_connect_led(OFF); 
                status = master_bind_mode();
                set_bind_led(OFF);
                    set_connect_led(ON);
            }
        }                
    }  // while(1)
}  // end main

