//--------------------------------------------------------------------------
//! \file
//!
//! Collection of the bind routines for automatic bind.
//
//--------------------------------------------------------------------------
// $Archive: /WirelessUSB/LS/Firmware/LS DVK/PSoC/Radio/bind.c $
// $Modtime: 3/19/04 1:34p $
// $Revision: 1.4 $
//--------------------------------------------------------------------------
//
// Copyright 2003-2004, Cypress Semiconductor Corporation.
//
// This software is owned by Cypress Semiconductor Corporation (Cypress)
// and is protected by and subject to worldwide patent protection (United
// States and foreign), United States copyright laws and international 
// treaty provisions. Cypress hereby grants to licensee a personal, 
// non-exclusive, non-transferable license to copy, use, modify, create 
// derivative works of, and compile the Cypress Source Code and derivative 
// works for the sole purpose of creating custom software in support of 
// licensee product to be used only in conjunction with a Cypress integrated 
// circuit as specified in the applicable agreement. Any reproduction, 
// modification, translation, compilation, or representation of this 
// software except as specified above is prohibited without the express 
// written permission of Cypress.
//
// Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED, 
// WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Cypress reserves the right to make changes without further notice to the
// materials described herein. Cypress does not assume any liability arising
// out of the application or use of any product or circuit described herein.
// Cypress does not authorize its products for use as critical components in
// life-support systems where a malfunction or failure may reasonably be
// expected to result in significant injury to the user. The inclusion of
// Cypress product in a life-support systems application implies that the
// manufacturer assumes all risk of such use and in doing so indemnifies
// Cypress against all charges.
//
// Use may be limited by and subject to the applicable Cypress software
// license agreement.
//
//--------------------------------------------------------------------------

//--------------------------------------
// Included files
//--------------------------------------
#include "bind.h"
#include "protocol.h"
#include "radio.h"

//--------------------------------------
// Local Definitions and Types
//--------------------------------------
//! Receive packet
extern LS_RX_PACKET  rx_packet;

//! Transmit packet
extern LS_TX_PACKET  tx_packet;

//! Channel valid array for data packets
extern UINT8         channel_valid[];

//! Length (bytes) of receive data.  Used in protocol_bind(), radio_receive(),  
//! protocol_verify_packet(), protocol_send_packet(), and mfg_receive_test_packets() 
extern UINT8         rx_data_length;

//! To tell whether the device is in a connected state or not
UINT8  bind_mode = 0;

#ifdef DATA_RATE_16

//! 8 PN codes for a data rate of 32kbps or 64kbps, and 48 PN codes for a
//! data rate of 16kbps
const UINT8 pn_code_table[] = 
{
    0x83, 0xF7, 0xA8, 0x2D, 0x7A, 0x44, 0x64, 0xD3,
    0x3F, 0x2C, 0x4E, 0xAA, 0x71, 0x48, 0x7A, 0xC9,
    0x17, 0xFF, 0x9E, 0x21, 0x36, 0x90, 0xC7, 0x82,
    0xA6, 0x46, 0xB5, 0x9A, 0x3A, 0x30, 0xB6, 0xAD,
    0xBC, 0x5D, 0x9A, 0x5B, 0xEE, 0x7F, 0x42, 0xEB,
    0x24, 0xF5, 0xDD, 0xF8, 0x7A, 0x77, 0x74, 0xE7,
    0x3D, 0x70, 0x7C, 0x94, 0xDC, 0x84, 0xAD, 0x95,
    0x1E, 0x6A, 0xF0, 0x37, 0x52, 0x7B, 0x11, 0xD4,
    0x62, 0xF5, 0x2B, 0xAA, 0xFC, 0x33, 0xBF, 0xAF,
    0x40, 0x56, 0x32, 0xD9, 0x0F, 0xD9, 0x5D, 0x97,
    0x8E, 0x4A, 0xD0, 0xA9, 0xA7, 0xFF, 0x20, 0xCA,
    0x38, 0xB3, 0x31, 0xAB, 0x24, 0x78, 0xA6, 0xBD,
    0x4C, 0x97, 0x9D, 0xBF, 0xB8, 0x3D, 0xB5, 0xBE,
    0x0C, 0x5D, 0x24, 0x30, 0x9F, 0xCA, 0x6D, 0xBD,
    0x29, 0x29, 0x7B, 0xB5, 0xC8, 0xF4, 0x4D, 0x8A,
    0x50, 0x14, 0x33, 0xDE, 0xF1, 0x78, 0x95, 0xAD,
    0xD6, 0xA6, 0xAA, 0x10, 0x96, 0xB3, 0xA6, 0xA7,
    0xF6, 0xCE, 0x0D, 0x12, 0xE3, 0x66, 0xA6, 0x94,
    0x0C, 0x3C, 0xFA, 0xF9, 0xF0, 0xF2, 0x10, 0xC9,
    0xF4, 0xDA, 0x06, 0xDB, 0xBF, 0x4E, 0x6F, 0xB3,
    0x93, 0x9C, 0x4E, 0x14, 0x1A, 0x39, 0xCF, 0xE6,
    0xC9, 0x2C, 0x06, 0x93, 0x86, 0xB9, 0x9E, 0xD7,
    0x9E, 0x08, 0xD1, 0xAE, 0x59, 0x5E, 0xE8, 0xF0,
    0xC0, 0x90, 0x8F, 0xBB, 0x7C, 0x8E, 0x2B, 0x8E,
    0x80, 0x69, 0x26, 0x80, 0x08, 0xF8, 0x49, 0xE7,
    0x7d, 0x2d, 0x49, 0x54, 0xd0, 0x80, 0x40, 0xC1,
    0xB6, 0xF2, 0xE6, 0x1B, 0x80, 0x5A, 0x36, 0xB4,
    0x42, 0xAE, 0x9C, 0x1C, 0xDA, 0x67, 0x05, 0xF6,
    0x9B, 0x75, 0xF7, 0xE0, 0x14, 0x8D, 0xB5, 0x80,
    0xBF, 0x54, 0x98, 0xB9, 0xB7, 0x30, 0x5A, 0x88,
    0x35, 0xD1, 0xFC, 0x97, 0x23, 0xD4, 0xC9, 0x88,
    0xE1, 0xD6, 0x31, 0x26, 0x5F, 0xBD, 0x40, 0x93,
    0xDC, 0x68, 0x08, 0x99, 0x97, 0xAE, 0xAF, 0x8C,
    0xC3, 0x0E, 0x01, 0x16, 0x0E, 0x32, 0x06, 0xBA,
    0xE0, 0x83, 0x01, 0xFA, 0xAB, 0x3E, 0x8F, 0xAC,
    0x5C, 0xD5, 0x9C, 0xB8, 0x46, 0x9C, 0x7D, 0x84,
    0xF1, 0xC6, 0xFE, 0x5C, 0x9D, 0xA5, 0x4F, 0xB7,
    0x58, 0xB5, 0xB3, 0xDD, 0x0E, 0x28, 0xF1, 0xB0,
    0x9A, 0xD6, 0x95, 0xBA, 0xA4, 0xC5, 0x32, 0x9C,
    0x5F, 0x30, 0x3B, 0x56, 0x96, 0x45, 0xF4, 0xA1,
    0x03, 0xBC, 0x6E, 0x8A, 0xEF, 0xBD, 0xFE, 0xF8,
    0x88, 0x17, 0x13, 0x3B, 0x2D, 0xBF, 0x06, 0xD6,
    0xF1, 0x94, 0x30, 0x21, 0xA1, 0x1C, 0x88, 0xA9,
    0xD0, 0xD2, 0x8E, 0xBC, 0x82, 0x2F, 0xE3, 0xB4,
    0x8C, 0xFA, 0x47, 0x9B, 0x83, 0xA5, 0x66, 0xD0,
    0x07, 0xBD, 0x9F, 0x26, 0xC8, 0x31, 0x0F, 0xB8,
    0xD7, 0xA1, 0x54, 0xB1, 0x5E, 0x89, 0xAE, 0x86,
    0xEF, 0x03, 0x95, 0x89, 0xB4, 0x71, 0x61, 0x9D,
    0x40, 0xBA, 0x97, 0xD5, 0x86, 0x4F, 0xCC, 0xD1,
};
#endif

#ifndef DATA_RATE_16

//! 8 PN codes for a data rate of 32kbps or 64kbps, and 48 PN codes for a
//! data rate of 16kbps
const UINT8 pn_code_table[] = 
{
    0x6A, 0xE7, 0x01, 0xEA, 0x03, 0xFD, 0x13, 0xD2, 
    0xDC, 0xC0, 0x6B, 0xB8, 0x2B, 0x09, 0xBB, 0xB2, 
    0xA3, 0x1E, 0xF2, 0xA4, 0x31, 0x32, 0x7A, 0xB3, 
    0x44, 0x83, 0x3B, 0xDD, 0x14, 0xCF, 0x8E, 0xC9, 
    0x35, 0x35, 0x4E, 0xC5, 0xF3, 0x52, 0x47, 0xB0, 
    0x7C, 0x23, 0x8A, 0xCE, 0x45, 0x5C, 0x54, 0xD7, 
    0x81, 0xAC, 0xFB, 0x83, 0x7A, 0x9A, 0x61, 0xAC, 
    0x3C, 0x12, 0x5F, 0x9C, 0x39, 0x98, 0xF6, 0x8A, 
};
#endif


///////////////////////////////////////////////////////////////////////////////
//
//  Function:    get_next_channel
//
//!  Description: Performs the channel selection algorithm. Every sixth channel
//!               will be used.
//!
//!  Inputs:      Void
//!
//!  Returns:     Void
//!
///////////////////////////////////////////////////////////////////////////////

void get_next_channel(void)
{
    sys_params.network_id.channel += (6 * (sys_params.network_id.pin + 1));

    if((NUM_CHANNELS) - 1 < sys_params.network_id.channel)
    {
        sys_params.network_id.channel -= NUM_CHANNELS;    
    }
}

///////////////////////////////////////////////////////////////////////////////
//
//  Function:    init_channel
//
//!  Description: Initialize the channel selection algorithm to the top channel
//!               in the channel subset
//!
//!  Inputs:      Void
//!
//!  Returns:     Void
//!
///////////////////////////////////////////////////////////////////////////////

void init_channel(void)
{
    while (sys_params.network_id.channel < NUM_CHANNELS - 6) 
    {
        sys_params.network_id.channel += 6;
    }
}

///////////////////////////////////////////////////////////////////////////////
//
//  Function:    protocol_bind_init
//
//!  Description: Initializes the channel to the top channel, and the bind mode
//!               to a disconnected state puts the radio in sleep mode (See
//!               radio_sleep() ), if necessary
//!
//!  Inputs:      Void
//!
//!  Returns:     Void
//!
///////////////////////////////////////////////////////////////////////////////

void protocol_bind_init()    // Bind Auto
{
    init_channel();

    bind_mode = DISCONNECTED_STATE;

#ifdef RADIO_SLEEP_ENABLED
    radio_sleep();
#endif
}

///////////////////////////////////////////////////////////////////////////////
//
//  Function:    protocol_bind
//
//!  Description: Formats the bind packet, reads radio information, sets up
//!               the radio and reads/sets the power level.  Then as it runs
//!               through the channels it sends bind requests until an 
//!               acknowledge is received (or the maximum amount of requests 
//!               have been sent).  If all channels have been run through 
//!               without an ack, then a bind timeout occurs which would result
//!               to an unsuccessful bind and all bind parameters are 
//!               reinitialized.  If a good ack packet is received, it then 
//!               creates and sends an ack packet back 3 times to ensure
//!               delivery.  Then the settings are saved in NVRAM and the power 
//!               settings are restored.
//!                                 
//!
//!  Inputs:      Void
//!
//!  Returns:     
//!               - LS_STATUS_SUCCESS - successful bind
//!               - LS_STATUS_FAILED - unsuccessful bind    
//!
///////////////////////////////////////////////////////////////////////////////

UINT8 protocol_bind()    // Bind Auto
{
    UINT8  channel_timeout;
    UINT8  status = LS_STATUS_SUCCESS;
    UINT8  packet_received;
    UINT8  tx_timeout;
    UINT8  pa_setting;
        
#ifdef RADIO_SLEEP_ENABLED
    radio_wakeup();  
#endif
         
    bind_mode = DISCONNECTED_STATE;
    
    // format the bind packet
    tx_packet.bind.hdr.type    = BIND_REQ; 
    tx_packet.bind.hdr.dev_type = DEVICE_TYPE; 
    tx_packet.bind.hdr.parity  = protocol_gen_parity(tx_packet.first.byte);
    
#ifndef PROTOCOL_1_1
    // read the radio ID
    SPI_RADIO_PUT( REG_ANALOG_CTL, (AGC_RSSI_CTL | PACTL_EN | MID_READ_EN ));    

    // read the Radio ID registers
    tx_packet.bind.mid_1 =  SPI_RADIO_GET( REG_MFG_ID_1 + RADIO_ID_1 );  
    tx_packet.bind.mid_2 =  SPI_RADIO_GET( REG_MFG_ID_1 + RADIO_ID_2 );  
    tx_packet.bind.mid_3 =  SPI_RADIO_GET( REG_MFG_ID_1 + RADIO_ID_3 );  
    tx_packet.bind.mid_4 =  SPI_RADIO_GET( REG_MFG_ID_1 + RADIO_ID_4 ); 

    // disable the Radio ID registers
    SPI_RADIO_PUT( REG_ANALOG_CTL, (AGC_RSSI_CTL | PACTL_EN ));

    tx_packet.bind.checksum = protocol_calc_ck_sum((UINT8 *)&tx_packet.bind, 
                                                   BIND_REQ_LEN-1, BIND_SEED);

    sys_params.network_id.pin = 0;
#endif // PROTOCOL_1_1

    // load the bind pn_code index
    radio_set_pn_code(&pn_code_table[(8 * BIND_PN_CODE)]);
     
    // Read PA setting
    pa_setting = radio_get_power_level();    
    
    // load Bind PA
    radio_set_power_level(BIND_POWER_LEVEL);

    // seed the channel algorithm with bind parameters 0,0
    sys_params.network_id.channel = 0;
       
    // send a bind request and wait for response, if no response change
    // the channel and try again
    for( channel_timeout = 0; channel_timeout < BIND_TIMEOUT; ++channel_timeout)
    {   
        // setup mode
        radio_set_channel(sys_params.network_id.channel);
        
        // loop until ACK radio_received or TX retries exhausted
        for(tx_timeout = 0; tx_timeout <= BIND_MAX_TRANSMITS; ++tx_timeout)
        {                           
            radio_transmit(BIND_REQ_LEN, (UINT8 *)&tx_packet);

            // wait for Bind Response 
            if (radio_receive(LS_RX_PACKET_LEN, (UINT8 *)&rx_packet, (UINT8 *)&channel_valid, BIND_ACK_TIMEOUT) > 0)
            {
                packet_received = protocol_verify_packet();
            }

            if (packet_received == BIND_RESP) 
            {
                break;                   
            }
            else
            {
                //  radio_off();
                #ifdef RADIO_SLEEP_ENABLED
                radio_sleep();
                TIMER_DELAY_MSEC(8);
                radio_wakeup();
                #else
                TIMER_DELAY_MSEC(8);
                #endif
            }
        }
       
        // check for Bind timeout
        if(tx_timeout >= BIND_MAX_TRANSMITS)
        {
            // Clear Watchdog and Sleep Timer
            M8C_ClearWDTAndSleep;

            //try the next channel in the subset of channels
            get_next_channel();
        }
        else if( (packet_received == BIND_RESP) && (rx_data_length == BIND_RESP_LEN) ) 
        {  
            // Good Ack
            
             // send an ACK
            tx_packet.first.byte = 0;
            tx_packet.ack.hdr.type   = ACK_PACKET;                    
            tx_packet.ack.hdr.flag   = GOOD_ACK;
            tx_packet.ack.hdr.parity = protocol_gen_parity(
                                      (UINT8) tx_packet.first.byte);
              
#ifdef CHECKSUM_ALL_PACKETS
            tx_packet.data.app_packet[0] = 
            protocol_calc_ck_sum((UINT8 *)&tx_packet, 1, 
                     rx_packet.bind.checksum_seed );
#endif        
    
            // send the ACK to the bind response multiple times to
            // ensure delivery
            radio_transmit(ACK_LEN, (UINT8 *)&tx_packet);
            
            TIMER_DELAY_50_USEC();
            TIMER_DELAY_50_USEC();
            TIMER_DELAY_50_USEC();
            TIMER_DELAY_50_USEC();          
            radio_transmit(ACK_LEN, (UINT8 *)&tx_packet);
            
            TIMER_DELAY_50_USEC();
            TIMER_DELAY_50_USEC();
            TIMER_DELAY_50_USEC();
            TIMER_DELAY_50_USEC();
            radio_transmit(ACK_LEN, (UINT8 *)&tx_packet);
                                    
#ifndef PROTOCOL_1_1
            // extract the bind parameters and store them        
            sys_params.network_id.pin         = rx_packet.bind.hdr.pin;
            sys_params.network_id.channel     = rx_packet.bind.channel;
            sys_params.network_id.pn_code     = rx_packet.bind.pn_code;
            sys_params.network_id.seed        = rx_packet.bind.checksum_seed;
#else
            // extract Bridge MID from BIND_RESP 
            sys_params.bridge_mid.mid_1        = rx_packet.bind.mid_1;
            sys_params.bridge_mid.mid_2        = rx_packet.bind.mid_2;
            sys_params.bridge_mid.mid_3        = rx_packet.bind.mid_3;
            sys_params.bridge_mid.mid_4        = rx_packet.bind.mid_4;
            // store sys_params
#endif // PROTOCOL_1_1

            status = LS_STATUS_SUCCESS;
            break; // exit the for loop
        }
    }  // for()
    
    // Restore PA setting
    radio_set_power_level(pa_setting);
    
    // check the results of the while loop
    if(channel_timeout > BIND_TIMEOUT - 1)
    {
        // can't Bind, reset to original bind parameters
        protocol_bind_init();
        
        status = LS_STATUS_FAILED;
    }
    else if(packet_received == BIND_RESP)   // ack sent OK
    {
        // store parameters in NVRAM
        NVRAM_WRITE( &sys_params );
        
#ifdef PROTOCOL_1_1
        // calculate channel, PN code, etc. from the Bridge MID
        calculate_network_id();
#endif // PROTOCOL_1_1
     
        // give the dongle time to ping before trying to reconnect
        TIMER_DELAY_MSEC(BRIDGE_PING_TIME);
        
        init_channel();
        
        status = protocol_reconnect();

#ifdef ENCRYPT_DATA
        if (status == LS_STATUS_SUCCESS) 
        {
            encrypt_request_key();
        }
#endif  // ENCRYPT_DATA
    }

#ifdef RADIO_SLEEP_ENABLED
    radio_sleep();  
#endif
        
    return status;
}


///////////////////////////////////////////////////////////////////////////////
//
//  Function:    protocol_reconnect
//
//!  Description: Checks for an unbound device, resets radio (and restore
//!               transmit valid bits if necessary), formats a connect data 
//!               packet, reads radio information and sets up the radio.  It 
//!               then reads and adjusts power level (if DYNAMIC_PA enabled).
//!               Then as it runs through the channels it sends connect requests
//!               until an good response is received (or the maximum amount of
//!               requests have been sent). If all channels have been run through 
//!               without a response, then it tries the original channel a few
//!               times.  If no response is received on any channel the 
//!               connection is unsuccessful.
//!               
//!
//!  Inputs:      Void
//!
//!  Returns:     
//!               - LS_STATUS_SUCCESS - successful connection
//!               - LS_STATUS_FAILED - unsuccessful connection    
//!
///////////////////////////////////////////////////////////////////////////////

UINT8 protocol_reconnect()
{
    UINT8  timeout;
    UINT8  status;
    UINT8  packet_received;
#ifdef DYNAMIC_PA_SUPPORT
    UINT8  pa_setting = PA_BIAS_MASK;
    UINT8  channel_count = 0;
#endif
        
    // check for unbound device
    if (sys_params.network_id.pin == 0) 
    {
        // Turn off the radio
#ifdef RADIO_SLEEP_ENABLED        
        radio_sleep();
#endif

        return LS_STATUS_FAILED;
    }
    
    bind_mode = DISCONNECTED_STATE;
    status = LS_STATUS_FAILED;

    // check for radio resetting due to a glitch on the N_RESET
    // pin. The TX Valids bit should be 0xFF. If not that value the 
    // radio is corrupted.
    if( radio_get_power_level() == 0x00)
    {
        // reset the radio
        radio_init();       
    }
    
    // select a channel, send a connect request, and
    // wait for a connect response
    // format the bind packet
    tx_packet.connect.hdr.type   = CONNECT_REQ; 
#ifdef DYNAMIC_PA_SUPPORT
    tx_packet.connect.hdr.pin    = protocol_device_type;
#else
    tx_packet.connect.hdr.pin    = sys_params.network_id.pin;
#endif
    tx_packet.connect.hdr.parity = 
        protocol_gen_parity((UINT8) tx_packet.first.byte);

#ifndef PROTOCOL_1_1
    tx_packet.connect.channel  = sys_params.network_id.base_channel; 
    tx_packet.connect.pn_code   = sys_params.network_id.pn_code; 
    
    // read the radio ID
    SPI_RADIO_PUT( REG_ANALOG_CTL, (AGC_RSSI_CTL | PACTL_EN | MID_READ_EN ));    

    // read the radio IDs
    tx_packet.connect.mid_1 =  SPI_RADIO_GET( REG_MFG_ID_1);  
    tx_packet.connect.mid_2 =  SPI_RADIO_GET( REG_MFG_ID_2);  
    tx_packet.connect.mid_3 =  SPI_RADIO_GET( REG_MFG_ID_3);  
    tx_packet.connect.mid_4 =  SPI_RADIO_GET( REG_MFG_ID_4); 

    // disable the Radio ID registers
    SPI_RADIO_PUT( REG_ANALOG_CTL, (AGC_RSSI_CTL | PACTL_EN ));
    
#else
    // load Bridge MID from sys_params into the tx_packet...
    NVRAM_READ( &tx_packet.connect.mid_1, 4 );
#endif

#ifdef DYNAMIC_PA_SUPPORT
    // Set PA field
    //tx_packet.connect.pa = (SPI_RADIO_GET(REG_PA) & PA_BIAS_MASK);
    tx_packet.connect.pa = radio_get_power_level();
#endif
       
    // calculate checksum
    tx_packet.connect.checksum =
        protocol_calc_ck_sum( (UINT8 *)&tx_packet.connect, 
                              CONNECT_REQ_LEN-1, sys_params.network_id.seed );
    
    // load the bind pnCode index
    //radio_set_pn_code(sys_params.network_id.pn_code);
    radio_set_pn_code(&pn_code_table[(8 * sys_params.network_id.pn_code)]);
   
    // send a bind request and wait for response, if no response change
    // the channel and try again
    for(timeout=0; timeout<CONNECT_TIMEOUT; timeout++)
    {                
#ifdef DYNAMIC_PA_SUPPORT
        if (SUBSET_CHANNELS - 1 < channel_count)
        {
            // Clear Channel count
            channel_count = 0;

            // Adjust PA (3,5, or 7)
            if (pa_setting == 0x03)
            {
                pa_setting = 0x07;
            }
            else
            {
                pa_setting -= 0x02;
            }

            // Change PA setting
            radio_set_power_level(pa_setting);

            // Set PA field
            tx_packet.connect.pa = pa_setting;

            // calculate check sum
            tx_packet.connect.checksum =
            protocol_calc_ck_sum( (UINT8 *)&tx_packet.connect, 
                                      CONNECT_REQ_LEN-1, 
                                      sys_params.network_id.seed );
        }
#endif    // DYNAMIC_PA_SUPPORT
        
        // setup radio_transmit mode
        radio_set_channel(sys_params.network_id.channel);
        radio_transmit(CONNECT_REQ_LEN, (UINT8 *)&tx_packet);

        // wait for Connect Response 
        if (radio_receive(LS_RX_PACKET_LEN, (UINT8 *)&rx_packet, 
                          (UINT8 *)&channel_valid, CONNECT_ACK_TIMEOUT) > 0)
        {
            packet_received = protocol_verify_packet();
        }
       
        if(packet_received == CONNECT_RESP)
        {
            if ((rx_packet.connect.hdr.flag == GOOD_ACK ) &&
                (rx_data_length == CONNECT_RESP_LEN))
            {
                bind_mode = CONNECTED_STATE;
              
                // return a success status...
                status = LS_STATUS_SUCCESS;
                
                break; // good response, exit the loop
            } 
            else
            {
                // bad response, bump channel
                get_next_channel();         
            }                    
        }
        else
        {
#ifdef APP_CALLBACK_FUNC
            APP_CALLBACK_FUNC();
#endif

            // Try a few times on the original channel
            if (timeout > ORIGINAL_CHAN_RECONNECT_COUNT)
            {
                // timeout, bump channel
                get_next_channel();
                
#ifdef DYNAMIC_PA_SUPPORT
                ++channel_count;
#endif
            }
        }
    }  // end for(timeout = 0; timeout < CONNECT_TIMEOUT; timeout++)

        
#ifdef RADIO_SLEEP_ENABLED
    radio_sleep();
#endif
    
    return status;
}
