;****************************************************************************
;
;   file:           bind-auto.asm
;   Description:    This file contains automatic bind procedures
;   External Functions:
;                   power_on_mode
;                   ping_mode
;                   bind_mode

;   Target:         Cypress CY7C63723/CY7C63743 Encore Chips
;   $Header: g:/archives/Projects/LS DVK P2/Dongle/Two Way/bind-auto.asm
;   Version:        1.3.0000
;
;****************************************************************************
; Copyright (2003), Cypress Semiconductor Corporation
; This software is owned by Cypress Semiconductor Corporation (Cypress) and  is
; protected by United States copyright laws and international treaty provisions.
; Cypress hereby grants to Licensee a personal, non-exclusive, non-transferable
; license to copy, use, modify, create derivative works of, and compile the
; Cypress Source Code and derivative works for the sole purpose of creating
; custom software in support of Licensee product ("Licensee Product") to be used
; only in conjunction with a Cypress integrated circuit. Any reproduction,
; modification, translation, compilation, or representation of this software
; except as specified above is prohibited without the express written permission
; of Cypress.
; Disclaimer: Cypress makes no warranty of any kind, express or implied, with
; regard to this material, including, but not limited to, the implied warranties
; of merchantability and fitness for a particular purpose. Cypress reserves the
; right to make changes without further notice to the materials described herein.
; Cypress does not assume any liability arising out of the application or use of
; any product or circuit described herein. Cypress products described herein are
; not authorized for use as components in life-support devices.
; This software is protected by and subject to worldwide patent coverage,
; including U.S. and foreign patents. Use may be limited by and subject to the
; Cypress Software License Agreement.
;
;****************************************************************************

;**********************************************************
;
;       power_on_mode
;
;   Final release will check E2 for connections 
;   currently just drops into ping mode...
;
;**********************************************************
power_on_mode:
    ; The manufacturing ID is used to compute the channel,
    ; PN code, checksum seed and PIN used by the bridge.
    ; This allows multiple systems to be easily co-located
    ; without devices communicating with the wrong bridge.

    IFDEF MFG_TEST
    IFDEF MFG_USE_BUTTON
    CALL check_for_bind             ; the bind button must be held down when plugging the bridge in
    AND  A, ffh                     ; in order to enter manufacturing test mode
    JNZ  mfg_test_mode              ; 
    ENDIF ; MFG_USE_BUTTON
    ENDIF ; MFG_TEST

    CALL read_radio_mid             ; MID is cached in bridge_mid1 through bridge_mid4

; PN Code                          
    MOV  A, [bridge_mid1]           ; PN Code = ((bridge_mid1 << 2) + bridge_mid2 + bridge_mid3) % NUM_PN_CODES 
    ASL  A
    ASL  A
    ADD  A, [bridge_mid2]
    ADD  A, [bridge_mid3]
power_on_pn_code_check:
    CMP  A, NUM_PN_CODES            ; make sure that the PN code is valid
    JC   power_on_pn_code_okay
    SUB  A, NUM_PN_CODES
    JMP  power_on_pn_code_check
power_on_pn_code_okay:
    MOV  [pn_code], A        

; Channel
    MOV  A, [bridge_mid1]           ; channel = ((bridge_mid2 >> 2) - (reg3bridge_mid1 << 5) + bridge_mid3) % NUM_CHANNELS
    ASL  A
    ASL  A
    ASL  A
    ASL  A
    ASL  A
    MOV  [ls_temp], A
    MOV  A, [bridge_mid2]
    ASR  A
    ASR  A
    AND  A, 3Fh
    SUB  A, [ls_temp]
    ADD  A, [bridge_mid3]
power_on_channel_check:
    CMP  A, NUM_CHANNELS            ; make sure that the channel is valid
    JC   power_on_channel_okay
    SUB  A, NUM_CHANNELS
    JMP  power_on_channel_check
power_on_channel_okay:
    MOV  [base_channel], A
    MOV  [ping_channel], A

; PIN
power_on_pin:
    MOV  A, [bridge_mid1]           ; pin = ((bridge_mid1  bridge_mid2) & mPIN_MASK) + MIN_PIN
    SUB  A, [bridge_mid2]
    AND  A, mPIN_MASK
    ADD  A, MIN_PIN
    MOV  [network_pin], A

; Checksum seed
power_on_checksum_seed:
    MOV  A, [bridge_mid2]           ; checkSumSeed = (bridge_mid1 + (bridge_mid2 >> 6) + bridge_mid3)
    ASR  A
    ASR  A
    ASR  A
    ASR  A
    ASR  A
    ASR  A
    AND  A, 03h
    ADD  A, [bridge_mid3]
    ADD  A, [bridge_mid1]
    MOV  [checksum_seed], A
    
read_id_complete:
    CALL radio_init                 ; set up the radio

IFDEF ENCRYPT_DATA_A
    CALL load_unique_key
ENDIF

    MOV  A, PING_REASON_NORMAL
    ; fall through to ping_mode

;**********************************************************
;
;       ping_mode:
;
;**********************************************************
ping_mode:
    SWAP A, X
    MOV  A, RSSI_NOISE_THRESHOLD    ; reset the RSSI threshold to the default
    MOV  [rssi_threshold], A
    MOV  A, 0
    MOV  [ping_channel_count], A
    SWAP A, X
    
ping_init_channel:                 
    CMP  A, PING_REASON_NORMAL
    JNZ  ping_next_channel          ; reinit channel to top of spectrum if entering ping for normal reason  

ping_load_pn_code:
    MOV  A, [pn_code]               ; this initializes the PN_CODEs on power-on and after bind
    CALL radio_load_pn_code

ping_init_top_channel:              ; initialize channel to the highest channel in the subset
    MOV  A, [base_channel]
    CMP  A, NUM_CHANNELS-6
    JNC   ping_good_channel
ping_init_channel_loop:
    ADD  A, 6
    CMP  A, NUM_CHANNELS-6
    JC   ping_init_channel_loop
    JMP  ping_good_channel

ping_next_channel:                  ; move to the next channel in the subset
    INC  [ping_channel_count]       ; increment the ping_channel_count each time we set a new channel
    MOV  A, [ping_channel_count]
    CMP  A, CHANNELS_PER_RSSI_INCREMENT ; if we have already changed channels CHANNELS_PER_RSSI_INCREMENT times
    JC   ping_rssi_level_complete        
    
    INC  [rssi_threshold]
    MOV  A, [rssi_threshold]        ; then increment the rssi threshold
    AND  A, mRSSI                   ; (this keeps us from getting stuck if ALL channes are noisy)
    MOV  [rssi_threshold], A
    MOV  A, 0
    MOV  [ping_channel_count], A

ping_rssi_level_complete:

IFNDEF PING_NO_HOP
    MOV  A, [network_pin]
    ADD  A, 1                       ; PIN gives us the number to skip, so we automatically increment one
    MOV  [ls_temp], A
    ASL 
    ASL                             ; PIN is multiplied by 6..    
    ADD  A, [ls_temp]
    ADD  A, [ls_temp]
    ADD  A, [ping_channel]          ; increment the ping channel
    CMP  A, NUM_CHANNELS            ; 
    JC   ping_good_channel
    SUB  A, NUM_CHANNELS            ; wrap around to the beginning
    
ELSE	; PING_NO_HOP
    MOV  A, [base_channel]          ; PING_NO_HOP is useful for debugging
ENDIF ; PING_NO_HOP
    
ping_good_channel:
    MOV  [ping_channel], A          ; store the new channel
    MOV  [channel], A               ; set the channel to be loaded in the radio
    CALL setup_rx                   ; set the radio into RX mode...
    
    MOV  A, 00h
    MOV  [mode_timer], A            ; the mode_timer is reset for each new channel that is being pinged
    MOV  [timer], A                 ; clear the RX variables
    MOV  [tx_ack_pending], A
    MOV  [packet_type], A
    MOV  [rx_counter], A
    CALL ping_leds  
    CALL delay200us

    ;MOV  A, PING_MODE_RSSI
    CALL check_rssi                 ; Check the RSSI to see if this channel is noisy   
    CMP  A, [rssi_threshold]
    JNC  ping_next_channel           ; Find a new channel if the RSSI is too high
    CALL setup_rx                   ; Reset radio to clear RSSI


ping_loop:
    IOWR watchdog

    IORD port0                      ; listen for data
    AND  A, IRQ                     ; 
    JNZ  ping_process_rx

ping_loop_time_check:
    MOV  A, [timer]                 ; IF we have not timed out
    SUB  A, PING_RSSI_INTERVAL               
    JC   ping_loop                  ; THEN just keep looping

    INC  [mode_timer]               ; ELSE IF ping mode is complete
    MOV  A, [mode_timer]            ; exit ping mode
    CMP  A, PING_NUM_RSSI            
    JNC  ping_timeout

    CALL check_for_bind             ; check for the bind button press
    AND  A, ffh
    JNZ  bind_mode                  ; jump to bind mode if the button was pressed
    
    ;MOV  A, PING_MODE_RSSI
    CALL check_rssi                 ; Check the RSSI to see if this channel is noisy   
    CMP  A, [rssi_threshold]
    JNC  ping_next_channel           ; Find a new channel if the RSSI is too high

    MOV  A, PING_DATA               ; build a ping packet
    MOV  [tx_sys_buffer], A

    MOV  A, LEN_PING                 ; set the packet length
    MOV  [tx_sys_counter], A    

IFDEF CHECKSUM_ALL_PACKETS
	MOV  A, BIND_CHECKSUM_SEED 		; A = checksum seed
	CALL set_sys_checksum			; calculate the checksum
ENDIF ; CHECKSUM_ALL_PACKETS

send_ping:
    CALL switch_tx                  ; transmit the ping packet
    CALL transmit_sys               ; (transmit_sys also resets the [timer] register)
    CALL switch_rx                  ; switch back to RX mode to listen for ping response
    JMP  ping_loop                  ; and to check RSSI
    
ping_timeout:    
    JMP  connected_mode             ; move to connected mode   

;----------------------------------------------------------
;   ping_process_rx:
;----------------------------------------------------------
ping_process_rx:
    CALL process_rx_int              
    
    CMP  A, bFLAG_EOF
    JNZ   ping_loop_time_check         

    CALL verify_packet              ; check checksum, store packet type, etc.    
    CMP  A, bFLAG_VALID
    JNZ   ping_process_rx_complete

ping_valid_packet:    
    MOV  A, [packet_type]
    SUB  A, PT_CONN_REQ+1            ; ignore bind and connect request messages
    JC   ping_process_rx_complete
    CALL clear_rx_packet
    JMP  ping_next_channel    

ping_process_rx_complete:
    CALL clear_rx_packet  
    CALL setup_rx                     ; toggle receive on/off so that the next RSSI reading will be new
    JMP  ping_loop


;**********************************************************
;
;       bind_mode:
;
;**********************************************************
bind_mode:
    MOV  A, BIND_INIT_CHANNEL       ; set the channel to the bind channel subset
    MOV  [channel], A
    
    MOV  A, BIND_PN_CODE
    CALL radio_load_pn_code
    CALL setup_rx                   ; set the radio into RX mode...
    
    MOV  A, 00h                     ; initialize the RX variables and timers
    MOV  [mode_timer], A
	MOV  [timer], A
    MOV  [tx_ack_pending], A

    CALL bind_leds                  ; LEDs flash in bind mode

    MOV  A, BIND_PA_BIAS            ; Allows binding at a lower PA to reduce the bind range
    MOV  [reg_data], A
    MOV  A, REG_PA
    MOV  [reg_addr], A
    CALL SPI_write

bind_loop:
    IOWR watchdog

    IORD port0                      
    AND  A, IRQ                      
    JZ   bind_loop_time_check
    CALL process_rx_int             ; Process Rx interrupt from radio
    
bind_packet:
    CMP  A, bFLAG_EOF               ; check for EOF
    JNZ  bind_loop
    
    CALL verify_packet
    CMP  A, bFLAG_VALID              ; check if the packet is valid
    JNZ  bind_dump_packet

    MOV  A, [packet_type]           ; Check for Bind Request packet
    CMP  A, PT_BIND_REQ
    JZ   bind_process_req
    
    CMP  A, PT_ACK                  ; We are only looking for BIND_REQ and ACK packets, ignore everything else
    JNZ  bind_dump_packet
   
    MOV  A, [tx_ack_pending]
    AND  A, bWAIT_FOR_ACK_A         ; If we aren't waiting for an ACK, ignore it.
    JZ   bind_dump_packet

    CALL clear_rx_packet
    
    MOV  A, [rx_buffer+LEN_BIND_REQUEST]     ; device ID is temporarily stored at rx_buffer+LEN_BIND_REQUEST
    AND  A, 01h                     ; check to see if device is A or B
    JNZ  bind_clear_sequence_b	

bind_key_gen:
    IFDEF ENCRYPT_DATA_A            ; this is for encryption only
    CALL key_gen                    ; generates encryption key
    ENDIF ; ENCRYPT_DATA_A

bind_clear_sequence_a:
	MOV  A, 0
	MOV  [sequence_id_a], A
    JMP  bind_store_device_id

bind_clear_sequence_b:
	MOV  A, 0
	MOV  [sequence_id_b], A

bind_store_device_id:
IFNDEF PROTOCOL_1_1                 ; Protocol 1.1 does not store the peripherals mid
    MOV  A, [rx_buffer+LEN_BIND_REQUEST]     ; device ID is temporarily stored at rx_buffer+LEN_BIND_REQUEST
    AND  A, 01h                     ; just set the low bit for use in the E2 function
        CALL E2_put_device_id
ENDIF ; PROTOCOL_1_1

    MOV  A, PING_REASON_NORMAL      ; jumping for normal reason
    JMP  ping_mode                  ; bind mode successful!


bind_process_req:
    ; check the length to make sure it is a valid bind packet
    MOV  A, [rx_counter]
    CMP  A, LEN_BIND_REQUEST
    JNZ  bind_dump_packet

    MOV  A, [rx_buffer]             ; received a bind request... process it
    AND  A, 0eh                     ; extract the Device Type field
    ASR 
    
    MOV  [rx_buffer+LEN_BIND_REQUEST], A     ; store the Device Type for later...
    
    CMP  A, DEVICE_TYPE_A
    JZ   bind_response

IFDEF COMBO_DEVICE
    CMP  A, DEVICE_TYPE_B
    JZ   bind_response
ENDIF   ; COMBO_DEVICE

bind_dump_packet:
    CALL clear_rx_packet            ; not a good bind request

bind_loop_time_check:                  ;
    MOV  A, [timer]                 ; Check to see if we need to change channels
    CMP  A, BIND_CHANNEL_TIMEOUT    ; end bind mode, reinit radio, etc. 
    JC   bind_loop                  
    
    INC  [mode_timer]
    MOV  A, [mode_timer]
    CMP  A, BIND_TIMEOUT
    JC   bind_set_channel
    MOV  A, PING_REASON_NORMAL      ; jumping for normal reason
    JMP  ping_mode                  ; bind timed out, switch to ping mode
    
bind_set_channel: 
IFNDEF BIND_NO_HOP
    MOV  A, [channel]               ; slowly loop through the bind channel subset
    ADD  A, 6
    CMP  A, NUM_CHANNELS             
    JC   bind_good_channel
    
    SUB  A, NUM_CHANNELS            ; loop around to the beginning if we went past the end

bind_good_channel:
    MOV  [channel], A               ; set the channel to be loaded in the radio
ENDIF ; BIND_NO_HOP
    CALL setup_rx                   ; set the radio into RX mode...
    MOV  A, 00h
    MOV  [tx_ack_pending], A        ; if we are switching channels, clear the bWAIT_FOR_ACK_A flag...
    MOV  [timer], A                 ; reset timer every time we switch channels

bind_loop_complete:    
    CALL bind_leds
    JMP  bind_loop

bind_response:
    MOV  A, LEN_BIND_RESPONSE
    MOV  [tx_sys_counter], A        ; set the packet length
     
IFDEF PROTOCOL_1_1
    MOV  A, BIND_RSP_DATA
    MOV  [tx_sys_buffer], A

    MOV  X, 3                   
bind_load_mid_loop:
    MOV  A, [x+bridge_mid1]         ; load the bridge MID into the tx buffer
    MOV  [x+1+tx_sys_buffer], A
    DEC  X
    JNC  bind_load_mid_loop

    MOV  A, BIND_CHECKSUM_SEED      ; use the bind checksum seed to calculate the checksum
    CALL set_sys_checksum
ELSE
    MOV  A, [pn_code]       ; fill in the PN_CODE
    MOV  [tx_sys_buffer + 2], A      

    MOV  A, [checksum_seed]
    MOV  [tx_sys_buffer+3], A       ; load the checksum seed

    MOV  A, [base_channel]          ; load the channel
    MOV  [tx_sys_buffer + 1], A
     
    MOV  A, [network_pin]
    AND  A, 07h                     ; make sure PIN is only 3 bits
    ASL                             ; move into proper position
    OR   A, PT_BIND_RSP             ; set the packet type
    MOV  [tx_sys_buffer], A         ; load into buffer
    
    CALL set_sys_parity
    MOV  A, BIND_CHECKSUM_SEED      ; use the bind checksum seed to calculate the checksum
    CALL set_sys_checksum
    
 ; Move the Manufacturing ID clear of the ACK
	MOV  A, 3
	MOV  X, A
move_id_loop:
	MOV  A, [X+rx_buffer+1]
	MOV  [X+rx_buffer+10], A
	DEC  X
	JNC move_id_loop
ENDIF ; PROTOCOL_1_1

    CALL switch_tx    
    CALL transmit_sys               ; transmit packet
    CALL switch_rx                  ; switch to RX mode to receive ACK

    CALL clear_rx_packet    
    MOV  A, bWAIT_FOR_ACK_A
    MOV  [tx_ack_pending], A
    MOV  A, 00h                     ; clear the timer so that we wait
    MOV  [timer], A                 ; for the ACK the full 48 ms

    JMP  bind_loop



;-------------------------------------------------------
;
;   process_conn_req:
;
;-------------------------------------------------------
process_conn_req:
    ; check packet length
    MOV  A, [rx_counter]            ; check the packet length to see if packet is right length
    CMP  A, LEN_CONN_REQUEST
IFNDEF DYNAMIC_PA_SUPPORT
    JNZ  conn_req_failed            ; Dynamic PA adds one byte to the Connect Request Packet length
ELSE
    JZ   conn_req_length_ok
    CMP  A, LEN_CONN_REQUEST+1
    JNZ  conn_req_failed
ENDIF ; DYNAMIC_PA_SUPPORT

conn_req_length_ok:
IFDEF PROTOCOL_1_1
    MOV  X, 3                   
compare_mid_loop:
    MOV  A, [x+1+rx_buffer]         ; compare the bridge MID with the received MID
    CMP  A, [x+bridge_mid1]
    JNZ  bad_conn_req
    DEC  X
    JNC  compare_mid_loop

IFDEF DYNAMIC_PA_SUPPORT
    MOV  A, [rx_counter]
    CMP  A, LEN_CONN_REQUEST
    JZ   store_default_pa
    CMP  A, LEN_CONN_REQUEST+1      ; check for PA value in connect request packet
    JNZ  conn_req_failed
    MOV  A, [rx_buffer]
    ASR
    AND  A, 01h                   
    CMP  A, 01h
    JZ   store_pa_b                 ; device type is stored in bits 1-3 of the packet header

store_pa_a:
IFDEF DYNAMIC_PA_SUPPORT
    MOV  A, [PA_POSITION+rx_buffer]           ; load the PA from the received CONNECT REQUEST packet
    MOV  [pa_bias_a], A
    CALL set_pa_a
ENDIF ; DYNAMIC_PA_SUPPORT
    JMP  good_conn_req

store_pa_b:
IFDEF DYNAMIC_PA_SUPPORT
    MOV  A, [PA_POSITION+rx_buffer]           ; load the PA from the received CONNECT REQUEST packet
    MOV  [pa_bias_b], A
    CALL set_pa_b
ENDIF ; DYNAMIC_PA_SUPPORT
   JMP  good_conn_req

store_default_pa:                   ; if PA value not included in CONNECT REQUEST packet
    MOV  A, [rx_buffer]             ; just store the default PA value
    ASR
    AND  A, 01h                     
    CMP  A, 01h
    JNZ  store_default_pa_b

store_default_pa_a:
    MOV  A, PA_BIAS                 ; use the default PA
    MOV  [pa_bias_a], A

    CALL set_pa_a
    JMP  good_conn_req

store_default_pa_b:
    MOV  A, PA_BIAS                 ; use the default PA   
    MOV  [pa_bias_b], A
    CALL set_pa_b
ENDIF ; DYNAMIC_PA_SUPPORT
ELSE
    MOV  A, [rx_buffer + 2]         ; check the PN_CODE
    CMP  A, [pn_code]    
    JNZ  bad_conn_req

    MOV  A, [rx_buffer + 1]         ; check the network channel
    CMP  A, [base_channel]
    JNZ  bad_conn_req
    
    CALL compare_id               ; check the Manufacturing ID
    AND  A, ffh
    JZ   bad_conn_req    
ENDIF ; PROTOCOL_1_1
    
good_conn_req:                      ; everything matches, so this is a good connect reqest
    MOV  A, CONN_RSP_YES            ; send a CONNECT RESPONSE packet         
    MOV  [tx_sys_buffer], A

    MOV  A, LEN_CONN_RESPONSE       ; CONNECT RESPONSE packet length
    MOV  [tx_sys_counter], A    
IFDEF CHECKSUM_ALL_PACKETS
	MOV  A, [checksum_seed]			; A = checksum seed
	CALL set_sys_checksum			; calculate the checksum
ENDIF ; CHECKSUM_ALL_PACKETS

conn_rsp_transmit:
    CALL transmit_sys               ; transmit the CONNECT RESPONSE packet
    JMP  process_packet_complete

;-------------------------------------------------------
;   bad_conn_req:
;-------------------------------------------------------
bad_conn_req:
    MOV  A, CONN_RSP_NO             ; send a negative CONNECT RESPONSE packet
    MOV  [tx_sys_buffer], A
    MOV  A, 1                       ; CONNECT RESPONSE packet length
    MOV  [tx_sys_counter], A    

    CALL transmit_sys
    
conn_req_failed:    
    JMP  process_packet_complete

IFNDEF PROTOCOL_1_1
;-------------------------------------------------------
;
;   compare_id
;
;-------------------------------------------------------
compare_id:                         ; compares received MID with stored MIDs
    MOV  A, 0
    CALL E2_get_device_id
    
    ; compare with received ID
    MOV  A, [rx_buffer+3]
    CMP  A, [valid_buffer+3]
    JNZ  compare_id2

    MOV  A, [rx_buffer+4]
    CMP  A, [valid_buffer+4]
    JNZ  compare_id2

    MOV  A, [rx_buffer+5]
    CMP  A, [valid_buffer+5]
    JNZ  compare_id2

    MOV  A, [rx_buffer+6]
    CMP  A, [valid_buffer+6]
    JNZ  compare_id2
    
    MOV  A, 1                       ; compare succeeded
    RET 
    
compare_id2:
    MOV  A, 1
    CALL E2_get_device_id
    
    ; compare with received ID
    MOV  A, [rx_buffer+3]
    CMP  A, [valid_buffer+3]
    JNZ  compare_id_failed

    MOV  A, [rx_buffer+4]
    CMP  A, [valid_buffer+4]
    JNZ  compare_id_failed

    MOV  A, [rx_buffer+5]
    CMP  A, [valid_buffer+5]
    JNZ  compare_id_failed

    MOV  A, [rx_buffer+6]
    CMP  A, [valid_buffer+6]
    JNZ  compare_id_failed
    
    MOV  A, 1                       ; compare succeeded
    RET 

compare_id_failed:
    MOV  A, 0
    RET 
    
ENDIF ; PROTOCOL_1_1

;-------------------------------------------------------
;
;   send_ping_rsp
;
;-------------------------------------------------------
send_ping_rsp:
    MOV  A, PING_RSP_DATA           ; send a PING response packet
    MOV  [tx_sys_buffer], A

    MOV  A, LEN_PING                 ; PING packet length
    MOV  [tx_sys_counter], A    

IFDEF CHECKSUM_ALL_PACKETS
	MOV  A, BIND_CHECKSUM_SEED		; A = checksum seed
	CALL set_sys_checksum			; calculate the checksum
ENDIF ; CHECKSUM_ALL_PACKETS

    CALL transmit_sys               ; transmit the packet
    JMP  process_packet_complete

;-------------------------------------------------------
;
;   check_rssi
;
;   Return: A = RSSI reading
;           X = rssi_counter
;-------------------------------------------------------
check_rssi:
     ; check the RSSI to see if this channel is noisy
    MOV  A, REG_RSSI
    MOV  [reg_addr], A
    CALL SPI_read
    CALL SPI_read
    MOV  A, [reg_data]
    CMP  A, bRSSI_VALID
    JNC  rssi_valid
    MOV  X, 0
    JMP  rssi_low                   ; ignore invalid RSSI readings
         
rssi_valid:
    AND  A, mRSSI
    MOV  X, A                       ; store the RSSI reading in X
    CMP  A, RSSI_LOUD_THRESHOLD
    JC   rssi_low
    INC  [rssi_counter]          ; rssi_counter is incremented 2 every high RSSI reading
    MOV  A, [rssi_counter]
    SWAP A, X                       ; 
    RET
    
rssi_low:
    MOV  A, 0                       ; RSSI counter is now reset every low RSSI reading...
    MOV  [rssi_counter], A
    SWAP A, X
    RET
    
