;****************************************************************************
;
;   file:           bind-basic.asm
;   Description:    This file contains basic bind AND  fixed bind procedures
;   External Functions:
;                   bind_init
;                   bind_process

;   Target:         Cypress CY7C63723/CY7C63743 Encore Chips
;   $Header: g:/archives/Projects/LS DVK P2/Dongle/Two Way/bind-basic.asm
;   Version:        1.3.0000
;
;****************************************************************************
; Copyright (2003), Cypress Semiconductor Corporation
; This software is owned by Cypress Semiconductor Corporation (Cypress) and  is
; protected by United States copyright laws and international treaty provisions.
; Cypress hereby grants to Licensee a personal, non-exclusive, non-transferable
; license to copy, use, modify, create derivative works of, and compile the
; Cypress Source Code and derivative works for the sole purpose of creating
; custom software in support of Licensee product ("Licensee Product") to be used
; only in conjunction with a Cypress integrated circuit. Any reproduction,
; modification, translation, compilation, or representation of this software
; except as specified above is prohibited without the express written permission
; of Cypress.
; Disclaimer: Cypress makes no warranty of any kind, express or implied, with
; regard to this material, including, but not limited to, the implied warranties
; of merchantability and fitness for a particular purpose. Cypress reserves the
; right to make changes without further notice to the materials described herein.
; Cypress does not assume any liability arising out of the application or use of
; any product or circuit described herein. Cypress products described herein are
; not authorized for use as components in life-support devices.
; This software is protected by and subject to worldwide patent coverage,
; including U.S. and foreign patents. Use may be limited by and subject to the
; Cypress Software License Agreement.
;
;****************************************************************************


IFDEF BIND_BASIC

DEFAULT_PN_CODE:        equ 03h
DEFAULT_CHECKSUM_SEED:  equ 00h

;-----------------------------------------
;
;   bind_init
;
;   Sets up the PN_CODE AND  channel.
;   The rotary switch selects the channel.
;   The PN_CODE is determined at compile time.
;
;-----------------------------------------
bind_init:
    set_port_1 f0h
    clr_port_1 04h
    IORD port1
    ASR 
    ASR 
    ASR 
    ASR 
    AND  A, 0fh
    XOR  A, 0fh
    MOV  [channel], A               ; set the channel to 5x switch value
    ASL 
    ASL 
    ADD  A, [channel]              
    MOV  [channel], A

    MOV  A, DEFAULT_PN_CODE         ; load the default PN_CODE
    MOV  [pn_code], A
    CALL radio_load_pn_code
    
    MOV  A, DEFAULT_CHECKSUM_SEED
    MOV  [checksum_seed], A
    
    RET 

;-----------------------------------------
;
;   bind_process
;
;   The rotary switch selects the channel.
;   The PN_CODE is determined at compile time
;   AND  is not changed in bind_process
;
;-----------------------------------------
bind_process:
    set_port_1 f0h
    clr_port_1 04h
    IORD port1
    ASR 
    ASR 
    ASR 
    ASR 
    AND  A, 0fh
    XOR  A, 0fh
    MOV  [temp], A                  ; set the channel to 5x switch value
    ASL 
    ASL 
    ADD  A, [temp]              

                                    ; let's compare A with [channel] AND  only change
    CMP  A, [channel]               ; the channel register if the switch has changed position...
    JZ   bind_process_complete      ; channel is already set to current switch position          
    MOV  [channel], A              
    CALL setup_rx                   ; reinit the radio, set the channel AND  VCO, etc.
              
bind_process_complete:
    RET 

ENDIF    ; BIND_BASIC



IFDEF BIND_FIXED
;-----------------------------------------
;
;   bind_init
;
;   Sets up the PN_CODE AND  channel using
;   the default values. BIND_FIXED uses
;   A default channel AND  PN code AND  works
;   without any inputs (buttons, switches, etc).
;
;-----------------------------------------
bind_init:
    MOV  A, DEFAULT_CHANNEL
    MOV  [channel], A
    
    MOV  A, DEFAULT_PN_CODE         ; load the default PN_CODE
    MOV  [pn_code], A
    CALL radio_load_pn_code

    MOV  A, 00h
    MOV  [checksum_seed], A

    RET 
    
    
;-----------------------------------------
;
;   bind_process
;
;-----------------------------------------
bind_process:
    RET 

ENDIF