;****************************************************************************
;
;   file:           gamepad.asm
;   Description:    This file contains gamepad application functions for the LS DVK
;   External Functions:
;                   app_data_received_a
;                   app_idle
;
;   Target:         Cypress CY7C63723/CY7C63743 Encore Chips
;   $Header: g:/archives/Projects/LS DVK P2/Dongle/Two Way/gamepad.asm
;   Version:        1.3.0000
;
;****************************************************************************
; Copyright (2003), Cypress Semiconductor Corporation
; This software is owned by Cypress Semiconductor Corporation (Cypress) and  is
; protected by United States copyright laws and international treaty provisions.
; Cypress hereby grants to Licensee a personal, non-exclusive, non-transferable
; license to copy, use, modify, create derivative works of, and compile the
; Cypress Source Code and derivative works for the sole purpose of creating
; custom software in support of Licensee product ("Licensee Product") to be used
; only in conjunction with a Cypress integrated circuit. Any reproduction,
; modification, translation, compilation, or representation of this software
; except as specified above is prohibited without the express written permission
; of Cypress.
; Disclaimer: Cypress makes no warranty of any kind, express or implied, with
; regard to this material, including, but not limited to, the implied warranties
; of merchantability and fitness for a particular purpose. Cypress reserves the
; right to make changes without further notice to the materials described herein.
; Cypress does not assume any liability arising out of the application or use of
; any product or circuit described herein. Cypress products described herein are
; not authorized for use as components in life-support devices.
; This software is protected by and subject to worldwide patent coverage,
; including U.S. and foreign patents. Use may be limited by and subject to the
; Cypress Software License Agreement.
;
;****************************************************************************

APP_IDLE_TIMEOUT:   equ 30h
NUM_BYTES_A:        equ 08h         ; number of bytes in wireless packet
    
app_init_a:
	RET
;-------------------------------------------------------
;   app_data_received_a
;
;   Sends the data to USB
;-------------------------------------------------------
app_data_received_a:
    swap A, X
    CMP  A, 00h
    JZ   app_data_rcvd_a_complete   ; do not process NULL packets

    MOV  X, NUM_EP1_BYTES-1         ; compare contents of rx data buffer to EP1 buffer.
check_loop_a:                       
    MOV  A, [X + app_buffer] 
    CMP  A, [X + ep1_dmabuff]
    JNZ  load_data_a             
    DEC  X                       
    JNC  check_loop_a
    
    RET                             ; unchanged data, no need to send to USB

    ; load the data into the USB buffer
load_data_a:
    IOWR watchdog                   ; IF last packet not yet gone
    IORD ep1_mode                   ; THEN wait 
    AND  A, 0fh
    CMP  A, 0dh
    JZ   load_data_a
        
    MOV  A, (NUM_BYTES_A - 1)       ; move contents of rx data buffer
    MOV  X, A                       ; to EP1 buffer.
load_loop_a:                          
    MOV  A, [X + app_buffer]      
    MOV  [X + ep1_dmabuff], A         
    DEC  X                           
    JNC  load_loop_a                 

clear_flag_a: 
    MOV  A, 80h                     ; invert data toggle
    XOR  [ep1_data_toggle], A       ;
    MOV  A, NUM_EP1_BYTES           ; set endpoint 1 to send defined number of bytes
    OR    A, [ep1_data_toggle]      ;
    IOWR    ep1_count               ;
    MOV  A, ACK_IN                  ; set to ack on endpoint 1
    IOWR ep1_mode                   ; AND  flag that data is waiting

    MOV   A,0h                     ; led_timer = 0x01; ; BLINK_BIND diag LED
    MOV   [led_timer],A     

app_data_rcvd_a_complete:
    RET 


;-------------------------------------------------------
;   app_idle
;-------------------------------------------------------
app_idle_a:
    RET 

;-------------------------------------------------------
;   app_verify_packet_a
;
;-------------------------------------------------------
app_verify_packet_a:
	SWAP A, X					; A = packet length
	CMP  A, 0Ah
	JNC  app_verify_packet_a_failed

    IORD ep1_mode               ; If still waiting for USB to ACK last data, fail
    AND  A, 0Fh     
    CMP  A, ACK_IN
    JZ   app_verify_packet_a_failed         	       
	MOV  A, 1
	RET	  	

app_verify_packet_a_failed:
	MOV A, 0
	RET

;-------------------------------------------------------
;   app_disconnect_a
;
;-------------------------------------------------------
app_disconnect_a:
    RET