;****************************************************************************
;
;   file:           mfgtest.asm 
;   Description:    This file contains application registers addresses,
;                   constants, etc. 
;   Target:         Cypress CY7C63723/CY7C63743 Encore Chips
;   $Header:
;   Version:        1.3.0000
;
;****************************************************************************
; Copyright (2003), Cypress Semiconductor Corporation
; This software is owned by Cypress Semiconductor Corporation (Cypress) and  is
; protected by United States copyright laws and international treaty provisions.
; Cypress hereby grants to Licensee a personal, non-exclusive, non-transferable
; license to copy, use, modify, create derivative works of, and compile the
; Cypress Source Code and derivative works for the sole purpose of creating
; custom software in support of Licensee product ("Licensee Product") to be used
; only in conjunction with a Cypress integrated circuit. Any reproduction,
; modification, translation, compilation, or representation of this software
; except as specified above is prohibited without the express written permission
; of Cypress.
; Disclaimer: Cypress makes no warranty of any kind, express or implied, with
; regard to this material, including, but not limited to, the implied warranties
; of merchantability and fitness for a particular purpose. Cypress reserves the
; right to make changes without further notice to the materials described herein.
; Cypress does not assume any liability arising out of the application or use of
; any product or circuit described herein. Cypress products described herein are
; not authorized for use as components in life-support devices.
; This software is protected by and subject to worldwide patent coverage,
; including U.S. and foreign patents. Use may be limited by and subject to the
; Cypress Software License Agreement.
;
;****************************************************************************

MFG_PN_CODE:                equ 1
MFG_CHANNEL:                equ 1
MFG_NUM_PACKETS_HIGH:       equ 0
MFG_NUM_PACKETS_LOW:        equ 200
MFG_CHECKSUM_SEED:          equ 0

MFG_RX_TIMEOUT:             equ 15      ; each tick is 200ms
MFG_EOF_TIMEOUT:            equ 0
MFG_PACKET_SIZE:            equ 5       ; size of packet
MFG_RESULT_PACKET_SIZE:     equ 10
MFG_NUM_PACKETS:            equ 0
MFG_PRE_TEST_DELAY:         equ 10
MFG_PRE_TX_DELAY:           equ 20       ; ms
MFG_INTER_TX_DELAY:         equ 5       ; ms
MFG_NUM_RESULTS_PACKETS:    equ 10
MFG_PRE_RESULTS_DELAY:      equ 100
MFG_INTER_RESULTS_DELAY:    equ 5
MFG_THRESHOLD_L:            equ 1
MFG_THRESHOLD_H:            equ 31
MFG_PA_BIAS:                equ 7

MFG_DATA_FILLER:            equ 41h     ; ASCII 'A'
MFG_HEADER_TX_DATA:         equ F1h
MFG_HEADER_RESULTS1:        equ FBh
MFG_HEADER_RESULTS2:        equ FDh
MFG_HEADER_RESULTS3:        equ FEh


total_received_bits_low:    equ C1h
total_received_bits_high:   equ C0h
bits_in_packet:             equ C2h
mfg_timer:                  equ C3h     ; increments every 200ms
tx_packet_num_low:          equ C4h
tx_packet_num_high:         equ C5h
;mfg_led_counter:            equ C6h

mfg_test_mode:
    MOV  A, 0
    MOV  [app_timer], A
    mfg_pre_test_delay:
        CALL mfg_leds
        MOV  A, [app_timer]
        CMP  A, MFG_PRE_TEST_DELAY
        JC   mfg_pre_test_delay

    ; initialize radio
    CALL radio_init                 ; set up the radio

    ; set PN code
    MOV  A, MFG_PN_CODE
    CALL radio_load_pn_code

    ; set EOF
    MOV  A, REG_SERDES_CTL
    MOV  [reg_addr], A
    MOV  A, (bSERDES_ENABLE | (mEND_OF_FRAME_LEN & MFG_EOF_TIMEOUT))
    MOV  [reg_data], A
    CALL SPI_write

    ; set correlator thresholds
    MOV  A, REG_THOLD_L
    MOV  [reg_addr], A
    MOV  A, MFG_THRESHOLD_L
    MOV  [reg_data], A
    CALL SPI_write

    MOV  A, REG_THOLD_H
    MOV  [reg_addr], A
    MOV  A, MFG_THRESHOLD_H
    MOV  [reg_data], A
    CALL SPI_write

    ; set PA Bias
    MOV  A, REG_PA
    MOV  [reg_addr], A
    MOV  A, (MFG_PA_BIAS & mPA_BIAS)
    MOV  [reg_data], A
    CALL SPI_write

    ; set the channel
    MOV  A, MFG_CHANNEL
    MOV  [channel], A

    mfg_test_loop:
    
        ; enter receive mode
        CALL setup_rx
    
        MOV  A, 0
        MOV  [total_received_bits_low], A
        MOV  [total_received_bits_high], A
        MOV  [app_timer], A

        mfg_rx_loop:
            IOWR watchdog

            IORD port0
            AND  A, IRQ
            JZ   mfg_rx_time_check
            CALL process_rx_int                  

            MOV  A, [rx_counter]             
            AND  A, ffh                      
            JZ   mfg_rx_time_check

            CMP  A, bFLAG_EOF
            JNZ  mfg_rx_loop

            ; process received packet
            MOV  A, 0
            MOV  [bits_in_packet], A
            MOV  [app_timer], A

            mfg_rx_process_packet:
                DEC  [rx_counter]
                JC   mfg_rx_tally_bits
                
                    MOV  X, [rx_counter]
                    MOV  A, [X+valid_buffer]
                    MOV  [ls_temp], A
                
                mfg_rx_process_byte:
                    AND  A, 01h
                    JZ   mfg_rx_bit_low
                    INC  [bits_in_packet]

                mfg_rx_bit_low:
                    MOV  A, [ls_temp]
                    ASR  A
                    AND  A, 7Fh         ; ASR doesn't shift a zero into the MSb
                    MOV  [ls_temp], A
                    JZ   mfg_rx_process_packet     ; process the next byte
                    JMP  mfg_rx_process_byte
                
            mfg_rx_tally_bits:
                MOV  A, [bits_in_packet]
                CMP  A, 04h
                JC   mfg_rx_time_check
                ADD  A, [total_received_bits_low]
                JNC  mfg_rx_tally_bits_no_carry
                INC  [total_received_bits_high]
            mfg_rx_tally_bits_no_carry:    
                MOV  [total_received_bits_low], A

                MOV  A, 0
                MOV  [rx_counter], A                    ; reset the rx_counter so that we can correctly receive the next packet


            mfg_rx_last_packet_check:
                MOV  A, [rx_buffer+2]
                CMP  A, MFG_NUM_PACKETS_LOW
                JNZ  mfg_rx_time_check

                MOV  A, [rx_buffer+1]
                CMP  A, MFG_NUM_PACKETS_HIGH
                JZ  mfg_rx_done                    ; last packet was received, don't wait for the timeout

            mfg_rx_time_check:
                CALL mfg_leds
                MOV  A, [total_received_bits_low]
                CMP  A, 00h
                JNZ   mfg_rx_time_check_valid

                MOV  A, [total_received_bits_high]
                CMP  A, 00h
                JNZ   mfg_rx_time_check_valid
        
            mfg_rx_reset_time:
                MOV  A, 0
                MOV  [app_timer], A                        
                JMP  mfg_rx_loop

            mfg_rx_time_check_valid:
                MOV  A, [app_timer]
                CMP  A, 200
                JC   mfg_rx_loop
                INC  [mfg_timer]
                MOV  A, [mfg_timer]
                CMP  A, MFG_RX_TIMEOUT
                JC   mfg_rx_loop

                JMP  mfg_rx_done

        mfg_rx_done:
            ; delay for specified time period
            MOV  A, 0
            MOV  [app_timer], A

            mfg_pre_transmit_delay:
            CALL mfg_leds
            MOV  A, [app_timer]
            CMP  A, MFG_PRE_TX_DELAY
            JC   mfg_pre_transmit_delay


        mfg_tx_build_packet:
            MOV  A, 0
            MOV  [tx_packet_num_high], A
            MOV  [tx_packet_num_low], A

            MOV  A, MFG_HEADER_TX_DATA
            MOV  [tx_sys_buffer], A

            MOV  A, MFG_DATA_FILLER
            MOV  X, MFG_PACKET_SIZE - 4       ; header, checksum, 2-byte packet number
            
            mfg_tx_packet_filler:
                MOV  [X+tx_sys_buffer+2], A
                INC  A
                DEC  X
                JNZ  mfg_tx_packet_filler

        mfg_tx_packet_loop:
            CALL setup_tx
            CALL mfg_leds
            MOV  A, [tx_packet_num_low]
            MOV  [tx_sys_buffer+2], A
            MOV  A, [tx_packet_num_high]
            MOV  [tx_sys_buffer+1], A

            ; increment packet number....
            INC  [tx_packet_num_low]
            JNC  mfg_tx_set_checksum
            INC  [tx_packet_num_high]

        mfg_tx_set_checksum:
            MOV  A, MFG_PACKET_SIZE
            MOV  [tx_sys_counter], A

            MOV  A, MFG_CHECKSUM_SEED  
            CALL set_sys_checksum

            CALL transmit_sys
            CALL radio_idle

        mfg_tx_check_complete:
            MOV  A, [tx_packet_num_low]
            CMP  A, MFG_NUM_PACKETS_LOW
            JNZ  mfg_tx_packet_done

            MOV  A, [tx_packet_num_high]
            CMP  A, MFG_NUM_PACKETS_HIGH
            JZ   mfg_tx_done                    ; last packet was transmitted

        mfg_tx_packet_done:
            MOV  A, 0
            MOV  [app_timer], A

            mfg_tx_inter_packet_delay:
            CALL mfg_leds
            MOV  A, [app_timer]
            CMP  A, MFG_INTER_TX_DELAY
            JC   mfg_tx_inter_packet_delay
           
            JMP  mfg_tx_packet_loop             ; this packet is finished, go to the next packet


        mfg_tx_done:
            MOV  A, 0
            MOV  [app_timer], A

            mfg_pre_results_delay:
            MOV  A, [app_timer]
            CMP  A, MFG_PRE_RESULTS_DELAY
            JC   mfg_pre_results_delay

       mfg_results_1:
            MOV  A, MFG_HEADER_RESULTS1
            MOV  [tx_sys_buffer], A

            MOV  A, MFG_NUM_PACKETS_HIGH
            MOV  [tx_sys_buffer+1], A
            MOV  A, MFG_NUM_PACKETS_LOW
            MOV  [tx_sys_buffer+2], A

            MOV  A, 0
            MOV  [tx_sys_buffer+3], A
            MOV  [tx_sys_buffer+4], A
            MOV  [tx_sys_buffer+5], A
            MOV  [tx_sys_buffer+6], A

            MOV  A, [total_received_bits_high]
            MOV  [tx_sys_buffer+7], A
            MOV  A, [total_received_bits_low]
            MOV  [tx_sys_buffer+8], A

            MOV  A, MFG_RESULT_PACKET_SIZE
            MOV  [tx_sys_counter], A

            MOV  A, MFG_CHECKSUM_SEED  
            CALL set_sys_checksum

            MOV  A, MFG_NUM_RESULTS_PACKETS
            MOV  [ls_temp], A
        mfg_results_1_transmit:
            CALL switch_tx
            CALL transmit_sys
            CALL radio_idle
            
            MOV  A, [ls_temp]
            DEC  A
            JZ   mfg_results_2
            MOV  [ls_temp], A

            MOV  A, 0
            MOV  [app_timer], A
            mfg_results_1_delay:
                CALL mfg_leds
                MOV  A, [app_timer]
                CMP  A, MFG_INTER_RESULTS_DELAY
                JC   mfg_results_1_delay
                JMP  mfg_results_1_transmit                

        mfg_results_2:
            MOV  A, MFG_HEADER_RESULTS2
            MOV  [tx_sys_buffer], A

            MOV  A, 0
            MOV  [tx_sys_buffer+1], A
            MOV  [tx_sys_buffer+2], A
            MOV  [tx_sys_buffer+3], A
            MOV  [tx_sys_buffer+4], A
            MOV  [tx_sys_buffer+5], A
            MOV  [tx_sys_buffer+6], A
            MOV  [tx_sys_buffer+7], A
            MOV  [tx_sys_buffer+8], A

            MOV  A, MFG_RESULT_PACKET_SIZE
            MOV  [tx_sys_counter], A

            MOV  A, MFG_CHECKSUM_SEED  
            CALL set_sys_checksum

            MOV  A, MFG_NUM_RESULTS_PACKETS
            MOV  [ls_temp], A
        mfg_results_2_transmit:
            CALL switch_tx
            CALL transmit_sys
            CALL radio_idle
            
            MOV  A, [ls_temp]
            DEC  A
            JZ   mfg_results_3
            MOV  [ls_temp], A

            MOV  A, 0
            MOV  [app_timer], A
            mfg_results_2_delay:
                CALL mfg_leds
                MOV  A, [app_timer]
                CMP  A, MFG_INTER_RESULTS_DELAY
                JC   mfg_results_2_delay
                JMP  mfg_results_2_transmit                

        mfg_results_3:
            MOV  A, MFG_HEADER_RESULTS3
            MOV  [tx_sys_buffer], A

            MOV  A, 0
            MOV  [tx_sys_buffer+1], A
            MOV  [tx_sys_buffer+2], A
            MOV  [tx_sys_buffer+3], A
            MOV  [tx_sys_buffer+4], A
            MOV  [tx_sys_buffer+5], A
            MOV  [tx_sys_buffer+6], A
            MOV  [tx_sys_buffer+7], A
            MOV  [tx_sys_buffer+8], A

            MOV  A, MFG_RESULT_PACKET_SIZE
            MOV  [tx_sys_counter], A

            MOV  A, MFG_CHECKSUM_SEED  
            CALL set_sys_checksum

            MOV  A, MFG_NUM_RESULTS_PACKETS
            MOV  [ls_temp], A
        mfg_results_3_transmit:
            CALL switch_tx
            CALL transmit_sys
            CALL radio_idle
            
            MOV  A, [ls_temp]
            DEC  A
            JZ   mfg_test_complete
            MOV  [ls_temp], A

            MOV  A, 0
            MOV  [app_timer], A
            mfg_results_3_delay:
                CALL mfg_leds
                MOV  A, [app_timer]
                CMP  A, MFG_INTER_RESULTS_DELAY
                JC   mfg_results_3_delay
                JMP  mfg_results_3_transmit                


    mfg_test_complete:
        JMP  mfg_test_loop      ; just test the data sections for now....


mfg_leds:
    MOV  A, [timer]
    AND  A, 80h
    JNZ  mfg_leds_toggle

    set_port_0 nDATA_LED
    clr_port_1 nBIND_LED
    RET

mfg_leds_toggle:
    clr_port_0 nDATA_LED
    set_port_1 nBIND_LED
    RET
