;****************************************************************************
;
;   file:           bind-kiss.asm
;   Description:    This file contains automatic bind procedures
;   External Functions:
;                   kiss_mode
;
;   Target:         Cypress CY7C63723/CY7C63743 Encore Chips
;   $Header:
;   Version:        1.3.0000
;
;****************************************************************************
; Copyright (2003), Cypress Semiconductor Corporation
; This software is owned by Cypress Semiconductor Corporation (Cypress) and  is
; protected by United States copyright laws and international treaty provisions.
; Cypress hereby grants to Licensee a personal, non-exclusive, non-transferable
; license to copy, use, modify, create derivative works of, and compile the
; Cypress Source Code and derivative works for the sole purpose of creating
; custom software in support of Licensee product ("Licensee Product") to be used
; only in conjunction with a Cypress integrated circuit. Any reproduction,
; modification, translation, compilation, or representation of this software
; except as specified above is prohibited without the express written permission
; of Cypress.
; Disclaimer: Cypress makes no warranty of any kind, express or implied, with
; regard to this material, including, but not limited to, the implied warranties
; of merchantability and fitness for a particular purpose. Cypress reserves the
; right to make changes without further notice to the materials described herein.
; Cypress does not assume any liability arising out of the application or use of
; any product or circuit described herein. Cypress products described herein are
; not authorized for use as components in life-support devices.
; This software is protected by and subject to worldwide patent coverage,
; including U.S. and foreign patents. Use may be limited by and subject to the
; Cypress Software License Agreement.
;
;****************************************************************************

IFDEF KISS_BIND_SUPPORT
;**********************************************************
;
;       kiss_mode:
;
;**********************************************************
KISS_RX_CHANNEL:    equ 77
KISS_TX_CHANNEL:    equ 77
KISS_PA_BIAS:       equ 0
KISS_TIMEOUT:       equ 250

KISS_XTL_ADJ:       equ 1Fh

KISS_BIND_RSSI:     equ 0Ch

kiss_mode:
    MOV  A, REG_PA
    MOV  [reg_addr], A
    MOV  A, KISS_PA_BIAS
    MOV  [reg_data], A
    CALL SPI_write

    ; disable Force CDET for RSSI reading of the link
    MOV  A, REG_CARRIER_DETECT
    MOV  [reg_addr], A
    MOV  A, 0
    MOV  [reg_data], A
    CALL SPI_write

    ; tighten up the correlator thresholds
    MOV  A, REG_THOLD_L
    MOV  [reg_addr], A
    MOV  A, 0
    MOV  [reg_data], A
    CALL SPI_write

    MOV  A, REG_THOLD_H
    MOV  [reg_addr], A
    MOV  A, 32
    MOV  [reg_data], A
    CALL SPI_write

    MOV  A, KISS_RX_CHANNEL
    MOV  [channel], A
    CALL setup_rx                   ; set the radio into RX mode...
    
    ; enable AGC
    MOV  A, REG_AGC_CTL
    MOV  [reg_addr], A
    MOV  A, bAGC_ON 
    MOV  [reg_data], A
    CALL SPI_write

    ; force attenuation
    CALL delay200us
    CALL delay50us

    MOV  A, REG_CARRIER_DETECT
    MOV  [reg_addr], A
    MOV  A, 02h
    MOV  [reg_data], A
    CALL SPI_write
    
    MOV  A, 00h
    MOV  [reg_data], A
    CALL SPI_write

    MOV  A, 02h
    MOV  [reg_data], A
    CALL SPI_write
    
    MOV  A, 00h
    MOV  [reg_data], A
    CALL SPI_write

    MOV  A, 02h
    MOV  [reg_data], A
    CALL SPI_write
   
    MOV  A, 00h
    MOV  [reg_data], A
    CALL SPI_write

    MOV  A, 02h
    MOV  [reg_data], A                              
    CALL SPI_write
    
    MOV  A, 00h
    MOV  [reg_data], A
    CALL SPI_write

    MOV  A, 00h
	MOV  [timer], A


kiss_loop:
    IOWR watchdog

    IORD port0                      ; IF interrupt 
    AND  A, IRQ                      
    JZ   kiss_loop_time_check
    CALL process_rx_int             ; THEN check interrupt 
    
kiss_packet:
    CMP  A, bFLAG_EOF
    JNZ  kiss_loop
    
    CALL verify_packet
    
    CMP  A, bFLAG_VALID
    JNZ  kiss_dump_packet

    MOV  A, [packet_type]           ; Check for Bind Request packet
    CMP  A, PT_BIND_REQ
    JNZ  kiss_dump_packet

    MOV  A, REG_RSSI                ; Check the RSSI
    MOV  [reg_addr], A
    CALL SPI_read
    MOV  A, [reg_data]
    CMP  A, bRSSI_VALID
    JC   kiss_dump_packet
    AND  A, mRSSI
    CMP  A, KISS_BIND_RSSI
    JC   kiss_dump_packet

kiss_process_req:
    ; check the length to make sure it is a valid bind packet
    MOV  A, [rx_counter]
    CMP  A, LEN_BIND_REQUEST
    JNZ  kiss_dump_packet

    MOV  A, [rx_buffer]             ; received a bind request... process it
    AND  A, 0eh                     ; extract the Device Type field
    ASR 

    MOV  [rx_buffer+LEN_BIND_REQUEST], A     ; store the Device Type for later...
    
    CMP  A, DEVICE_TYPE_A
    JZ   kiss_response

IFDEF COMBO_DEVICE
    CMP  A, DEVICE_TYPE_B
    JZ   kiss_response
ENDIF   ; COMBO_DEVICE

kiss_dump_packet:
    CALL clear_rx_packet            ; not a good bind request
    CALL radio_idle
    CALL setup_rx

kiss_loop_time_check:                  ;
    MOV  A, [timer]                 ; Check to see if we need to change channels
    CMP  A, KISS_TIMEOUT    ; end bind mode, reinit radio, etc. 
    JC   kiss_loop                  
    
    JMP  kiss_complete    

kiss_response:
    MOV  A, LEN_BIND_RESPONSE
    MOV  [tx_sys_counter], A        ; set the packet length
     
    MOV  A, BIND_RSP_DATA
    MOV  [tx_sys_buffer], A

    CALL read_radio_mid

    MOV  A, BIND_CHECKSUM_SEED      ; signals a bind packet to set_sys_checksum
    CALL set_sys_checksum

    CALL switch_tx    
    CALL transmit_sys               ; transmit packet

kiss_complete:
    ; fix the thresholds and the clock
    MOV  A, REG_THOLD_L
    MOV  [reg_addr], A
    MOV  A, THRESHOLD_L
    MOV  [reg_data], A
    CALL SPI_write

    MOV  A, REG_THOLD_H
    MOV  [reg_addr], A
    MOV  A, THRESHOLD_H
    MOV  [reg_data], A
    CALL SPI_write

    ; disable AGC
    MOV  A, REG_AGC_CTL
    MOV  [reg_addr], A
    MOV  A, bAGC_OFF
    MOV  [reg_data], A
    CALL SPI_write

    ; fix the PA
    MOV  A, 7
    MOV  [reg_data], A
    MOV  A, REG_PA
    MOV  [reg_addr], A
    CALL SPI_write

    ; enable Force CDET
    MOV  A, REG_CARRIER_DETECT
    MOV  [reg_addr], A
    MOV  A, bCDET
    MOV  [reg_data], A
    CALL SPI_write

    MOV  A, PING_REASON_NORMAL      ; jumping for normal reason
    JMP  ping_mode                  ; bind timed out, switch to ping mode


ENDIF ; KISS_BIND_SUPPORT
