;****************************************************************************
;
;   file:           wusb-ls-headers.inc 
;   Description:    This file contains application registers addresses,
;                   constants, etc. 
;   Target:         Cypress CY7C63723/CY7C63743 Encore Chips
;   $Header:
;   Version:        1.3.0000
;
;****************************************************************************
; Copyright (2003), Cypress Semiconductor Corporation
; This software is owned by Cypress Semiconductor Corporation (Cypress) and  is
; protected by United States copyright laws and international treaty provisions.
; Cypress hereby grants to Licensee a personal, non-exclusive, non-transferable
; license to copy, use, modify, create derivative works of, and compile the
; Cypress Source Code and derivative works for the sole purpose of creating
; custom software in support of Licensee product ("Licensee Product") to be used
; only in conjunction with a Cypress integrated circuit. Any reproduction,
; modification, translation, compilation, or representation of this software
; except as specified above is prohibited without the express written permission
; of Cypress.
; Disclaimer: Cypress makes no warranty of any kind, express or implied, with
; regard to this material, including, but not limited to, the implied warranties
; of merchantability and fitness for a particular purpose. Cypress reserves the
; right to make changes without further notice to the materials described herein.
; Cypress does not assume any liability arising out of the application or use of
; any product or circuit described herein. Cypress products described herein are
; not authorized for use as components in life-support devices.
; This software is protected by and subject to worldwide patent coverage,
; including U.S. and foreign patents. Use may be limited by and subject to the
; Cypress Software License Agreement.
;
;****************************************************************************

INCLUDE "usb.inc"
INCLUDE "radio.inc"

;----------------------------------------------------
; RADIO DEFINES
;----------------------------------------------------
BIND_POLL_TIMEOUT:  equ 30h         ; poll rate for bind button, RSSI check, etc.
POLL_TIMEOUT:       equ 14
EOF_BITS:           equ 07h

NUM_CHANNELS:       equ 78          ; number of channels that are used 0 to NUM_CHANNELS-1
CHANNEL_OFFSET:     equ 02

IFDEF DATA_RATE_16
DEFINE              PN_CODE_64_TABLE    
RADIO_MODE:         equ (b64_CHIP_BITS | bNORMAL_DATA_RATE | b6X_OVERSAMPLING)
ENDIF

IFDEF DATA_RATE_32
DEFINE              PN_CODE_32_TABLE
RADIO_MODE:         equ (b32_CHIP_BITS | bNORMAL_DATA_RATE | b6X_OVERSAMPLING)
ENDIF										    

IFDEF DATA_RATE_64
DEFINE              PN_CODE_32_TABLE       
RADIO_MODE:         equ (b32_CHIP_BITS | bDOUBLE_DATA_RATE | b6X_OVERSAMPLING)
ENDIF

IFDEF PN_CODE_64_TABLE
THRESHOLD_L:        equ 8           ; RX correlator lo threshold    
THRESHOLD_H:        equ 56          ; RX correlator hi threshold  
NUM_PN_CODES:       equ 49  
ENDIF

IFDEF PN_CODE_32_TABLE
    THRESHOLD_L:        equ 3           ; RX correlator lo threshold    
    THRESHOLD_H:        equ 29          ; RX correlator hi threshold    
NUM_PN_CODES:       equ 8  
ENDIF

RSSI_NOISE_THRESHOLD:        equ 08h
RSSI_LOUD_THRESHOLD:         equ 0Ah
CHANNELS_PER_RSSI_INCREMENT: equ 2

PING_RSSI_INTERVAL:  equ 1           ; time between RSSI readings in ping_mode (in ms)
PING_NUM_RSSI:       equ 20          ; number of RSSI readings in ping_mode

CORRUPT_THRESHOLD:      equ 10   ; was 6
NUM_BITS_CORRECTABLE:	equ 03
;CONNECT_REQ_CORRUPT_COUNT: equ 00

NUM_HIGH_RSSI_READINGS:     equ 5

bRSSI_NEW:                  equ 00h
bRSSI_READ:                 equ 01h
QUICK_RSSI_TIMEOUT:         equ 02h ; number of ms to wait after toggling RX mode before reading RSSI



;*****************************************
;       Data Memory map
;*****************************************

PSP_BASE:       equ 00h             ; Program stack rises from here
DSP_TOP:        equ dfh             ; Data stack pointer works down from just below EP0 buffer


;------------------------------------------------------
;       LS Protocol Constants
;------------------------------------------------------
bFLAG_EOF:              equ 01h
bFLAG_FIXED:            equ 02h
bFLAG_VALID:            equ 04h


bDEVICE_ID_ACK:         equ 04h
bDEVICE_ID_NULL:        equ 02h
bDEVICE_ID_DATA:        equ 02h

PT_BIND_REQ:            equ 00h
PT_BIND_RSP:            equ 00h
PT_CONN_REQ:            equ 10h
PT_CONN_RSP:            equ 20h
PT_PING:                equ 30h
PT_DATA:                equ 40h
PT_ACK:                 equ 50h
PT_ACKDATA:             equ 60h
PT_NULL:                equ 70h

PT_KISS_BIND_REQ:       equ D0h

bHEADER_FLAG:           equ 08h
bTX_DATA_TOGGLE:        equ 04h
bPARITY:                equ 01h


IFDEF CHECKSUM_ALL_PACKETS
    LEN_ACK:            equ 2
    LEN_NULL:           equ 2
    LEN_PING:           equ 2          
    LEN_CONN_RESPONSE:  equ 2
ELSE
    LEN_ACK:            equ 1
    LEN_NULL:           equ 1
    LEN_PING:           equ 1
    LEN_CONN_RESPONSE:  equ 1
ENDIF   ; CHECKSUM_ALL_PACKETS

IFDEF PROTOCOL_1_1
    IFDEF CHECKSUM_ALL_PACKETS
        LEN_BIND_REQUEST:   equ 2
    ELSE
        LEN_BIND_REQUEST:   equ 1
    ENDIF ; CHECKSUM_ALL_PACKETS
    LEN_BIND_RESPONSE:  equ 6
    LEN_CONN_REQUEST:   equ 6
    BIND_RSP_DATA:      equ 01h ; Header byte for Bind Response packets
ELSE
    LEN_BIND_REQUEST:   equ 6
    LEN_BIND_RESPONSE:  equ 5
    LEN_CONN_REQUEST:   equ 8
ENDIF  ; PROTOCOL_1_1

IFDEF TWO_WAY_DATA              
bWAIT_FOR_ACK_A:    equ 01h
bWAIT_FOR_ACK_B:    equ 02h
ENDIF         ; TWO_WAY_DATA

PING_DATA:          equ 31h        
PING_RSP_DATA:      equ 38h        
CONN_RSP_YES:       equ 29h        
CONN_RSP_NO:        equ 20h        

PING_REASON_NORMAL:     equ 0
PING_REASON_RSSI:       equ 1
PING_REASON_CORRUPT:    equ 2

BIND_CHANNEL_TIMEOUT: equ 132       ; 132 ms on each channel
BIND_TIMEOUT:       equ 95          ; bind listens on each channel five times... Bind mode takes approximately 13 secs

BIND_INIT_CHANNEL:  equ 00h
BIND_PN_CODE:       equ 00h
BIND_CHECKSUM_SEED: equ 00h

MAX_PIN:            equ 07h         ; PIN is A 3-bit value
MIN_PIN:            equ 03h         ; PIN needs to be large enough to jump around a Wi-Fi channel
mPIN_MASK:          equ 03h

PA_POSITION:        equ 5

;------------------------------------------------------
;       Radio-related Variables
;------------------------------------------------------
; USB uses registers up to 36h
port0Shadow:        equ 37h
port1Shadow:        equ 38h
                                
reg_addr:           equ 39h
reg_data:           equ 3Ah

radio_int:          equ 3Bh
channel:            equ 3Ch
pn_code:            equ 3Dh

packet_type:        equ 3Eh
rx_counter:         equ 3Fh
timer:              equ 40h
led_state:          equ 41h
led_timer:          equ 42h
led_timer2:         equ 43h
app_timer:          equ 44h

sequence_id_a:      equ 45h
sequence_id_b:      equ 46h
checksum_a:         equ 47h
checksum_b:         equ 48h

ls_temp:            equ 49h
parity:             equ 4Ah
loop_counter:       equ 4Bh
invalid_bit:        equ 4Ch
corrected_bits:	    equ 4Dh
checksum_seed:      equ 4Eh

button_pushed:      equ 4Fh

; Radio parameters of peripheral devices 
batt_report_req_a:  equ 50h	
battery_a:          equ 51h		; _a = kbd
batt_report_req_b:  equ 52h	
battery_b:          equ 53h		; _b = mouse

; Determines size of RX Buffer, must be at least 10 bytes for encrypted, 8 bytes for unencrypted
RX_BUFFER_LEN:      equ 10
rx_buffer:          equ 70h         ; 70h-79h
app_buffer:         equ 71h         ; skips header byte
valid_buffer:       equ 80h         ; 80h-89h

tx_sys_counter:     equ 90h
tx_sys_buffer:      equ 91h         ; requires 10 bytes

bad_packets_a_low:    equ 54h
bad_packets_a_high:   equ 55h
good_packets_a_low:   equ 56h
good_packets_a_high:  equ 57h

bad_packets_b_low:    equ 58h
bad_packets_b_high:   equ 59h
good_packets_b_low:   equ 5Ah
good_packets_b_high:  equ 5Bh

;----------------------------------------------------
;       Two Way Data
;----------------------------------------------------
IFDEF TWO_WAY_DATA              
tx_app_counter:     equ 5Ch         
tx_data_toggle:     equ 5Dh         
tx_ack_pending:     equ 5Eh         

tx_app_header:      equ 5Fh
tx_app_buffer:      equ 60h         ; requires 9 bytes
ENDIF         ; TWO_WAY_DATA

bridge_mid1:        equ 7Bh
bridge_mid2:        equ 7Ch
bridge_mid3:        equ 7Dh
bridge_mid4:        equ 7Eh

IFDEF DYNAMIC_PA_SUPPORT
pa_bias_a:          equ 8Ah
pa_bias_b:          equ 8Bh
ENDIF ; DYNAMIC_PA_SUPPORT

IFDEF MFG_TEST
in_mfg_test:        equ 8Ch
ENDIF ; MFG_TEST

;----------------------------------------------------
;       Automatic Bind Configuration
;----------------------------------------------------
IFDEF BIND_AUTO
network_pin:        equ 69h
base_channel:       equ 6Ah
ping_channel:       equ 6Bh
mode_timer:         equ 6Ch
corrupt_counter:    equ 6Dh
ping_channel_count: equ 6Eh    
rssi_counter:       equ 6Fh
rssi_threshold:     equ 7Ah    
rssi_state:         equ 7Fh 
ENDIF ; BIND_AUTO

;------------------------------------------------------
;       Semi-automatic Bind Configuration
;------------------------------------------------------
IFDEF BIND_SEMI
BIND_NUM_BYTES:     equ 02h         ; number of data bytes in bind packet (excludes checksum)
PING_TIMER_INIT:    equ 15      

PING_DATA:          equ 5Ah    

BS_BIND:            equ 00h         ; waiting for A bind packet
BS_PING:            equ 01h         ; waiting for A ping packet

BIND_CHANNEL:       equ 77       
BIND_PN_CODE:       equ 00

bind_state:         equ 60h
bind_timer:         equ 61h         ; total time in bind mode (DEC 'd every time we reinit the radio, approximately every 48ms)
ping_timer:         equ 62h         ; time waiting for A ping
ENDIF   ; BIND_SEMI


;------------------------------------------------------
;       Hardware Constants
;------------------------------------------------------

bBUTTON_DOWN:           equ 01h


; port 0
nRESET:                 equ 01h
IRQ:                    equ 02h
DIO0:                   equ 04h
nCS:                    equ 04h 
DIO1:                   equ 08h
nDATA_LED:              equ 08h 
EnSS:                   equ 10h
EMOSI:                  equ 20h
EMISO:                  equ 40h
ESCLK:                  equ 80h


; port 1
nPD_R:                  equ 01h
PWR_EN:                 equ 02h
IFDEF PDC_9168
nBIND_LED:              equ 02h
ENDIF ; PDC_9168
IFDEF PDC_9075
nBIND_LED:              equ 04h
ENDIF ; PDC_9075

; port 2
BIND_BUTTON:            equ 02h


P0_MODE_1_DEFAULT:                 equ (ESCLK |         EMOSI | EnSS | nDATA_LED | nCS |       nRESET) ;BDh ;1011 1101
P0_MODE_0_DEFAULT:                 equ (ESCLK |         EMOSI       )                                  ;A0h ;1010 0000
;P0_DATA_DEFAULT:                  equ (ESCLK | EMISO | EMOSI | EnSS |             nCS |       nRESET) ;F5h ;1111 0101

P0_MODE_1_SUSPEND:                 equ FFh
P0_MODE_0_SUSPEND:                 equ 00h
P0_DATA_SUSPEND:                   equ 1Dh

P1_BITS:                           equ (PWR_EN | nPD_R)
P1_MODE_1_DEFAULT:                 equ FFh
P1_MODE_0_DEFAULT:                 equ 00h
;P1_DATA_DEFAULT:                   equ (PWR_EN | nPD_R) ;03h ;0000 0011

P1_MODE_1_SUSPEND:                 equ FFh
P1_MODE_0_SUSPEND:                 equ 00h
P1_DATA_SUSPEND:                   equ FEh ; continue to hold nPD low during suspend
;P1_DATA_SUSPEND:                   equ FFh


