;****************************************************************************
;
;   file:           radio.inc 
;   Description:    This file contains register definitions for the LS radio
;   Target:         Cypress CY7C63723/CY7C63743 Encore Chips
;   $Header:
;   Version:        1.3.0000
;
;****************************************************************************
; Copyright (2003), Cypress Semiconductor Corporation
; This software is owned by Cypress Semiconductor Corporation (Cypress) and  is
; protected by United States copyright laws and international treaty provisions.
; Cypress hereby grants to Licensee a personal, non-exclusive, non-transferable
; license to copy, use, modify, create derivative works of, and compile the
; Cypress Source Code and derivative works for the sole purpose of creating
; custom software in support of Licensee product ("Licensee Product") to be used
; only in conjunction with a Cypress integrated circuit. Any reproduction,
; modification, translation, compilation, or representation of this software
; except as specified above is prohibited without the express written permission
; of Cypress.
; Disclaimer: Cypress makes no warranty of any kind, express or implied, with
; regard to this material, including, but not limited to, the implied warranties
; of merchantability and fitness for a particular purpose. Cypress reserves the
; right to make changes without further notice to the materials described herein.
; Cypress does not assume any liability arising out of the application or use of
; any product or circuit described herein. Cypress products described herein are
; not authorized for use as components in life-support devices.
; This software is protected by and subject to worldwide patent coverage,
; including U.S. and foreign patents. Use may be limited by and subject to the
; Cypress Software License Agreement.
;
;****************************************************************************

SYNTH_LOCK_COUNT:   equ 100     ; number of ticks to wait for synthesizer to settle
DEFINE              AGC_OFF     ; turn off the automatic gain control

;------------------------------------------------------
;       LS Constants
;------------------------------------------------------
REG_ID:                     equ 00h

REG_SYN_A_CNTR:             equ 01h

REG_SYN_N_CNTR:             equ 02h

REG_CONTROL:                equ 03h
    bRX_ENABLE:             equ 80h
    bTX_ENABLE:             equ 40h
    bPN_CODE_SELECT:        equ 20h
    bAUTO_SYNTH_COUNT:      equ 10h
    bAUTO_PA_DISABLE:       equ 08h
    bPA_ENABLE:             equ 04h
    bAUTO_SYNTH_DISABLE:    equ 02h
    bSYNTH_ENABLE:          equ 01h

REG_DATA_RATE:              equ 04h
    b32_CHIP_BITS:          equ 04h
    b64_CHIP_BITS:          equ 00h
    bNORMAL_DATA_RATE:      equ 00h
    bDOUBLE_DATA_RATE:      equ 02h
    b6X_OVERSAMPLING:       equ 00h
    b12X_OVERSAMPLING:      equ 01h

REG_CONFIG:                 equ 05h
    bCMOS:                  equ 01h
    bCMOS_INVERTED:         equ 00h

REG_SERDES_CTL:             equ 06h
    bSERDES_ENABLE:         equ 08h
    mEND_OF_FRAME_LEN:      equ 07h

REG_RX_INT_EN:              equ 07h

REG_RX_INT_STAT:            equ 08h
    bRX_VALID_B:            equ 80h
    bRX_OVER_B:             equ 40h
    bRX_EOF_B:              equ 20h
    bRX_FULL_B:             equ 10h
    bRX_VALID_A:            equ 08h
    bRX_OVER_A:             equ 04h
    bRX_EOF_A:              equ 02h
    bRX_FULL_A:             equ 01h

REG_RX_DATA_A:              equ 09h

REG_RX_VALID_A:             equ 0ah

REG_RX_DATA_B:              equ 0bh

REG_RX_VALID_B:             equ 0ch

REG_TX_INT_EN:              equ 0dh

REG_TX_INT_STAT:            equ 0eh
    bTX_UNDER:              equ 08h
    bTX_OVER:               equ 04h
    bTX_EOF:                equ 02h
    bTX_EMPTY:              equ 01h

REG_TX_DATA:                equ 0fh

REG_TX_VALID:               equ 10h

REG_PN_CODE:                equ 11h

REG_THOLD_L:                equ 19h
    mTHRESHOLD_L:           equ 7Fh

REG_THOLD_H:                equ 1ah
    mTHRESHOLD_H:           equ 7Fh

REG_WAKE_EN:                equ 1Ch
    bWAKE_EN:               equ 01h

REG_WAKE_STAT:              equ 1Dh
    bWAKE_STAT:             equ 01h

REG_ANALOG_CTL:             equ 20h
    bAGC_EN:               equ 40h
    bID_EN:                 equ 20h
    bPACTL_EN:              equ 04h
    bPACTL_INVERT:          equ 02h
    bSYSTEM_RESET:          equ 01h

REG_CHANNEL:                equ 21h
    bA_N_EN:                equ 80h
    mCHANNEL:               equ 7fh     ;mask for channel bits

REG_RSSI:                   equ 22h
    bRSSI_VALID:            equ 20h
    mRSSI:                  equ 1Fh

REG_PA:                     equ 23h
    mPA_BIAS:               equ 07h
    
REG_XTAL_ADJ:               equ 24h
    bCLOCK_DISABLE:         equ 40h
    mXTAL_ADJ:              equ 1fh     ;mask for xtal adj value
    
REG_VCO_CAL:                equ 26h
    bMINUS5_PLUS5:          equ c0h
    bMINUS2_PLUS3:          equ 80h
    
REG_AGC_CTL:                equ 2Eh
    bAGC_OFF:               equ 80h
    bAGC_ON:                equ 00h
    bCDET_ENABLE:           equ 40h
    
REG_CARRIER_DETECT:         equ 2Fh
    bCDET:                  equ 80h
    
REG_CLOCK_MANUAL:           equ 32h

REG_CLOCK_ENABLE:           equ 33h    
    
REG_SYN_LOCK_CNT:           equ 38h

REG_MFG_ID:                 equ 3Ch



