//--------------------------------------------------------------------------
//! \file
//!
//!  This file contain debug types and macros
//!
//--------------------------------------------------------------------------
// $Archive: /WirelessUSB/LS/Firmware/LS DVK/PSoC/Common/debug.h $
// $Modtime: 2/12/04 12:33p $
// $Revision: 1.3 $
//--------------------------------------------------------------------------
//
// Copyright 2003, Cypress Semiconductor Corporation.
//
// This software is owned by Cypress Semiconductor Corporation (Cypress)
// and is protected by and subject to worldwide patent protection (United
// States and foreign), United States copyright laws and international 
// treaty provisions. Cypress hereby grants to licensee a personal, 
// non-exclusive, non-transferable license to copy, use, modify, create 
// derivative works of, and compile the Cypress Source Code and derivative 
// works for the sole purpose of creating custom software in support of 
// licensee product to be used only in conjunction with a Cypress integrated 
// circuit as specified in the applicable agreement. Any reproduction, 
// modification, translation, compilation, or representation of this 
// software except as specified above is prohibited without the express 
// written permission of Cypress.
//
// Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED, 
// WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Cypress reserves the right to make changes without further notice to the
// materials described herein. Cypress does not assume any liability arising
// out of the application or use of any product or circuit described herein.
// Cypress does not authorize its products for use as critical components in
// life-support systems where a malfunction or failure may reasonably be
// expected to result in significant injury to the user. The inclusion of
// Cypress product in a life-support systems application implies that the
// manufacturer assumes all risk of such use and in doing so indemnifies
// Cypress against all charges.
//
// Use may be limited by and subject to the applicable Cypress software
// license agreement.
//
//--------------------------------------------------------------------------

#ifndef _DEBUG_H_
#define _DEBUG_H_

//--------------------------------------
// Included files
//--------------------------------------


//--------------------------------------
// API Definitions and Types
//--------------------------------------

#ifdef DEBUG
    //! Macro for displaying a message with a carriage return and a newline
    #define DEBUG_MSG(str)          debug_out_str(#str"\r\n");   
    //! Macro for displaying a string
    #define DEBUG_STR(str)          debug_out_str ( (str) );   
    //! Macro for displaying a character
    #define DEBUG_CHAR(chr)         debug_out_char( (chr) );   
    //! Macro for displaying a hex value
    #define DEBUG_HEX(var)          debug_out_hex ( (var) );   
    //! Macro for displaying a decimal
    #define DEBUG_DEC(var)          debug_out_dec ( (var) );  
    //! Macro for displaying a hex message with a carriage return and a newline
    #define DEBUG_MSG_HEX(str,var)  debug_out_str(str);debug_out_hex(var);debug_out_str("\r\n");
    //! Macro for displaying a decimal message with a carriage return and a newline
    #define DEBUG_MSG_DEC(str,var)  debug_out_str(str);debug_out_dec(var);debug_out_str("\r\n");
#else /* !DEBUG */
    //! Blank macro for DEBUG_MSG() just incase DEBUG is not defined. If DEBUG
    //! is define then it will be for displaying a message with a carriage
    //! return and a newline
    #define DEBUG_MSG(str)
    //! Blank macro for DEBUG_STR() just incase DEBUG is not defined. If DEBUG
    //! is define then it will be for displaying a string
    #define DEBUG_STR(str)
    //! Blank macro for DEBUG_CHAR() just incase DEBUG is not defined. If DEBUG
    //! is define then it will be for displaying a character
    #define DEBUG_CHAR(chr)
    //! Blank macro for DEBUG_HEX() just incase DEBUG is not defined. If DEBUG
    //! is define then it will be for displaying a hex value
    #define DEBUG_HEX(var)
    //! Blank macro for DEBUG_DEC() just incase DEBUG is not defined. If DEBUG
    //! is define then it will be for displaying a decimal
    #define DEBUG_DEC(var)
    //! Blank macro for DEBUG_MSG_HEX() just incase DEBUG is not defined. If DEBUG
    //! is define then it will be for displaying a hex message with a carriage
    //! return and a newline
    #define DEBUG_MSG_HEX(str,var)
    //! Blank macro for DEBUG_MSG_DEC() just incase DEBUG is not defined. If DEBUG
    //! is define then it will be for displaying a decimal message with a carriage
    //! return and a newline
    #define DEBUG_MSG_DEC(str,var)
#endif // debug


//--------------------------------------
// API Function Declarations
//--------------------------------------

void debug_out_char(UINT8 data);
void debug_out_str(const UINT8 *pbStrPtr);
void debug_out_hex(UINT8 data);
void debug_out_dec(UINT8 data);
void out_dec_b(UINT8 data);
void out_int_hex(UINT16 data);
void out_int_dec(UINT16 data);
void out_int_dec_b(UINT16 data);


#endif   // _DEBUG_H_


