;;*****************************************************************************
;;*****************************************************************************
;;  FILENAME: RX8_1.asm
;;   Version: 2.2, Updated on 2003/11/18 at 15:01:51
;;  Generated by PSoC Designer ver 4.1 b931 : 21 January, 2004
;;
;;  DESCRIPTION: RX8 User Module software implementation file
;;               for 22/24/25/26/27xxx PSoC family of devices.
;;
;;  NOTE: User Module APIs conform to the fastcall convention for marshalling
;;        arguments and observe the associated "Registers are volatile" policy.
;;        This means it is the caller's responsibility to preserve any values
;;        in the X and A registers that are still needed after the API
;;        function returns. Even though these registers may be preserved now,
;;        there is no guarantee they will be preserved in future releases.
;;-----------------------------------------------------------------------------
;;  Copyright (c) Cypress MicroSystems 2000-2003. All Rights Reserved.
;;*****************************************************************************
;;*****************************************************************************

;-----------------------------------------------
; include instance specific register definitions
;-----------------------------------------------
include "m8c.inc"
include "RX8_1.inc"


;-----------------------------------------------
;  Global Symbols
;-----------------------------------------------
export   RX8_1_EnableInt
export  _RX8_1_EnableInt
export   RX8_1_DisableInt
export  _RX8_1_DisableInt
export   RX8_1_Start
export  _RX8_1_Start
export   RX8_1_Stop
export  _RX8_1_Stop
export   RX8_1_bReadRxData
export  _RX8_1_bReadRxData
export   RX8_1_bReadRxStatus
export  _RX8_1_bReadRxStatus

; Old function name convension, do not use.
; These will be removed in a future release.
export  bRX8_1_ReadRxData
export _bRX8_1_ReadRxData
export  bRX8_1_ReadRxStatus
export _bRX8_1_ReadRxStatus

;-----------------------------------------------
;  EQUATES
;-----------------------------------------------
bfCONTROL_REG_START_BIT:   equ   1     ; Control register start bit

area UserModules (ROM, REL)

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: RX8_1_EnableInt
;
;  DESCRIPTION:
;     Enables this receiver's interrupt by setting the interrupt enable mask
;     bit associated with this User Module. Remember to call the global interrupt
;     enable function by using the macro: M8C_EnableGInt.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS: none
;
;  RETURNS: none
;
;  SIDE EFFECTS:
;    REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;
;  THEORY of OPERATION or PROCEDURE:
;     Sets the specific user module interrupt enable mask bit.
;
;-----------------------------------------------------------------------------
 RX8_1_EnableInt:
_RX8_1_EnableInt:
   M8C_EnableIntMask RX8_1_INT_REG, RX8_1_bINT_MASK
   ret
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: RX8_1_DisableInt
;
;  DESCRIPTION:
;     Disables this RX8's interrupt by clearing the interrupt enable mask bit
;     associated with this User Module.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS:  none
;
;  RETURNS:  none
;
;  SIDE EFFECTS:
;    REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;
;  THEORY of OPERATION or PROCEDURE:
;     Clears the specific user module interrupt enable mask bit.
;
;-----------------------------------------------------------------------------
 RX8_1_DisableInt:
_RX8_1_DisableInt:
   M8C_DisableIntMask RX8_1_INT_REG, RX8_1_bINT_MASK
   ret
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: RX8_1_Start(BYTE bParity)
;
;  DESCRIPTION:
;    Sets the start bit and parity in the Control register of this user module.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS:
;    BYTE bParity - parity of received data.  Use defined masks.
;    passed in A register.
;
;  RETURNS: none
;
;  SIDE EFFECTS:
;    REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;
;  THEORY of OPERATION or PROCEDURE:
;     Set the specified parity and start bits in the Control register.
;
;-----------------------------------------------------------------------------
 RX8_1_Start:
_RX8_1_Start:
   or    A, bfCONTROL_REG_START_BIT
   mov   REG[RX8_1_CONTROL_REG], A
   ret
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: RX8_1_Stop
;
;  DESCRIPTION:
;     Disables RX8 operation.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS: none
;
;  RETURNS: none
;
;  SIDE EFFECTS:
;    REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;
;  THEORY of OPERATION or PROCEDURE:
;     Clear the start bit in the Control register.
;
;-----------------------------------------------------------------------------
 RX8_1_Stop:
_RX8_1_Stop:
   and   REG[RX8_1_CONTROL_REG], ~bfCONTROL_REG_START_BIT
   ret
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: RX8_1_bReadRxData
;
;  DESCRIPTION:
;     Reads the RX buffer register.  Should check the status regiser to make
;     sure data is valid.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS:  none
;
;  RETURNS:
;    bRxData - returned in A.
;
;  SIDE EFFECTS:
;    REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;
;  THEORY of OPERATION or PROCEDURE:
;
;-----------------------------------------------------------------------------
 RX8_1_bReadRxData:
_RX8_1_bReadRxData:
 bRX8_1_ReadRxData:
_bRX8_1_ReadRxData:
        mov A, REG[RX8_1_RX_BUFFER_REG]
        ret
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: RX8_1_bReadRxStatus
;
;  DESCRIPTION:
;    Reads the RX Status bits in the Control/Status register.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS:  none
;
;  RETURNS:
;     BYTE  bRXStatus - transmit status data.  Use the following defined bits
;                       masks: RX_COMPLETE and RX_BUFFER_EMPTY
;
;  SIDE EFFECTS:
;    REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;
;  THEORY of OPERATION or PROCEDURE:
;     Read the status and control register.
;
;-----------------------------------------------------------------------------
 RX8_1_bReadRxStatus:
_RX8_1_bReadRxStatus:
 bRX8_1_ReadRxStatus:
_bRX8_1_ReadRxStatus:
        mov A,  REG[RX8_1_CONTROL_REG]
        ret
.ENDSECTION

; End of File RX8_1.asm
