//--------------------------------------------------------------------------
//! \file
//!
//! Configure All Global Compile Options
//!
//! These items are usually set in the sources files, but can be over-ridden
//! here by using 'define' or 'undefine'.
//!
//--------------------------------------------------------------------------
// $Archive: /WirelessUSB/LS/Firmware/LS DVK/PSoC/DVK Listener/ls_config.h $
// $Modtime: 2/12/04 12:33p $
// $Revision: 1.4 $
//--------------------------------------------------------------------------
//
// Copyright 2003, Cypress Semiconductor Corporation.
//
// This software is owned by Cypress Semiconductor Corporation (Cypress)
// and is protected by and subject to worldwide patent protection (United
// States and foreign), United States copyright laws and international 
// treaty provisions. Cypress hereby grants to licensee a personal, 
// non-exclusive, non-transferable license to copy, use, modify, create 
// derivative works of, and compile the Cypress Source Code and derivative 
// works for the sole purpose of creating custom software in support of 
// licensee product to be used only in conjunction with a Cypress integrated 
// circuit as specified in the applicable agreement. Any reproduction, 
// modification, translation, compilation, or representation of this 
// software except as specified above is prohibited without the express 
// written permission of Cypress.
//
// Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED, 
// WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Cypress reserves the right to make changes without further notice to the
// materials described herein. Cypress does not assume any liability arising
// out of the application or use of any product or circuit described herein.
// Cypress does not authorize its products for use as critical components in
// life-support systems where a malfunction or failure may reasonably be
// expected to result in significant injury to the user. The inclusion of
// Cypress product in a life-support systems application implies that the
// manufacturer assumes all risk of such use and in doing so indemnifies
// Cypress against all charges.
//
// Use may be limited by and subject to the applicable Cypress software
// license agreement.
//
//--------------------------------------------------------------------------

#ifndef _LS_CONFIG_H_
#define _LS_CONFIG_H_

// PROTOCOL PARAMTERS
//! For TWO_WAY protocol.  See See the WirelessUSB LS 2-Way HID Systemes 
//! document for more information
#define TWO_WAY
//! End of Frame bits are the lower three bits 
#define EOF_BITS        0x07
//! For testing all channels rather than the top middle, and bottom channel
#define TELEC_ALL_CHANNELS

// DEBUG PARAMETERS
//! For extra debug messages
#define DEBUG

//! Default channel when initializing the channel
#define DEFAULT_CHANNEL 0x00
//! Default PN code when initializing the PN code
#define DEFAULT_PN_CODE 0x00

// RADIO PARAMETERS
//! Initial power amplitude level
#define PA_BIAS				0x07

// API Macro's
//! Macro that is set to the port anded with the interrupt request mask
#define LS_IRQ_ASSERTED    (PRT1DR & IRQ_MASK)

//! Macro for the isr_init() routine
#define RADIO_ISR_INIT()        isr_init()
//! Macro for the isr_enable() routine. INT_RADIO is passed in when using this macro
#define RADIO_ISR_ENABLE()      isr_enable( INT_RADIO )
//! Macro for the isr_disable() routine. INT_RADIO is passed in when using this macro
#define RADIO_ISR_DISABLE()     isr_disable( INT_RADIO )

//! Macro for the spi_radio_on() routine
#define SPI_RADIO_ON()              spi_radio_on()
//! Macro for the spi_radio_reset() routine
#define SPI_RADIO_RESET()           spi_radio_reset()
//! Macro for the spi_radio_put() routine
#define SPI_RADIO_PUT(addr, data)   spi_radio_put(addr, data)
//! Macro for the spi_radio_get() routine
#define SPI_RADIO_GET(data)         spi_radio_get(data)


// Flash Block location of the System Parameters
//#define SYS_PARAM_LOC     250  // set near the end of 16K flash memory, 3e80.
//#define NVRAM_READ(data, len)       nvram_read(SYS_PARAM_LOC, data, len)
//#define NVRAM_WRITE(data, len)      nvram_write(SYS_PARAM_LOC, data, len)
//! Macro for the timer_delay_50_usec() routine
#define TIMER_DELAY_50_USEC()                 timer_delay_50_usec()
//! Macro for the timer_delay_msec() routine
#define TIMER_DELAY_MSEC(cnt)                 timer_delay_msec(cnt)
//! Macro for the timer_delay_incremental() routine
#define TIMER_DELAY_INCREMENTAL(base, incr)   timer_delay_incremental(base, incr)
//! Macro for the timer_time_elapsed() routine
#define TIMER_IS_TIME_ELASPSED(base, curr)    timer_time_elasped(base, incr)
//! Macro for the timer_get_time_stamp() routine
#define TIMER_GET_TIME_STAMP()                timer_get_time_stamp()


//-----------------------------------------------
// Included files
// 
// These are at the bottom for the above #defines
//-----------------------------------------------

#include "psocgpioint.h"
#include "spi.h"
#include "debug.h"
#include "isr.h"
#include "timer.h"

#endif // _LS_CONFIG_H_
