//--------------------------------------------------------------------------
//! \file
//!  DVK Listener Main application routine
//!
//!
//! Copyright 2003, Cypress Semiconductor Corporation.
//!
//! This software is owned by Cypress Semiconductor Corporation (Cypress)
//! and is protected by and subject to worldwide patent protection (United
//! States and foreign), United States copyright laws and international 
//! treaty provisions. Cypress hereby grants to licensee a personal, 
//! non-exclusive, non-transferable license to copy, use, modify, create 
//! derivative works of, and compile the Cypress Source Code and derivative 
//! works for the sole purpose of creating custom software in support of 
//! licensee product to be used only in conjunction with a Cypress integrated 
//! circuit as specified in the applicable agreement. Any reproduction, 
//! modification, translation, compilation, or representation of this 
//! software except as specified above is prohibited without the express 
//! written permission of Cypress.
//!
//! Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED, 
//! WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
//! WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//! Cypress reserves the right to make changes without further notice to the
//! materials described herein. Cypress does not assume any liability arising
//! out of the application or use of any product or circuit described herein.
//! Cypress does not authorize its products for use as critical components in
//! life-support systems where a malfunction or failure may reasonably be
//! expected to result in significant injury to the user. The inclusion of
//! Cypress product in a life-support systems application implies that the
//! manufacturer assumes all risk of such use and in doing so indemnifies
//! Cypress against all charges.
//!
//! Use may be limited by and subject to the applicable Cypress software
//! license agreement.
//!
//--------------------------------------------------------------------------
// $Archive: /WirelessUSB/LS/Firmware/LS DVK/PSoC/DVK Listener/main.c $
// $Modtime: 2/12/04 12:33p $
// $Revision: 1.4 $
//--------------------------------------------------------------------------

//--------------------------------------
// Included files
//--------------------------------------
#include "ls_config.h"
#include "radio.h"
#include "emc_tester.h"
#include "radio.h"
#include "pdc9075.h"

void system_init(void);
UINT8 scan_buttons(void);

//UINT8 check_rssi(void);
//! Counter for scanning the buttons every CHECK_BUTTON_TIME 
UINT16 counter;
//! To keep track of the buttons state 
UINT8 buttonState;


//! For know what mode the emc_tester is in
extern UINT8 gEMCtesterMode;
//! Data rate setting for radio
extern UINT8 gDataRate;
//! Current PN code the radio is on
extern UINT8 pn_code;
//! Current channel the radio is on
extern UINT8 gChannel;
//! For using the top channel (channel 77)
extern UINT8 gTopChannel;
//! For using the bottom channel (channel 0)
extern UINT8 gBotChannel;
//! Current PA bias the radio is on
extern UINT8 gPaBias;

//! Button to use when incrementing the channel
#define CHANNEL_UP         BUTTON_4
//! Button to use when decrementing the channel
#define CHANNEL_DOWN       BUTTON_1 
//! Button to use when incrementing the PN code
#define PN_CODE_UP         BUTTON_5
//! Button to use when decrementing the PN code
#define PN_CODE_DOWN       BUTTON_2
//! Button to use when incrementing the data rate
#define DATARATE_UP        BUTTON_6
//! Button to use when decrementing the data rate
#define DATARATE_DOWN      BUTTON_3
//! Button to use when incrementing the PA bias
#define PA_INC             BUTTON_9
//! Button to use when decrementing the PA bias
#define PA_DEC             BUTTON_7

//! Button to use when incrementing the tests
#define INCR_TEST          BUTTON_PLUS
//! Button to use when displaying help information
#define HELP               BUTTON_DOT

//! Button to use when transmitting carrier
#define TX_CARRIER_ON      BUTTON_NUMLK
//! Button to use when transmitting data
#define TX_DATA_ON         BUTTON_SLASH
//! Button to use when transmitting packet data
#define TX_PKT_DATA_ON     BUTTON_MINUS
//! Button to use when receiving
#define RX_ON              BUTTON_STAR
//! Button to stop all transmits and receives
#define STOP_ALL           BUTTON_0


//! For the counter to know when to do a button scan
#define CHECK_BUTTON_TIME  0x01000

///////////////////////////////////////////////////////////////////////////////
//
//  Function:    reg_help
//
//!  Description: Displays the help menu through the hyperterminal 
//!
//!  Inputs:      Void
//!
//!  Returns:     Void
//!
///////////////////////////////////////////////////////////////////////////////
void reg_help()
{    
    debug_out_str("\t\tLS DVK EMC Test Support\r\n\n");
    debug_out_str("\t*** USAGE ***\r\n\n");
    debug_out_str("\tXmit No Mod: Num Lock on, 0 off\r\n");
    debug_out_str("\tXmit w/Mod:  / on, 0 off\r\n");
    debug_out_str("\tRecv:        * on, 0 off\r\n");
    debug_out_str("\tTx Data Pkt: - on, 0 off\r\n");

    debug_out_str("\r\n");

    debug_out_str("\tCHANNEL:     1 down, 4 up\r\n");
    debug_out_str("\tPN CODE:     2 down, 5 up\r\n");
    debug_out_str("\tDATA RATE:   3 down, 6 up\r\n");
    debug_out_str("\tPA Bias:     7 down, 9 up\r\n");
    debug_out_str("\r\n\n\n");

    debug_out_str("Top Channel   : ");
    debug_out_dec(gTopChannel);
    debug_out_str(", frequency: ");
    out_int_dec(2400 + CHANNEL_OFFSET + gTopChannel);
    debug_out_str("\r\n");                    
    debug_out_str("Middle Channel: ");
    debug_out_dec(CHANNEL_MIDDLE);
    debug_out_str(", frequency: ");
    out_int_dec(2400 + CHANNEL_OFFSET + CHANNEL_MIDDLE);
    debug_out_str("\r\n");     
    debug_out_str("Bottom Channel: ");
    debug_out_dec(gBotChannel);
    debug_out_str(", frequency: ");
    out_int_dec(2400 + CHANNEL_OFFSET + gBotChannel);
    debug_out_str("\r\n\n");                      


    debug_out_str("Channel:   ");
    debug_out_dec(gChannel);
    debug_out_str("\r\n");
                     
    debug_out_str("pnCode:    ");
    debug_out_dec(pn_code);
    debug_out_str("\r\n");
    
    debug_out_str("Data Rate: " );
    debug_out_dec(gDataRate);
    debug_out_str("\r\n");

    debug_out_str("PA: ");
    debug_out_dec(gPaBias);
    debug_out_str("\r\n");
}


///////////////////////////////////////////////////////////////////////////////
//
//  Function:    main
//
//!  Description: The emc_tester main routine initializes the system, sets the
//!               emc_tester mode to EMC_TESTER_IDLE, and displays the initial 
//!               help screen through hyperterminal.  Then it continuously 
//!               scans the platform board for a button press and checks for 
//!               sending the actual packet 
//!
//!  Inputs:      Void
//!
//!  Returns:     Void
//!
///////////////////////////////////////////////////////////////////////////////
void main()
{
	UINT8 buttonIndex;
    UINT8 packetcounter = 0;

    // initialize the system
    system_init();
    
    gEMCtesterMode = EMC_TESTER_IDLE;
    
    reg_help();
    
    while(1) 
    {   
        if ( 
             (counter++      >= CHECK_BUTTON_TIME) ||
             (gEMCtesterMode == EMC_TESTER_PKT_DATA)
           )
        {
            counter = 0;
        	buttonIndex = scan_buttons();
            
            if (buttonIndex != 0xFF)
            {
                switch(buttonIndex) {
                case CHANNEL_UP:
                    increment_channel();
                    debug_out_str("increment channel: ");
                    debug_out_dec(gChannel);
                    debug_out_str(", frequency: ");
                    out_int_dec(2400+CHANNEL_OFFSET+gChannel);
                    debug_out_str("\r\n");
                    break;
                    
                case CHANNEL_DOWN:
                    decrement_channel();
                    debug_out_str("decrement channel: ");
                    debug_out_dec(gChannel);
                    debug_out_str(", frequency: ");
                    out_int_dec(2400+CHANNEL_OFFSET+gChannel);
                    debug_out_str("\r\n");
                    break;
                    
                case PN_CODE_UP:
                    increment_pn_code();
                    debug_out_str("increment PN code: ");
                    debug_out_dec(pn_code);
                    debug_out_str("\r\n");
                    break;
                    
                case PN_CODE_DOWN:
                    decrement_pn_code();
                    debug_out_str("decrement PN code: ");
                    debug_out_dec(pn_code);
                    debug_out_str("\r\n");
                    break;
    
                case DATARATE_UP:
                    increment_data_rate();
                    debug_out_str("increment data rate: ");
                    debug_out_dec(gDataRate);
                    debug_out_str("\r\n");
                    break;
                    
                case DATARATE_DOWN:
                    decrement_data_rate();
                    debug_out_str("decrement data rate: ");
                    debug_out_dec(gDataRate);
                    debug_out_str("\r\n");
                    break;
                    
                case PA_INC:
                    increment_pa_bias();
                    debug_out_str("PA: ");
                    debug_out_dec(gPaBias);
                    debug_out_str("\r\n");
                    break;
                    
                case PA_DEC:
                    decrement_pa_bias();
                    debug_out_str("PA: ");
                    debug_out_dec(gPaBias);
                    debug_out_str("\r\n");
                    break;                           
                  
                case TX_CARRIER_ON:
                    start_transmit_carrier();
                    debug_out_str("Start Transmitting Carrier\r\n");
                    break;
                    
                case TX_DATA_ON:
                    start_transmit_data();
                    debug_out_str("Start Transmitting Data\r\n");
                    break;
                    
                case RX_ON:
                    start_receive();
                    debug_out_str("Start Receive\r\n");
                    break;
                    
                case TX_PKT_DATA_ON:
                    reset_test();
                    gEMCtesterMode = EMC_TESTER_PKT_DATA;
                    debug_out_str("Start Transmitting Packet Data\r\n");
                    break;
                                                          
                case STOP_ALL:
                    reset_test();
                    debug_out_str("Stop Test\r\n");
                    break;
                    
                case INCR_TEST:
                    increment_test();
                    debug_out_str("Increment Tests: " );
                    debug_out_str("\r\n");                    
                    break;
                        
                case HELP:
                    reg_help();
                    break;
                }
            }
        }
        // check for sending actual packet
        if( gEMCtesterMode == EMC_TESTER_PKT_DATA )
        {
            if ((packetcounter++ & 0x0F) == 0x00) {
                packet_test();
            }
        }  
        
    }  // while(1)
    
}  // end main


///////////////////////////////////////////////////////////////////////////////
//
//  Function:    system_init
//
//!  Description: Initializes the Application, platform board, LS Radio and 
//!               bind protocol
//!
//!  Inputs:      None
//!
//!  Returns:     Void
//!
///////////////////////////////////////////////////////////////////////////////
void system_init()
{
	isr_init();
	
	timer_init();

    platform_init();
    
    radio_init();
}


///////////////////////////////////////////////////////////////////////////////
//
//  Function:    scan_buttons
//
//!  Description: Scans the buttons by checking ever row with every column for 
//!               a button press.
//!
//!  Inputs:      None
//!
//!  Returns:     
//!               - index - Button index
//!               _ 0xFF - No change in button activity
//!
///////////////////////////////////////////////////////////////////////////////
UINT8 scan_buttons(void)
{
	UINT8 index;
	UINT8 row;
	UINT8 col;
	UINT8 mask;
	UINT8 rowBit;
	UINT8 prt3shadow;
    UINT8 downButton = 0xFF;

	// save port 4's configuration
	prt3shadow = PRT3DR;
    
    //loop through the buttons
	for(col = 0; col < COLUMNS; ++col)
	{
		// drive the column
		PRT3DR = ~(0x01 << col);
		// read the row
		row = PRT5DR;
		row &= (ROW_0 | ROW_1 | ROW_2 | ROW_3);
		mask = 0x01;
		for(mask = 0x01, rowBit = 0; rowBit < ROWS; ++rowBit, mask <<= 1)
        {
        	index = (col * ROWS) + rowBit;           
            if(!(row & mask))   // down key
            {    
                if (buttonState == index) {
                    return 0xFF;
                }
                else {
                    buttonState = index;
                    return index;
                }
            }
 		}
	}
	// restore Port 4 config
	PRT3DR = prt3shadow;
    buttonState = 0xFF;
	return 0xFF;
}

