//--------------------------------------------------------------------------
//! \file
//!
//! Include file which defines the LS Radio registers and C prototypes
//!
//--------------------------------------------------------------------------
// $Archive: /WirelessUSB/LS/Firmware/LS DVK/PSoC/Radio/radio.h $
// $Modtime: 3/04/04 3:11p $
// $Revision: 1.2 $
//--------------------------------------------------------------------------
//
// Copyright 2003-2004, Cypress Semiconductor Corporation.
//
// This software is owned by Cypress Semiconductor Corporation (Cypress)
// and is protected by and subject to worldwide patent protection (United
// States and foreign), United States copyright laws and international 
// treaty provisions. Cypress hereby grants to licensee a personal, 
// non-exclusive, non-transferable license to copy, use, modify, create 
// derivative works of, and compile the Cypress Source Code and derivative 
// works for the sole purpose of creating custom software in support of 
// licensee product to be used only in conjunction with a Cypress integrated 
// circuit as specified in the applicable agreement. Any reproduction, 
// modification, translation, compilation, or representation of this 
// software except as specified above is prohibited without the express 
// written permission of Cypress.
//
// Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED, 
// WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Cypress reserves the right to make changes without further notice to the
// materials described herein. Cypress does not assume any liability arising
// out of the application or use of any product or circuit described herein.
// Cypress does not authorize its products for use as critical components in
// life-support systems where a malfunction or failure may reasonably be
// expected to result in significant injury to the user. The inclusion of
// Cypress product in a life-support systems application implies that the
// manufacturer assumes all risk of such use and in doing so indemnifies
// Cypress against all charges.
//
// Use may be limited by and subject to the applicable Cypress software
// license agreement.
//
//--------------------------------------------------------------------------

//--------------------------------------
// Included files
//--------------------------------------

#include "cypdef.h"

#ifndef _RADIO_H_
#define _RADIO_H_

//#define AGC_OFF

//! There are a total of 78 channels
#define NUM_CHANNELS 78
//! The network pin is a 3 bit value
#define MAX_PIN       0x07  // Network PIN is a 3 bit value
//! Number of PN codes in the PN code table (See pn_code_table[] in bind.c).  
//! 49 PN codes with a data rate of 16kbps
#define NUM_PN_CODES_64  49
//! Number of PN codes in the PN code table (See pn_code_table[] in bind.c).  
//! 8 PN codes are used with a data rate of 32kbps or 64kpbs
#define NUM_PN_CODES_32  0x08

#ifndef EOF_BITS
//! End of Frame bits are the lower two bits
#define EOF_BITS 0x07
#endif

#ifndef SYNTH_SETTLE_COUNT
//! To allow synth to settle
#define SYNTH_SETTLE_COUNT    100
#endif

//! With a data rate of 64 -> (CHIP_BITS_64 | NORMAL_DATA_RATE)
#define RADIO_MODE_64   (CHIP_BITS_64 | NORMAL_DATA_RATE)
//! With a data rate of 32 -> (CHIP_BITS_32 | NORMAL_DATA_RATE)
#define RADIO_MODE_32   (CHIP_BITS_32 | NORMAL_DATA_RATE)
//! With a double data rate -> (CHIP_BITS_32 | DOUBLE_DATA_RATE)
#define RADIO_MODE_DDR  (CHIP_BITS_32 | DOUBLE_DATA_RATE)

//! Low threshold for data rate of 64
#define THRESHOLD_LO_64 0x08
//! High threshold for data rate of 64
#define THRESHOLD_HI_64 56

//! Low threshold for data rate of 32
#define THRESHOLD_LO_32 0x03
//! High threshold for data rate of 32
#define THRESHOLD_HI_32 29

#ifndef CHANNEL_OFFSET
//! This is setup to ensure a guard ban at the low end Channel 0 - 2.402, a 
//! 2 MHz guard band to 2.400. The upper guard band is protected by the use of
//! NUM_CHANNELS in the protocol and application Channel 78 - 2.480, a 3.5MHz 
//! guard to 2.4835 
#define CHANNEL_OFFSET 0x02 
#endif

/***********************************
* CY Radio Register Definitions
***********************************/
#define REG_ID              0x00
#define VERSION_MASK        0x0F
#define MANUFACTURING_MASK  0xF0

#define REG_SYNTH_A_CNTR    0x01  
#define REG_SYNTH_N_CNTR    0x02

#define REG_CONTROL         0x03    
#define RX_ENABLE           0x80    
#define TX_ENABLE           0x40    
#define PN_CODE_SELECT      0x20    
#define AUTO_SYNTH_COUNT    0x10
#define AUTO_PA_DISABLE     0x08
#define PA_ENABLE           0x04
#define AUTO_SYNTH_DISABLE  0x02
#define SYNTH_ENABLE        0x01

#define REG_DATA_RATE       0x04    
#define RADIO_MODE_NORM     0x00
#define CHIP_BITS_32        0x04
#define CHIP_BITS_64        0x00
#define NORMAL_DATA_RATE    0x00
#define DOUBLE_DATA_RATE        0x02
#define OVERSAMPLING_6X     0x00
#define OVERSAMPLING_12X    0x01


#define REG_CONFIG          0x05    
#define RADIO_BYPASS        0x20
#define RX_INVERT           0x10
#define TX_INVERT           0x08
#define IRQ_OD              0x02
#define IRQ_CMOS            0x00
#define IRQ_ACTIVE_HI       0x01
#define IRQ_ACTIVE_LO       0x00

#define REG_SERDES_CTL      0x06    
#define SERDES_ENABLE       0x08
#define EOF_LEN_MASK        0x07

#define REG_RX_INT_EN       0x07
#define RX_UNDER_B          0x80    
#define RX_OVER_B           0x40    
#define RX_EOF_B            0x20    
#define RX_FULL_B           0x10    
#define RX_UNDER_A          0x08    
#define RX_OVER_A           0x04    
#define RX_EOF_A            0x02    
#define RX_FULL_A           0x01    

#define REG_RX_INT_STAT     0x08
#define RX_VALID_B          0x80    
#define RX_VALID_A          0x08    
// other bits same as above (almost)

#define REG_DATA_RX_A       0x09
#define REG_VALID_RX_A      0x0A
#define REG_DATA_RX_B       0x0B
#define REG_VALID_RX_B      0x0C

#define REG_TX_INT_EN       0x0D
#define TX_UNDER            0x08
#define TX_OVER             0x04
#define TX_EOF              0x02
#define TX_EMPTY            0x01
//bits same as REG_RX_INT_EN except LSb of each nibble

#define REG_TX_INT_STAT     0x0E
// bits same as above

#define REG_DATA_TX         0x0F
#define REG_VALID_TX        0x10

#define REG_PN_CODE         0x11    
//Address 0x11 is LSB, 0x18 is MSB
//Transmit and receive LSB first

#define REG_THRESHOLD_LO        0x19    
#define REG_THRESHOLD_HI        0x1A    
#define THRESHOLD_MASK  0x7F

#define REG_THRESHOLD_CNT   0x1B    // read only

#define REG_WAKE_EN         0x1C    
#define WAKE_EN             0x01    

#define REG_WAKE_STAT       0x1D    
#define WAKE_INT            0x01    // bWAKE_STAT


//Registers 0x1C - 0x1F are Reserved
#define REG_ANALOG_CTL      0x20    
#define AGC_DISABLE         0x40    
#define MFG_ID_EN           0x20    
#define PACTL_EN            0x04
#define PACTL_INVERT        0x02
#define SYSTEM_RESET        0x01
    
#define REG_CHANNEL         0x21
#define A_N_EN              0x80    
#define CHANNEL_MASK        0x7F

#define REG_RSSI            0x22
#define RSSI_VALID          0x20
#define RSSI_MASK           0x1F

#define REG_PA              0x23    
//#define mLNA_GAIN         0x78
#define PA_BIAS_MASK        0x07

#define REG_XTAL_ADJ        0x24
#define CLOCK_DISABLE       0x40
#define XTAL_ADJ_MASK       0x3F

#define REG_CAL_COUNT       0x25

#define REG_VCO_CAL         0x26
#define MINUS_5_PLUS_5      0xC0
#define MINUS_2_PLUS_3      0x80
#define VCO_CAL_MASK        0x1F


    
#define REG_AGC_CTL         0x2E
#define AGC_OFF             0x80

#define REG_CARRIER_DETECT          0x2F

#define REG_CLOCK_MANUAL    0x32
            
#define REG_CLOCK_ENABLE    0x33

#define REG_SYN_LOCK_CNT    0x38    

#define REG_MFG_ID_1        0x3C    // REG_MFG_ID
#define REG_MFG_ID_2        0x3D
#define REG_MFG_ID_3        0x3E
#define REG_MFG_ID_4        0x3F


void radio_off(void);
void radio_transmit_on(UINT8 channel);
void radio_receive_on(UINT8 channel);
void radio_init(void);
void radio_set_pn_code_64(int pn_code_index);
void radio_set_pn_code_32(int pn_code_index);
void radio_dump_registers(void);
void radio_isr(void);
UINT8 radio_get_id( UINT8 id );
#ifdef ADJUST_XTAL
void radio_set_crystal(UINT8 xtal);
UINT8 radio_get_crystal(void);
#endif

#endif // _RADIO_H
