//--------------------------------------------------------------------------
//! \file
//!
//!  This file contains DVK common SPI API code.
//!
//--------------------------------------------------------------------------
// $Archive: /WirelessUSB/LS/Firmware/LS DVK/PSoC/Common/spi.c $
// $Modtime: 2/12/04 12:33p $
// $Revision: 1.2 $
//--------------------------------------------------------------------------
//
// Copyright 2003, Cypress Semiconductor Corporation.
//
// This software is owned by Cypress Semiconductor Corporation (Cypress)
// and is protected by and subject to worldwide patent protection (United
// States and foreign), United States copyright laws and international 
// treaty provisions. Cypress hereby grants to licensee a personal, 
// non-exclusive, non-transferable license to copy, use, modify, create 
// derivative works of, and compile the Cypress Source Code and derivative 
// works for the sole purpose of creating custom software in support of 
// licensee product to be used only in conjunction with a Cypress integrated 
// circuit as specified in the applicable agreement. Any reproduction, 
// modification, translation, compilation, or representation of this 
// software except as specified above is prohibited without the express 
// written permission of Cypress.
//
// Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED, 
// WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Cypress reserves the right to make changes without further notice to the
// materials described herein. Cypress does not assume any liability arising
// out of the application or use of any product or circuit described herein.
// Cypress does not authorize its products for use as critical components in
// life-support systems where a malfunction or failure may reasonably be
// expected to result in significant injury to the user. The inclusion of
// Cypress product in a life-support systems application implies that the
// manufacturer assumes all risk of such use and in doing so indemnifies
// Cypress against all charges.
//
// Use may be limited by and subject to the applicable Cypress software
// license agreement.
//
//--------------------------------------------------------------------------


///////////////////////////////////////////////////////////////////////////////
//
//  Filename:    spi.c
//
//  Description: 
//
/////////////////////////////////////////////////////////////////////////////// 

#include "spim_1.h"
#include "ls_config.h"
#include "pdc9075.h"

//! To lock SPI while reading or writing data
UINT8 spiLock = 0;

///////////////////////////////////////////////////////////////////////////////
//
//  Function:    spi_radio_on
//
//!  Description: Disables the interrupt, then sets up the radio port by doing
//!               a reset and a power cycle
//!
//!  Inputs:      Void
//!
//!  Returns:     Void
//!
///////////////////////////////////////////////////////////////////////////////
void spi_radio_on(void)
{
    // disable the PSOC GPIO interrupt (radioIsr)
    RADIO_ISR_DISABLE();
    
	RADIO_PORT &= ~(N_RESET | N_PD);  
   	RADIO_PORT |= N_PD;	
	
	timer_delay_msec(10);
	
	RADIO_PORT |= (N_RESET);
	
 	timer_delay_msec(1);
	RADIO_PORT &= ~N_PD;  
	timer_delay_msec(1);
   	RADIO_PORT |= N_PD;	
	
	timer_delay_msec(1);
 	RADIO_PORT &= ~(N_RESET);
	timer_delay_msec(1);
 	RADIO_PORT |= (N_RESET);	
	
	SPIM_1_Start(SPIM_MODE_0 | SPIM_MSB_FIRST);
}

///////////////////////////////////////////////////////////////////////////////
//
//  Function:    spi_radio_reset
//
//!  Description: Reset the LS radio
//!
//!  Inputs:      Void
//!
//!  Returns:     Void
//!
///////////////////////////////////////////////////////////////////////////////
void spi_radio_reset(void)
{
 	RADIO_PORT &= ~(N_RESET);
	timer_delay_50_usec();
 	RADIO_PORT |= (N_RESET);	
}

///////////////////////////////////////////////////////////////////////////////
//
//  Function:    spi_radio_put
//
//!  Description: Write data to the LS radio via the SPI port
//!
//!  Inputs:      
//!               - address - Address of the data to write
//!               - data - Data to write
//!
//!  Returns:     Void
//!
///////////////////////////////////////////////////////////////////////////////
void spi_radio_put(UINT8 address, UINT8 data)
{
	UINT8 isrState;
	
	if (spiLock) {
		return;
	}
	
	spiLock = 1;

        // assert the slave select
	RADIO_PORT &= ~N_SS;
	
        // write the address to the SPI port
	SPIM_1_TX_BUFFER_REG = ((address & SPI_ADDRESS_MASK)| bSPI_WRITE);
	while(!(bSPIM_1_ReadStatus() & SPIM_SPI_COMPLETE));    // infinite loop

        // write the byte to the SPI port 
	SPIM_1_TX_BUFFER_REG = data;
	while(!(bSPIM_1_ReadStatus() & SPIM_SPI_COMPLETE));    // infinite loop

        // deassert the slave select
	RADIO_PORT |= N_SS;

	spiLock = 0;
}

///////////////////////////////////////////////////////////////////////////////
//
//  Function:    spi_radio_get
//
//!  Description: Read data from an address in the Radio
//!
//!  Inputs:      
//!               - address - Address of the data that is read
//!
//!  Returns:     
//!               - SPIM_1_RX_BUFFER_REG - Register for the receive buffer
//!
///////////////////////////////////////////////////////////////////////////////
UINT8 spi_radio_get(UINT8 address)
{
	UINT8 isrState;
	
	if(spiLock) {
		return 0;
	}
	spiLock = 1;

	// assert the slave select
	RADIO_PORT &= ~N_SS;
	
        // read the select address
	SPIM_1_TX_BUFFER_REG = (address & SPI_ADDRESS_MASK);
	while(!(bSPIM_1_ReadStatus() & SPIM_SPI_COMPLETE));
	
        // read the data
	SPIM_1_TX_BUFFER_REG = 0xFF;
	while(!(bSPIM_1_ReadStatus() & SPIM_SPI_COMPLETE));

	// deassert the slave select
	RADIO_PORT |= N_SS;

	spiLock = 0;

	return(SPIM_1_RX_BUFFER_REG);
}

