//--------------------------------------------------------------------------
//! \file
//!
//!  This file contains DVK common SPI API code types and macros.
//!
//--------------------------------------------------------------------------
// $Archive: /WirelessUSB/LS/Firmware/LS DVK/PSoC/Common/timer.h $
// $Modtime: 2/12/04 12:33p $
// $Revision: 1.3 $
//--------------------------------------------------------------------------
//
// Copyright 2003, Cypress Semiconductor Corporation.
//
// This software is owned by Cypress Semiconductor Corporation (Cypress)
// and is protected by and subject to worldwide patent protection (United
// States and foreign), United States copyright laws and international 
// treaty provisions. Cypress hereby grants to licensee a personal, 
// non-exclusive, non-transferable license to copy, use, modify, create 
// derivative works of, and compile the Cypress Source Code and derivative 
// works for the sole purpose of creating custom software in support of 
// licensee product to be used only in conjunction with a Cypress integrated 
// circuit as specified in the applicable agreement. Any reproduction, 
// modification, translation, compilation, or representation of this 
// software except as specified above is prohibited without the express 
// written permission of Cypress.
//
// Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED, 
// WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Cypress reserves the right to make changes without further notice to the
// materials described herein. Cypress does not assume any liability arising
// out of the application or use of any product or circuit described herein.
// Cypress does not authorize its products for use as critical components in
// life-support systems where a malfunction or failure may reasonably be
// expected to result in significant injury to the user. The inclusion of
// Cypress product in a life-support systems application implies that the
// manufacturer assumes all risk of such use and in doing so indemnifies
// Cypress against all charges.
//
// Use may be limited by and subject to the applicable Cypress software
// license agreement.
//
//--------------------------------------------------------------------------

#ifndef _TIMER_H_
#define _TIMER_H_

//--------------------------------------
// Included files
//--------------------------------------

#include "cypdef.h"


//--------------------------------------
// API Definitions and Types
//--------------------------------------

//! Mainly used for finding a time elapse
typedef UINT32 TIME_STAMP;


// Tick is set to 1ms
//! Millisecond to Tick (Note: 1 Millisecond is equivalent to 1 Tick)
#define MS_TO_TICK(n) (n)
//! Tick to Millisecond
#define TICK_TO_MS(n) (n)


// CPU @ 12MHz
//! Three nop instructions is equivalent to 1 usec for a 12MHz CPU
#define delay1usec()   \
            asm("nop"); \
            asm("nop"); \
            asm("nop");


//! PSoC CY8C26XXX series has potential sleep problems
//! This macro is a work-around for that issue.
#define timer_sleep_psoc()      \
    asm("push A");              \
    asm("or  F, 10h");          \
    asm("mov A, reg[E0h]");     \
    asm("and reg[E0h], F8h");   \
    asm("or  reg[FFh], 08h");   \
    asm("nop");                 \
    asm("mov reg[E0h], A");     \
    asm("and F, EFh");          \
    asm("pop A");


//--------------------------------------
// API Function Declarations
//--------------------------------------

extern void timer_init(void);

extern void timer_delay_10_usec(void);
//extern void timer_delay_100_usec(void);
extern void timer_delay_50_usec(void);
extern void timer_delay_msec(UINT16 num_milliseconds);

extern TIME_STAMP timer_get_time_stamp(void);
extern void timer_delay_incremental( TIME_STAMP from_timestamp, UINT16 delay_ms );
extern BOOL timer_time_elapsed(TIME_STAMP from_timestamp, UINT16 elapsed_time_ms);


// API for radio

#endif   // _TIMER_H_


