;****************************************************************************
;
;   file:           usb.inc 
;   Description:    This file contains USB definitions
;   Target:         Cypress CY7C63723/CY7C63743 Encore Chips
;   $Header:
;   Version:        1.3.0000
;
;****************************************************************************
; Copyright (2003), Cypress Semiconductor Corporation
; This software is owned by Cypress Semiconductor Corporation (Cypress) and  is
; protected by United States copyright laws and international treaty provisions.
; Cypress hereby grants to Licensee a personal, non-exclusive, non-transferable
; license to copy, use, modify, create derivative works of, and compile the
; Cypress Source Code and derivative works for the sole purpose of creating
; custom software in support of Licensee product ("Licensee Product") to be used
; only in conjunction with a Cypress integrated circuit. Any reproduction,
; modification, translation, compilation, or representation of this software
; except as specified above is prohibited without the express written permission
; of Cypress.
; Disclaimer: Cypress makes no warranty of any kind, express or implied, with
; regard to this material, including, but not limited to, the implied warranties
; of merchantability and fitness for a particular purpose. Cypress reserves the
; right to make changes without further notice to the materials described herein.
; Cypress does not assume any liability arising out of the application or use of
; any product or circuit described herein. Cypress products described herein are
; not authorized for use as components in life-support devices.
; This software is protected by and subject to worldwide patent coverage,
; including U.S. and foreign patents. Use may be limited by and subject to the
; Cypress Software License Agreement.
;
;****************************************************************************
;----------------------------------------------------
;       USB DATA MEMORY VARIABLES
;----------------------------------------------------
suspend_count:      equ 20h     ; counter for suspend/resume
ep2_data_toggle:    equ 21h     ; data toggle for INs on endpoint one
ep1_data_toggle:    equ 22h     ; data toggle for INs on endpoint one
ep0_data_toggle:    equ 23h     ; data toggle for INs on endpoint zero
data_start:         equ 24h     ; address of request response data, as an offset
data_count:         equ 25h     ; number of bytes to send back to the host
maximum_data_count: equ 26h     ; request response size
ep0_in_machine:     equ 27h     
ep0_in_flag:        equ 28h
configuration:      equ 29h
ep1_stall:          equ 2Ah
idle:               equ 2Bh
protocol:           equ 2Ch
temp:               equ 2Dh     ; temporary register
event_machine:      equ 2Eh
pending_data:       equ 2Fh
int_temp:           equ 30h
idle_timer:         equ 31h
idle_prescaler:     equ 32h
ep0_transtype:      equ 33h
pc_has_desc:        equ 34h
remote_wakeup:      equ 35h
misc_counter1:      equ 36h

;----------------------------------------------------
;       USB-related RAM declarations                                 
;----------------------------------------------------
ep1_dmabuff:        equ F0h
ep1_dmabuff0:       equ ep1_dmabuff+0
ep1_dmabuff1:       equ ep1_dmabuff+1
ep1_dmabuff2:       equ ep1_dmabuff+2
ep1_dmabuff3:       equ ep1_dmabuff+3
ep1_dmabuff4:       equ ep1_dmabuff+4
ep1_dmabuff5:       equ ep1_dmabuff+5
ep1_dmabuff6:       equ ep1_dmabuff+6
ep1_dmabuff7:       equ ep1_dmabuff+7

ep2_dmabuff:        equ E8h
ep2_dmabuff0:       equ ep2_dmabuff+0
ep2_dmabuff1:       equ ep2_dmabuff+1
ep2_dmabuff2:       equ ep2_dmabuff+2
ep2_dmabuff3:       equ ep2_dmabuff+3
ep2_dmabuff4:       equ ep2_dmabuff+4
ep2_dmabuff5:       equ ep2_dmabuff+5
ep2_dmabuff6:       equ ep2_dmabuff+6
ep2_dmabuff7:       equ ep2_dmabuff+7

ep0_dmabuff:        equ F8h
ep0_dmabuff0:       equ ep0_dmabuff+0
ep0_dmabuff1:       equ ep0_dmabuff+1
ep0_dmabuff2:       equ ep0_dmabuff+2
ep0_dmabuff3:       equ ep0_dmabuff+3
ep0_dmabuff4:       equ ep0_dmabuff+4
ep0_dmabuff5:       equ ep0_dmabuff+5
ep0_dmabuff6:       equ ep0_dmabuff+6
ep0_dmabuff7:       equ ep0_dmabuff+7

bmRequestType:      equ ep0_dmabuff0
bRequest:           equ ep0_dmabuff1
wValuelo:           equ ep0_dmabuff2
wValuehi:           equ ep0_dmabuff3
wIndexlo:           equ ep0_dmabuff4
wIndexhi:           equ ep0_dmabuff5
wLengthlo:          equ ep0_dmabuff6
wLengthhi:          equ ep0_dmabuff7                             
                                 


;------------------------------------------------------
;       USB Constants
;------------------------------------------------------

; STATE MACHINE CONSTANTS
;EP0 IN TRANSACTIONS
EP0_IN_IDLE:            equ 00h
CONTROL_READ_DATA:      equ 02h
NO_DATA_STATUS:         equ 04h
EP0_IN_STALL:           equ 06h
CTRL_READ_HID_RPT_DESC: equ 08h

; FLAG CONSTANTS
;EP0 NO-DATA CONTROL FLAGS
ADDRESS_CHANGE_PENDING: equ 00h
NO_CHANGE_PENDING:      equ 02h

; RESPONSE SIZES
DEVICE_STATUS_LENGTH:       equ 2
DEVICE_CONFIG_LENGTH:       equ 1
ENDPOINT_STALL_LENGTH:      equ 2
INTERFACE_STATUS_LENGTH:    equ 2
INTERFACE_ALTERNATE_LENGTH: equ 1
INTERFACE_PROTOCOL_LENGTH:  equ 1

NO_EVENT_PENDING:       equ 00h
EVENT_PENDING:          equ 02h

; TRANSACTION TYPES
TRANS_NONE:             equ 00h
TRANS_CONTROL_READ:     equ 02h
TRANS_CONTROL_WRITE:    equ 04h
TRANS_NO_DATA_CONTROL:  equ 06h



;**********************************************************
; USB Descriptor AND  Request constants
;   source p172,,175 USB specification
;**********************************************************


;   Characterists of bmRequest Value
;
; D7    Data xfer direction
;   0 = Host to device
;   1 = Device to host
;
; D6..5 Type
;   0 = Standard
;   1 = Class
;   2 = Vendor
;   3 = Reserved
;
; D4..0 Recipient
;   0 = Device
;   1 = Interface
;   2 = Endpoint
;   3 = Other
;   4..31 = Reserved


;***** bmRequestType
HOSTTODEVICE:           equ 00h
DEVICETOHOST:           equ 80h

STANDARD_TYPE:          equ 00h
CLASS_TYPE:             equ 20h
VENDOR_TYPE:            equ 40h
RESERVED_TYPE:          equ 60h

DEVICE_RECIPIENT:       equ 00h
INTERFACE_RECIPIENT:    equ 01h
ENDPOINT_RECIPIENT:     equ 02h
OTHER_RECIPIENT:        equ 03h

;***** bRequest
GET_STATUS:             equ 00h
CLEAR_FEATURE:          equ 01h
SET_FEATURE:            equ 03h
SET_ADDRESS:            equ 05h
GET_DESCRIPTOR:         equ 06h
SET_DESCRIPTOR:         equ 07h
GET_CONFIGURATION:      equ 08h
SET_CONFIGURATION:      equ 09h
GET_INTERFACE:          equ 0Ah
SET_INTERFACE:          equ 0Bh
SYNCH_FRAME:            equ 0Ch

;***** Descriptor Types
DEVICE:                 equ 01h
CONFIGURATION:          equ 02h
STRING:                 equ 03h
INTERFACE:              equ 04h
ENDPOINT:               equ 05h

;***** Feature Selectors
DEVICE_REMOTE_WAKEUP:   equ 01h
ENDPOINT_STALL:         equ 00h

;***** HID Class Request Types
GET_REPORT:             equ 01h
GET_IDLE:               equ 02h
GET_PROTOCOL:           equ 03h
SET_REPORT:             equ 09h
SET_IDLE:               equ 0Ah
SET_PROTOCOL:           equ 0Bh
                                                    
