//--------------------------------------------------------------------------
//! \file
//!
//!  Include file which defines the board configuration
//!
//--------------------------------------------------------------------------
// $Archive: /WirelessUSB/LS/Firmware/LS DVK/PSoC/DVK RS232 Master/pdc9075.h $
// $Modtime: 3/04/04 3:11p $
// $Revision: 1.1 $
//--------------------------------------------------------------------------
//
// Copyright 2003-2004, Cypress Semiconductor Corporation.
//
// This software is owned by Cypress Semiconductor Corporation (Cypress)
// and is protected by and subject to worldwide patent protection (United
// States and foreign), United States copyright laws and international 
// treaty provisions. Cypress hereby grants to licensee a personal, 
// non-exclusive, non-transferable license to copy, use, modify, create 
// derivative works of, and compile the Cypress Source Code and derivative 
// works for the sole purpose of creating custom software in support of 
// licensee product to be used only in conjunction with a Cypress integrated 
// circuit as specified in the applicable agreement. Any reproduction, 
// modification, translation, compilation, or representation of this 
// software except as specified above is prohibited without the express 
// written permission of Cypress.
//
// Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED, 
// WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Cypress reserves the right to make changes without further notice to the
// materials described herein. Cypress does not assume any liability arising
// out of the application or use of any product or circuit described herein.
// Cypress does not authorize its products for use as critical components in
// life-support systems where a malfunction or failure may reasonably be
// expected to result in significant injury to the user. The inclusion of
// Cypress product in a life-support systems application implies that the
// manufacturer assumes all risk of such use and in doing so indemnifies
// Cypress against all charges.
//
// Use may be limited by and subject to the applicable Cypress software
// license agreement.
//
//-------------------------------------------------------------------------

#ifndef _PDC9075_H_
#define _PDC9075_H_

//--------------------------------------
// Included files
//--------------------------------------

#include "cypdef.h"

//--------------------------------------
// API Definitions and Types
//--------------------------------------
//! Port for the radio
#define RADIO_PORT     PRT1DR
//! Port for the interrupt enable for the radio
#define RADIO_IE_PORT  PORT1
//! Port for LEDs
#define LED_PORT_DR     PRT4DR
//! Port for columns
#define COL_PORT_DR     PRT3DR

//! GPIO ISR definitions (see PSoCGPIO.H)
#define GPIO_ISR_RADIO_IE_PORT    PRT1IE
//! GPIO ISR definitions (see PSoCGPIO.H)
#define GPIO_ISR_RADIO_INT        R_IRQ_MASK 


// Port definitions
//! Port 0
#define PORT0     0x00
//! Port 1
#define PORT1     0x01
//! Port 2
#define PORT2     0x02
//! Port 3
#define PORT3     0x03
//! Port 4
#define PORT4     0x04
//! Port 5
#define PORT5     0x05


// Port bit definitions
//! Port Bit 0
#define PORT_BIT0 0x01
//! Port Bit 1
#define PORT_BIT1 0x02
//! Port Bit 2
#define PORT_BIT2 0x04
//! Port Bit 3
#define PORT_BIT3 0x08
//! Port Bit 4
#define PORT_BIT4 0x10
//! Port Bit 5
#define PORT_BIT5 0x20
//! Port Bit 6
#define PORT_BIT6 0x40
//! Port Bit 7
#define PORT_BIT7 0x80

// Port 1
//! Negated Power Down Pin
#define N_PD        0x01
//! Negated Slave Select Pin
#define N_SS        0x02
//! SERDES Bypass Mode (See CYWUSB6934 Datasheet)
#define DIO	        0x04
//! Negated Reset Pin
#define N_RESET     0x08
//! Negated Interrupt Request Pin
#define N_IRQ       0x10
//! Master In Slave Out Pin
#define MISO        0x20
//! Serial Clock Pin
#define SCK         0x40
//! Master Out Slave In Pin
#define MOSI        0x80

// Port 2
//! LED 1 Pin
#define LED_1		0x01
//! LED 2 Pin
#define LED_2		0x02
//! LED 3 Pin
#define LED_3		0x04
//! LED 4 Pin
#define LED_4		0x08
//! Switch 1 Pin
#define SW_1		0x10
//! Switch 2 Pin
#define SW_2		0x20
//! Switch 3 Pin
#define SW_3		0x40
//! Switch 4 Pin
#define SW_4		0x80

// Port 3
//! Bind Button Pin 
#define BUTTON_BIND    0x01
//! Bind LED Pin 
#define DATA_LED       0x02
//! Connect Button Pin 
#define BUTTON_CONNECT 0x04
//! Connect LED Pin 
#define CONNECT_LED    0x08
//! Bind and Connect LEDs OFF (CONNECT_LED | BIND_LED) 
#define LEDS_OFF       0x0A

// Port 4
//! Column 0 Pin
#define COL_0		0x01
//! Column 1 Pin
#define COL_1		0x02
//! Column 2 Pin
#define COL_2		0x04
//! Column 3 Pin
#define COL_3		0x08
//! Column 4 Pin
#define COL_4		0x10
//! Column 5 Pin
#define COL_5		0x20
#define BIND_LED    0x20
//! Column 6 Pin
#define COL_6		0x40
//! Column 7 Pin
#define COL_7		0x80

// Port 5
//! Row 0 Pin
#define ROW_0		0x01
//! Row 1 Pin
#define ROW_1		0x02
//! Row 2 Pin
#define ROW_2		0x04
//! Row 3 Pin
#define ROW_3		0x08

//! Column dimensions of the scan matrix
#define COLUMNS				 0x05
//! Row dimensions of the scan matrix
#define ROWS				 0x04

// button name defines
//! Button 7
#define BUTTON_7       0x00
//! Button 4
#define BUTTON_4       0x01
//! Button 1
#define BUTTON_1       0x02
//! Button 0
#define BUTTON_0       0x03
//! Button 8
#define BUTTON_8       0x04
//! Button 5
#define BUTTON_5       0x05
//! Button 2
#define BUTTON_2       0x06
//! Button DOT (.)
#define BUTTON_DOT     0x07
//! Button 9
#define BUTTON_9       0x08
//! Button 6
#define BUTTON_6       0x09
//! Button 3
#define BUTTON_3       0x0A
//! Button SPARE
#define BUTTON_SPARE   0x0B
//! Button Right Joystick
#define BUTTON_RT_POT  0x0C
//! Button Minus (-)
#define BUTTON_MINUS   0x0D
//! Button Plus (+)
#define BUTTON_PLUS    0x0E
//! Button Enter
#define BUTTON_ENTER   0x0F
//! Button Left Joystick
#define BUTTON_LT_POT  0x10
//! Button Num Lock
#define BUTTON_NUMLK   0x11
//! Button Slash (/)
#define BUTTON_SLASH   0x12
//! Button Star (*)
#define BUTTON_STAR    0x13

// ADC channel assignments
//! X coordinate for right joystick
#define RIGHT_X	 0x00
//! Y coordinate for right joystick
#define RIGHT_Y	 0x01
//! X coordinate for left joystick
#define LEFT_X	 0x02
//! Y coordinate for left joystick
#define LEFT_Y	 0x03
//! Pot A
#define POT_A	 0x04
//! Pot B
#define POT_B	 0x05
//! Pot C
#define POT_C	 0x06
//! Pot D
#define POT_D    0x07
//! Pot E
#define POT_E    0x08
//! Pot F
#define POT_F    0x09
//! Pot G
#define POT_G    0x0A
//! Pot H
#define POT_H    0x0B

//! To check or set the ON state of the LED's 
#define ON       0x01
//! To check or set the OFF state of the LED's 
#define OFF      0x00

//--------------------------------------
// API Function Declarations
//--------------------------------------

void sw_ports_init(void);
void platform_init(void);

UINT8 bind_pressed(void);
void do_leds(void);
void set_bind_led(UINT8 state);
void set_connect_led(UINT8 state);


#endif //_PDC9075_H_

