//--------------------------------------------------------------------------
//! \file
//!
//! Configure All Global Compile Options
//!
//! These items are usually set in the sources files, but can be over-ridden
//!  here by using 'define' or 'undefine'.
//!
//--------------------------------------------------------------------------
// $Archive: /WirelessUSB/LS/Firmware/LS DVK/PSoC/DVK RS232 Master/ls_config.h $
// $Modtime: 3/04/04 2:41p $
// $Revision: 1.1 $
//--------------------------------------------------------------------------
//
// Copyright 2003-2004, Cypress Semiconductor Corporation.
//
// This software is owned by Cypress Semiconductor Corporation (Cypress)
// and is protected by and subject to worldwide patent protection (United
// States and foreign), United States copyright laws and international 
// treaty provisions. Cypress hereby grants to licensee a personal, 
// non-exclusive, non-transferable license to copy, use, modify, create 
// derivative works of, and compile the Cypress Source Code and derivative 
// works for the sole purpose of creating custom software in support of 
// licensee product to be used only in conjunction with a Cypress integrated 
// circuit as specified in the applicable agreement. Any reproduction, 
// modification, translation, compilation, or representation of this 
// software except as specified above is prohibited without the express 
// written permission of Cypress.
//
// Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED, 
// WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Cypress reserves the right to make changes without further notice to the
// materials described herein. Cypress does not assume any liability arising
// out of the application or use of any product or circuit described herein.
// Cypress does not authorize its products for use as critical components in
// life-support systems where a malfunction or failure may reasonably be
// expected to result in significant injury to the user. The inclusion of
// Cypress product in a life-support systems application implies that the
// manufacturer assumes all risk of such use and in doing so indemnifies
// Cypress against all charges.
//
// Use may be limited by and subject to the applicable Cypress software
// license agreement.
//
//--------------------------------------------------------------------------

#ifndef _LS_CONFIG_H_
#define _LS_CONFIG_H_



//--------------------------------------
// Included files
//--------------------------------------
#include "cypdef.h"
#include "psocgpioint.h"
#include "pdc9075.h"

#define TUTORIAL_MODE // force bind to Channel 7 PN Code 0

//--------------------------------------
// API Definitions and Types
//--------------------------------------

// RADIO PARAMETERS
#ifdef TUTORIAL_MODE
  #define DEFAULT_PN_CODE 0x00
  #define DEFAULT_CHANNEL 0x07
#else
  #define DEFAULT_PN_CODE 0x01
  #define DEFAULT_CHANNEL 0x03
#endif
  
#define DATA_RATE_64

#define BIND_POWER_LEVEL      0x04
#define DEFAULT_POWER_LEVEL	  0x07

#define DEVICE_TYPE           0x00
#define APP_TX_PACKET_SIZE    0x04
#define APP_RX_PACKET_SIZE    0x01

#define TX_TIMEOUT   0x05	

// Flash Block location of the System Parameters
//! Used as a parameter for the non-encrypted nvram reads and writes. Set near the end
//! of 16K flash memory, 3e80.
#define SYS_PARAM_LOC     250  // set near the end of 16K flash memory, 3e80.

// API Macro's

//! Macro for the timer_delay_10_usec routine
#define TIMER_DELAY_10_USEC()                 timer_delay_10_usec()
//! Macro for the timer_delay_50_usec routine
#define TIMER_DELAY_50_USEC()                 timer_delay_50_usec()
//! Macro for the timer_delay_msec routine
#define TIMER_DELAY_MSEC(cnt)                 timer_delay_msec(cnt)
#endif // _LS_CONFIG_H_
