;****************************************************************************
;
;   file:           radio.asm
;   Description:    This file contains all the procedures necessary to interface
;                   with the LS radio
;   External Functions:
;                   radio_interface_init
;                   radio_reset
;                   radio_init
;                   radio_idle
;                   radio_suspend
;                   radio_resume
;                   radio_setup_rx
;                   radio_switch_rx
;                   radio_setup_tx
;                   radio_switch_tx
;                   radio_load_pn_code
;
;   Target:         Cypress CY7C63723/CY7C63743 Encore Chips
;   $Header: g:/archives/Projects/LS DVK P2/Dongle/Two Way/radio.asm
;   Version:        1.3.0000
;
;****************************************************************************
; Copyright (2003), Cypress Semiconductor Corporation
; This software is owned by Cypress Semiconductor Corporation (Cypress) and  is
; protected by United States copyright laws and international treaty provisions.
; Cypress hereby grants to Licensee a personal, non-exclusive, non-transferable
; license to copy, use, modify, create derivative works of, and compile the
; Cypress Source Code and derivative works for the sole purpose of creating
; custom software in support of Licensee product ("Licensee Product") to be used
; only in conjunction with a Cypress integrated circuit. Any reproduction,
; modification, translation, compilation, or representation of this software
; except as specified above is prohibited without the express written permission
; of Cypress.
; Disclaimer: Cypress makes no warranty of any kind, express or implied, with
; regard to this material, including, but not limited to, the implied warranties
; of merchantability and fitness for a particular purpose. Cypress reserves the
; right to make changes without further notice to the materials described herein.
; Cypress does not assume any liability arising out of the application or use of
; any product or circuit described herein. Cypress products described herein are
; not authorized for use as components in life-support devices.
; This software is protected by and subject to worldwide patent coverage,
; including U.S. and foreign patents. Use may be limited by and subject to the
; Cypress Software License Agreement.
;
;****************************************************************************
;-------------------------------------------------------
; 
;   radio_interface_init
;
;-------------------------------------------------------
radio_interface_init:
    MOV  A, ffh                     ; initialize the radio
    MOV  [port0Shadow], A
    MOV  A, fdh
    MOV  [port1Shadow], A
    
    clr_port_1 nPD_R        
    clr_port_0 nRESET

    set_port_1 PWR_EN
    clr_port_1 nPD_R
    
    set_port_1 DIO0
    
    set_port_0 EnSS
    set_port_0 EMOSI
    set_port_0 EMISO
    set_port_0 ESCLK
    
    MOV  A, (0h)         
    IOWR    port1_mode0
    MOV  A, (ffh) 
    IOWR    port1_mode1

    MOV  A, P0_MODE_0_DEFAULT
    IOWR    port0_mode0
    
    MOV  A, P0_MODE_1_DEFAULT
    IOWR    port0_mode1

    CALL delay200us
    set_port_1 nPD_R
  
    MOV  A, ( MODE0 | CPHA)         ; configure SPI
    IOWR spi_control
    
    set_port_0 nRESET               ; bring the radio out of reset    
        
    RET 
    
;-------------------------------------------------------
;
;       radio_init
;
;-------------------------------------------------------
  
radio_init:
    MOV  X, 00h                     ; reset X

radio_loop:        
    IOWR watchdog                   ; load init values into radio registers
    MOV  A, X                       ; radio_table is at bottom of this file
    INC  X
    INDEX radio_table
    MOV  [reg_addr], A
    MOV  A, X
    INC  X
    INDEX radio_table
    MOV  [reg_data], A
    CALL SPI_write
    MOV  A, X
    SUB  A, (end_radio_table - radio_table)
    JC   radio_loop
     
    IOWR watchdog
  
radio_init_complete:
    RET 

;-------------------------------------------------------
;
;   radio_idle
;
;       Turns Rx AND  Tx off.  
;
;-------------------------------------------------------

radio_idle:
    MOV  A, REG_CONTROL
    MOV  [reg_addr], A
    MOV  A, 00h
    MOV  [reg_data], A
    CALL SPI_write
    
    RET 

;-------------------------------------------------------
;
;   setup_rx
;
;       Sets up the radio for Rx
;-------------------------------------------------------
setup_rx:
    MOV  A, REG_CONTROL             ; clear REG_CONTROL
    MOV  [reg_addr], A
    MOV  A, 00h
    MOV  [reg_data], A
    CALL SPI_write

    MOV  A, REG_CHANNEL             ; set the channel
    MOV  [reg_addr], A
    MOV  A, [channel]
    ADD  A, CHANNEL_OFFSET
    AND  A, mCHANNEL
    MOV  [reg_data], A
    CALL SPI_write

switch_rx:
    MOV  A, REG_CONTROL             ; sets radio into RX mode
    MOV  [reg_addr], A
    MOV  A, (bRX_ENABLE | bAUTO_SYNTH_COUNT)
    MOV  [reg_data], A
    CALL SPI_write

    MOV  A, REG_RX_INT_STAT         ; clear RX interrupts to remove any stale interrupts
    MOV  [reg_addr], A  
    CALL SPI_read               

    MOV  A, REG_RX_DATA_A           ; read RX data register to remove any stale data
    MOV  [reg_addr], A  
    CALL SPI_read               

    RET 


                                        
;-------------------------------------------------------
;
;       setup_tx
;
;-------------------------------------------------------
setup_tx:
    MOV  A, REG_CONTROL             ; clear REG_CONTROL
    MOV  [reg_addr], A
    MOV  A, 00h
    MOV  [reg_data], A
    CALL SPI_write

    MOV  A, REG_CHANNEL             ; set the channel
    MOV  [reg_addr], A
    MOV  A, [channel]
    ADD  A, CHANNEL_OFFSET
    AND  A, mCHANNEL
    MOV  [reg_data], A
    CALL SPI_write

switch_tx:
    MOV  A, REG_CONTROL             ; sets radio into TX mode
    MOV  [reg_addr], A
    MOV  A, (bTX_ENABLE | bAUTO_SYNTH_COUNT)
    MOV  [reg_data], A
    CALL SPI_write

    MOV  A, REG_TX_INT_STAT         ; clear TX interrupts to remove any stale interrupts
    MOV  [reg_addr], A  
    CALL SPI_read               

    RET 

;-------------------------------------------------------
;
;   SPI_put
;
;-------------------------------------------------------
SPI_put:
    IOWR spi_data
sp_wait_done:
    IOWR watchdog
    IORD spi_control
    AND  A, TCMP
    JZ   sp_wait_done
    MOV  A, (MODE0 | CPHA)    
    IOWR spi_control
    RET 

;-------------------------------------------------------
;
;   SPI_write
;
;-------------------------------------------------------
SPI_write:
    DI
    clr_port_0 EnSS
    MOV  A, [reg_addr]
    OR    A, 80h
    CALL SPI_put
    MOV  A, [reg_data]
    CALL SPI_put
    set_port_0 EnSS
    EI
    RET 
    
;-------------------------------------------------------
;
;   SPI_read
;
;-------------------------------------------------------
SPI_read:
    DI
    clr_port_0 EnSS
    MOV  A, [reg_addr]
    AND  A, 3fh
    CALL SPI_put
    MOV  A, 0                       ; dummy data
    CALL SPI_put
    IORD spi_data
    MOV  [reg_data], A
    set_port_0 EnSS
    EI
    RET 

;****************************************************************************
; radio_suspend
;
; Processing:
; The radio is put into Suspend state
;
;****************************************************************************
radio_suspend :
    CALL radio_idle                 ; disable Tx, Rx    
    clr_port_1 nPD_R                ; power down radio

    RET 

;****************************************************************************
; radio_resume
;
; Processing:
; The radio is taken out of Suspend state
;
;****************************************************************************
radio_resume :

    CALL delay200us
    set_port_1 nPD_R                ; power up radio
    
    CALL delay200us                 
    CALL delay200us                 
    CALL delay200us                 
    CALL delay200us                 
    CALL delay200us                 

    CALL delay200us                 
    CALL delay200us                 
    CALL delay200us                 
    CALL delay200us                 
    CALL delay200us  
                   
    CALL delay200us                 
    CALL delay200us                 
    CALL delay200us                 
    CALL delay200us                 
    CALL delay200us                 
    
    CALL setup_rx

    RET 
    

;-------------------------------------------------------
;
;       radio_load_pn_code
;       Loads the desired PN_CODE from the PN_CODE tables into 
;       the radio.
;
;       A: contains PN code index
;-------------------------------------------------------
radio_load_pn_code:

    ASL                             ; pn_code is the PN_CODE's position in the ROM table,
    ASL                             ; which takes 8 bytes, so multiply by 8
    ASL                             ; to get the position of the first byte of the PN_CODE
    MOV  [ls_temp], A                
    
    MOV  X, 0
       
pn_code1_move_loop:                 ; Now that the pn_code is set we can load the PN_CODE into the radio
    MOV  A, X
    ADD  A, REG_PN_CODE
    MOV  [reg_addr], A

    MOV  A, X
    ADD  A, [ls_temp]
    INDEX pn_code_1_table
    MOV  [reg_data], A
    CALL SPI_write

    INC  X
    MOV  A, X
    SUB  A, 8
    JC   pn_code1_move_loop    

    RET 

;-------------------------------------------------------
;
;   read_radio_mid
;
;   reads the radio MID into RAM
;   the radio MID is used to calculate the channel, PN code, etc.
;-------------------------------------------------------
read_radio_mid:
    MOV  A, REG_ANALOG_CTL          ; enable Radio MID
    MOV  [reg_addr], A
    MOV  A, (bAGC_EN | bPACTL_EN | bID_EN)
    MOV  [reg_data], A
    CALL SPI_write
    
    MOV  A, REG_MFG_ID+3
    MOV  [reg_addr], A
    CALL SPI_read
    MOV  A, [reg_data]
    MOV  [bridge_mid4], A
    
    MOV  A, REG_MFG_ID+2
    MOV  [reg_addr], A
    CALL SPI_read
    MOV  A, [reg_data]
    MOV  [bridge_mid3], A
    
    MOV  A, REG_MFG_ID+1
    MOV  [reg_addr], A
    CALL SPI_read
    MOV  A, [reg_data]
    MOV  [bridge_mid2], A
    
    MOV  A, REG_MFG_ID
    MOV  [reg_addr], A
    CALL SPI_read
    MOV  A, [reg_data]
    MOV  [bridge_mid1], A
    
    MOV  A, REG_ANALOG_CTL          ; disable the ID to conserve power
    MOV  [reg_addr], A
    MOV  A, (bAGC_EN | bPACTL_EN)
    MOV  [reg_data], A
    CALL SPI_write
    RET    

XPAGEOFF
;-------------------------------------------------------
;   radio_table
;-------------------------------------------------------
radio_table:
    db REG_CONTROL, 00h             ; TX, RX disable
    db REG_DATA_RATE, RADIO_MODE    ; 32/64 chip PN_CODE, DDR select, etc. (see config.inc)
    db REG_CONFIG, bCMOS            ; CMOS Active high IRQ pin
    db REG_THOLD_L, THRESHOLD_L     ; correlation threshold
    db REG_THOLD_H, THRESHOLD_H     ; correlation threshold
    db REG_XTAL_ADJ, (bCLOCK_DISABLE)
    db REG_VCO_CAL, bMINUS5_PLUS5
    db REG_PA, (PA_BIAS & mPA_BIAS)
    db REG_RX_INT_EN, (bRX_EOF_A | bRX_FULL_A)   ; only Full AND  EOF on channel A
    db REG_TX_INT_EN, (bTX_EMPTY | bTX_EOF)    ; empty A, EOF 
    db REG_SERDES_CTL, (bSERDES_ENABLE | (mEND_OF_FRAME_LEN & EOF_BITS))              
    db REG_TX_VALID, FFh                           ; ALL valid bits (we are transmitting full bytes)
    db REG_ANALOG_CTL, (bAGC_EN | bPACTL_EN)
    db REG_AGC_CTL, bAGC_OFF
    db REG_CLOCK_MANUAL, 41h        ; Manually override RSSI clock and RC clock
    db REG_CLOCK_ENABLE, 41h
    db REG_CARRIER_DETECT, bCDET
end_radio_table:
XPAGEON                
      
    
XPAGEOFF
pn_code_1_table:
    db 6Ah, E7h, 01h, EAh, 03h, FDh, 13h, D2h 
    db DCh, C0h, 6Bh, B8h, 2Bh, 09h, BBh, B2h 
    db A3h, 1Eh, F2h, A4h, 31h, 32h, 7Ah, B3h 
    db 44h, 83h, 3Bh, DDh, 14h, CFh, 8Eh, C9h 
    db 35h, 35h, 4Eh, C5h, F3h, 52h, 47h, B0h
    db 7Ch, 23h, 8Ah, CEh, 45h, 5Ch, 54h, D7h 
    db 81h, ACh, FBh, 83h, 7Ah, 9Ah, 61h, ACh 
    db 3Ch, 12h, 5Fh, 9Ch, 39h, 98h, F6h, 8Ah 
end_pn_code_table:
XPAGEON
    
