;****************************************************************************
;
;   file:           wusb-ls-headers.inc 
;   Description:    This file contains application registers addresses,
;                   constants, etc. 
;   Target:         Cypress CY7C63723/CY7C63743 Encore Chips
;   $Header:
;   Version:        1.3.0000
;
;****************************************************************************
; Copyright (2003), Cypress Semiconductor Corporation
; This software is owned by Cypress Semiconductor Corporation (Cypress) and  is
; protected by United States copyright laws and international treaty provisions.
; Cypress hereby grants to Licensee a personal, non-exclusive, non-transferable
; license to copy, use, modify, create derivative works of, and compile the
; Cypress Source Code and derivative works for the sole purpose of creating
; custom software in support of Licensee product ("Licensee Product") to be used
; only in conjunction with a Cypress integrated circuit. Any reproduction,
; modification, translation, compilation, or representation of this software
; except as specified above is prohibited without the express written permission
; of Cypress.
; Disclaimer: Cypress makes no warranty of any kind, express or implied, with
; regard to this material, including, but not limited to, the implied warranties
; of merchantability and fitness for a particular purpose. Cypress reserves the
; right to make changes without further notice to the materials described herein.
; Cypress does not assume any liability arising out of the application or use of
; any product or circuit described herein. Cypress products described herein are
; not authorized for use as components in life-support devices.
; This software is protected by and subject to worldwide patent coverage,
; including U.S. and foreign patents. Use may be limited by and subject to the
; Cypress Software License Agreement.
;
;****************************************************************************

INCLUDE "radio.inc"

;----------------------------------------------------
; RADIO DEFINES
;----------------------------------------------------
EOF_BITS:           equ 07h

NUM_CHANNELS:       equ 78          ; number of channels that are used 0 to NUM_CHANNELS-1
CHANNEL_OFFSET:     equ 02

DEFINE              PN_CODE_32_TABLE       
RADIO_MODE:         equ (b32_CHIP_BITS | bDOUBLE_DATA_RATE | b6X_OVERSAMPLING)

THRESHOLD_L:        equ 3           ; RX correlator lo threshold    
THRESHOLD_H:        equ 29          ; RX correlator hi threshold    
NUM_PN_CODES:       equ 8  

PA_BIAS:            equ 07h         ; radio power amp bias

bFLAG_EOF:              equ 01h


;*****************************************
;       Data Memory map
;*****************************************

PSP_BASE:       equ 00h             ; Program stack rises from here
DSP_TOP:        equ dfh             ; Data stack pointer works down from just below EP0 buffer


;------------------------------------------------------
;       Radio-related Variables
;------------------------------------------------------
; USB uses registers up to 36h
port0Shadow:        equ 39h
port1Shadow:        equ 3Ah
                                
reg_addr:           equ 3Bh
reg_data:           equ 3Ch

timer:              equ 3Fh
led_timer:          equ 40h
led_state:          equ 44h
ls_temp:            equ 41h
radio_int:          equ 42h
rx_counter:         equ 3Eh

channel:            equ 43h
pn_code:            equ 44h

button_pushed:      equ 52h


; Determines size of RX Buffer, must be at least 10 bytes for encrypted, 8 bytes for unencrypted
RX_BUFFER_LEN:      equ 10
rx_buffer:          equ 70h         ; 70h-79h
valid_buffer:       equ 80h         ; 80h-89h

tx_sys_counter:     equ 90h
tx_sys_buffer:      equ 91h         ; requires 10 bytes

;------------------------------------------------------
;       Hardware Constants
;------------------------------------------------------

bBUTTON_DOWN:           equ 01h


; port 0
nRESET:                 equ 01h
IRQ:                    equ 02h
DIO0:                   equ 04h
nCS:                    equ 04h 
DIO1:                   equ 08h
nDATA_LED:              equ 08h 
EnSS:                   equ 10h
EMOSI:                  equ 20h
EMISO:                  equ 40h
ESCLK:                  equ 80h


; port 1
nPD_R:                  equ 01h
PWR_EN:                 equ 02h
IFDEF PDC_9168
nBIND_LED:              equ 02h
ENDIF ; PDC_9168
IFDEF PDC_9075
nBIND_LED:              equ 04h
ENDIF ; PDC_9075

; port 2
BIND_BUTTON:            equ 02h


P0_MODE_1_DEFAULT:                 equ (ESCLK |         EMOSI | EnSS | nDATA_LED | nCS |       nRESET) ;BDh ;1011 1101
P0_MODE_0_DEFAULT:                 equ (ESCLK |         EMOSI       )                                  ;A0h ;1010 0000
;P0_DATA_DEFAULT:                  equ (ESCLK | EMISO | EMOSI | EnSS |             nCS |       nRESET) ;F5h ;1111 0101

P0_MODE_1_SUSPEND:                 equ FFh
P0_MODE_0_SUSPEND:                 equ 00h
P0_DATA_SUSPEND:                   equ 1Dh

P1_BITS:                           equ (PWR_EN | nPD_R)
P1_MODE_1_DEFAULT:                 equ FFh
P1_MODE_0_DEFAULT:                 equ 00h
;P1_DATA_DEFAULT:                   equ (PWR_EN | nPD_R) ;03h ;0000 0011

P1_MODE_1_SUSPEND:                 equ FFh
P1_MODE_0_SUSPEND:                 equ 00h
P1_DATA_SUSPEND:                   equ FEh ; continue to hold nPD low during suspend
;P1_DATA_SUSPEND:                   equ FFh


